@@ -2,19 +2,22 @@ OC.L10N.register(
     "activity",
     {
     "Activity" : "활동",
+    "Activities" : "활동",
+    "Error loading activities" : "활동 불러오기 오류",
+    "No activities" : "활동 없음",
+    ", " : ", ",
+    "{parameterList} and {lastParameter}" : "{parameterList} 및 {lastParameter}",
+    "_{parameterList} and {linkStart}%n more{linkEnd}_::_{parameterList} and {linkStart}%n more{linkEnd}_" : ["{parameterList} 및 {linkStart}%n개 더{linkEnd}"],
+    "in {directory}" : "{directory}에 있음",
+    "This stream will show events like additions, changes & shares" : "스트림에는 추가, 변경, 공유와 같은 이벤트가 표시됩니다",
+    "There are no events for this filter" : "이 필터를 만족하는 이벤트 없음",
+    "Today" : "오늘",
+    "Yesterday" : "어제",
     "Personal activity feed for %s" : "%s 님의 개인 활동 피드",
     "Your feed URL is invalid" : "피드 주소가 잘못되었습니다",
     "Your settings have been updated." : "설정이 업데이트 되었습니다.",
     "Mail" : "메일",
     "Stream" : "스트림",
-    "Activities" : "활동",
-    "Error loading activities" : "활동 불러오기 오류",
-    "No activities" : "활동 없음",
-    ", " : ", ",
-    "This stream will show events like additions, changes & shares" : "스트림에는 추가, 변경, 공유와 같은 이벤트가 표시됩니다",
-    "There are no events for this filter" : "이 필터를 만족하는 이벤트 없음",
-    "Today" : "오늘",
-    "Yesterday" : "어제",
     "\"remote user\"" : "\"원격 사용자\"",
     "Activity notification" : "활동 알림",
     "All Activities" : "모든 활동",
@@ -25,7 +28,6 @@ OC.L10N.register(
     "You are receiving this email because the following things happened at %s" : "%s에서 일어난 일의 알림을 받아 보기로 설정하였으므로 이 메일을 받았습니다",
     "* %1$s - %2$s" : "* %1$s - %2$s",
     "_* and %n more _::_* and %n more _" : ["* 그 외 %n개 더 있음"],
-    "List your own actions in the stream" : "스트림에서 내가 한 작업 보기",
     "Notify about your own actions via email" : "내 작업도 이메일로 알림 받기",
     "You need to set up your email address before you can receive notification emails." : "알림 이메일을 받으려면 이메일 주소를 설정해야 합니다.",
     "Send emails:" : "이메일 보내는 간격:",
