@@ -2,16 +2,21 @@ OC.L10N.register(
     "activity",
     {
     "Activity" : "Активност",
+    "Activities" : "Активности",
+    "Error loading activities" : "Грешка при вчитување на активностите",
+    "No activities" : "Нема активности",
+    ", " : ", ",
+    "{parameterList} and {lastParameter}" : "{parameterList} и {lastParameter}",
+    "in {directory}" : "во {directory}",
+    "This stream will show events like additions, changes & shares" : "Овој стрим ќе прикажува настани како додатоци, промени и споделувања",
+    "There are no events for this filter" : "Нема настани за овој филтер",
+    "Today" : "Денеска",
+    "Yesterday" : "Вчера",
     "Personal activity feed for %s" : "Feed на лични активности за %s",
     "Your feed URL is invalid" : "Вашиот URL за feed не е исправен",
     "Your settings have been updated." : "Вашите нагодувања беа освежени.",
     "Mail" : "Електронска пошта",
     "Stream" : "Стрим",
-    ", " : ", ",
-    "This stream will show events like additions, changes & shares" : "Овој стрим ќе прикажува настани како додатоци, промени и споделувања",
-    "There are no events for this filter" : "Нема настани за овој филтер",
-    "Today" : "Денеска",
-    "Yesterday" : "Вчера",
     "\"remote user\"" : "\"далечен корисник\"",
     "Activity notification" : "Известување за Активности",
     "All Activities" : "Сите активности",
@@ -20,7 +25,7 @@ OC.L10N.register(
     "%s and %s" : "%s и %s",
     "Hello %s," : "Здраво %s,",
     "* %1$s - %2$s" : "* %1$s - %2$s",
-    "List your own actions in the stream" : "Ги листа вашите активности во стримот",
+    "List your own file actions in the stream" : "Ги листа вашите активности во стримот",
     "Notify about your own actions via email" : "Извести за своите активности преку порака",
     "You need to set up your email address before you can receive notification emails." : "Ќе треба да ја внесете Вашата електронска адреса за да можете да примате известувања по електронска пошта.",
     "Send emails:" : "Пратени пораки:",
