@@ -21,14 +21,16 @@ OC.L10N.register(
     "Invalid directory." : "مسار غير صحيح.",
     "Files" : "الملفات",
     "All files" : "كل الملفات",
-    "Favorites" : "المفضلة ",
     "Home" : "البيت",
     "Close" : "إغلاق",
+    "Favorites" : "المفضلة ",
     "Upload cancelled." : "تم إلغاء عملية رفع الملفات .",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "تعذر رفع الملف {filename} إما لأنه مجلد أو لان حجم الملف 0 بايت",
     "Total file size {size1} exceeds upload limit {size2}" : "حجم الملف الكلي {size1} تجاوز الحد المسموح للرفع {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "لا يوجد مساحة تخزين كافية، انت تقوم برفع {size1} ولكن المساحه المتوفره هي {size2}.",
     "Could not get result from server." : "تعذر الحصول على نتيجة من الخادم",
+    "Uploading..." : "ترفيع...",
+    "..." : "...",
     "File upload is in progress. Leaving the page now will cancel the upload." : "عملية رفع الملفات قيد التنفيذ. اغلاق الصفحة سوف يلغي عملية رفع الملفات.",
     "Actions" : "* تطبيقات.\n* أنشطة.",
     "Download" : "تحميل",
@@ -40,6 +42,12 @@ OC.L10N.register(
     "Pending" : "قيد الانتظار",
     "Unable to determine date" : "تعذر تحديد التاريخ",
     "This operation is forbidden" : "هذة العملية ممنوعة ",
+    "Could not rename \"{fileName}\"" : "إعادة تسمية الملف \"{fileName}\" لم تنجح",
+    "Could not create file \"{file}\"" : "لا يمكن إنشاء الملف\"{file}\"",
+    "Could not create file \"{file}\" because it already exists" : "لا يمكن إنشاء الملف \"{file}\" فهو موجود بالفعل",
+    "Could not create folder \"{dir}\"" : "لا يمكن إنشاء المجلد \"{dir}\"",
+    "Could not create folder \"{dir}\" because it already exists" : "لا يمكن إنشاء المجلد \"{dir}\" فهو موجود بالفعل",
+    "Error deleting file \"{fileName}\"." : "خطأ أثناء حذف الملف \"{fileName}\".",
     "No entries in this folder match '{filter}'" : "لا يوجد مدخلات في هذا المجلد تتوافق مع '{filter}'",
     "Name" : "اسم",
     "Size" : "حجم",
@@ -56,6 +64,7 @@ OC.L10N.register(
     "Your storage is full, files can not be updated or synced anymore!" : "مساحتك التخزينية ممتلئة, لا يمكن تحديث ملفاتك أو مزامنتها بعد الآن !",
     "Storage of {owner} is almost full ({usedSpacePercent}%)" : "المساحة التخزينية لـ {owner} ممتلئة تقريبا ({usedSpacePercent}%)",
     "Your storage is almost full ({usedSpacePercent}%)" : "مساحتك التخزينية امتلأت تقريبا ",
+    "Path" : "المسار",
     "Favorite" : "المفضلة",
     "Folder" : "مجلد",
     "New folder" : "مجلد جديد",
@@ -82,8 +91,6 @@ OC.L10N.register(
     "Save" : "حفظ",
     "Settings" : "إعدادات",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "استخدم هذا العنوان لـ  <a href=\"%s\" target=\"_blank\">الدخول الى ملفاتك عن طريق WebDAV</a>",
-    "Cancel upload" : "إلغاء الرفع",
     "No files in here" : "لا يوجد ملفات هنا ",
     "Upload some content or sync with your devices!" : "ارفع بعض المحتوي او زامن مع اجهزتك !",
     "No entries found in this folder" : "لا يوجد مدخلات في هذا المجلد ",
