@@ -15,21 +15,33 @@ OC.L10N.register(
     "Missing a temporary folder" : "Chybí adresář pro dočasné soubory",
     "Failed to write to disk" : "Zápis na disk selhal",
     "Not enough storage available" : "Nedostatek dostupného úložného prostoru",
-    "The target folder has been moved or deleted." : "Cílová složka byla přesunuta nebo smazána.",
+    "The target folder has been moved or deleted." : "Cílový adresář byl přesunuta nebo smazán.",
     "Upload failed. Could not find uploaded file" : "Nahrávání selhalo. Nepodařilo se nalézt nahraný soubor.",
     "Upload failed. Could not get file info." : "Nahrávání selhalo. Nepodařilo se získat informace o souboru.",
     "Invalid directory." : "Neplatný adresář",
     "Files" : "Soubory",
     "All files" : "Všechny soubory",
-    "Favorites" : "Oblíbené",
+    "File could not be found" : "Soubor nelze nalézt",
     "Home" : "Domů",
     "Close" : "Zavřít",
+    "Favorites" : "Oblíbené",
     "Upload cancelled." : "Odesílání zrušeno.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nelze nahrát soubor {filename}, protože je to buď adresář nebo má velikost 0 bytů",
     "Total file size {size1} exceeds upload limit {size2}" : "Celková velikost souboru {size1} překračuje povolenou velikost pro nahrávání {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Není dostatek místa pro uložení, velikost souboru je {size1}, zbývá pouze {size2}",
     "Error uploading file \"{fileName}\": {message}" : "Chyba nahrávání souboru \"{fileName}\": {message}",
     "Could not get result from server." : "Nepodařilo se získat výsledek ze serveru.",
+    "Uploading..." : "Odesílám...",
+    "..." : "...",
+    "{hours}:{minutes}:{seconds} hour{plural_s} left" : "zbývá {hours}:{minutes}:{seconds} hour{plural_s}",
+    "{hours}:{minutes}h" : "{hours}:{minutes}h",
+    "{minutes}:{seconds} minute{plural_s} left" : "zbývá {minutes}:{seconds} minute{plural_s}",
+    "{minutes}:{seconds}m" : "{minutes}:{seconds}m",
+    "{seconds} second{plural_s} left" : "{seconds} sekund{plural_s} zbývá",
+    "{seconds}s" : "{seconds}s",
+    "Any moment now..." : "Každou chvíli...",
+    "Soon..." : "Brzy...",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} z {totalSize} ({bitrate})",
     "File upload is in progress. Leaving the page now will cancel the upload." : "Probíhá odesílání souboru. Opuštění stránky způsobí zrušení nahrávání.",
     "Actions" : "Činnosti",
     "Download" : "Stáhnout",
@@ -58,7 +70,7 @@ OC.L10N.register(
     "Name" : "Název",
     "Size" : "Velikost",
     "Modified" : "Upraveno",
-    "_%n folder_::_%n folders_" : ["%n složka","%n složky","%n složek"],
+    "_%n folder_::_%n folders_" : ["%n adresář","%n adresáře","%n adresářů"],
     "_%n file_::_%n files_" : ["%n soubor","%n soubory","%n souborů"],
     "{dirs} and {files}" : "{dirs} a {files}",
     "You don’t have permission to upload or create files here" : "Nemáte oprávnění sem nahrávat nebo vytvářet soubory",
@@ -75,16 +87,17 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtů"],
     "Favorited" : "Přidáno k oblíbeným",
     "Favorite" : "Oblíbené",
-    "Folder" : "Složka",
-    "New folder" : "Nová složka",
+    "Local link" : "Místní odkaz",
+    "Folder" : "Adresář",
+    "New folder" : "Nový adresář",
     "{newname} already exists" : "{newname} již existuje",
     "Upload" : "Odeslat",
     "An error occurred while trying to update the tags" : "Při pokusu o úpravu tagů nastala chyba",
-    "A new file or folder has been <strong>created</strong>" : "Byl <strong>vytvořen</strong> nový soubor nebo složka",
-    "A file or folder has been <strong>changed</strong>" : "Soubor nebo složka byla <strong>změněna</strong>",
+    "A new file or folder has been <strong>created</strong>" : "Byl <strong>vytvořen</strong> nový soubor nebo adresář",
+    "A file or folder has been <strong>changed</strong>" : "Soubor nebo adresář byl <strong>změněn</strong>",
     "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limit oznámení o tvorbě a změnách vašich <strong>oblíbených souborů</strong> <em>(Pouze streamovat)</em>",
-    "A file or folder has been <strong>deleted</strong>" : "Soubor nebo složka byla <strong>smazána</strong>",
-    "A file or folder has been <strong>restored</strong>" : "Soubor nebo složka byla <strong>obnovena</strong>",
+    "A file or folder has been <strong>deleted</strong>" : "Soubor nebo adresář byl <strong>smazán</strong>",
+    "A file or folder has been <strong>restored</strong>" : "Soubor nebo adresář byla <strong>obnoven</strong>",
     "You created %1$s" : "Vytvořili jste %1$s",
     "%2$s created %1$s" : "%2$s vytvořil(a) %1$s",
     "%1$s was created in a public folder" : "%1$s byl vytvořen ve veřejném adresáři",
@@ -105,25 +118,18 @@ OC.L10N.register(
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "Při použití PHP-FPM může změna nastavení trvat až 5 minut od uložení.",
     "Missing permissions to edit from here." : "Pro úpravy v aktuálním náhledu chybí oprávnění.",
     "Settings" : "Nastavení",
+    "Show hidden files" : "Zobrazit skryté soubory",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Použijte tuto adresu pro <a href=\"%s\" target=\"_blank\">přístup k vašim souborům přes WebDAV</a>",
-    "Cancel upload" : "Zrušit odesílání",
+    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Použijte tuto adresu pro <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">přístup ke svým Souborům přes WebDAV</a>",
     "No files in here" : "Žádné soubory",
     "Upload some content or sync with your devices!" : "Nahrajte nějaký obsah nebo synchronizujte se svými přístroji!",
-    "No entries found in this folder" : "V této složce nebylo nic nalezeno",
+    "No entries found in this folder" : "V tomto adresáři nebylo nic nalezeno",
     "Select all" : "Vybrat vše",
     "Upload too large" : "Odesílaný soubor je příliš velký",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Soubory, které se snažíte odeslat, překračují limit velikosti odesílání na tomto serveru.",
     "No favorites" : "Žádné oblíbené",
     "Files and folders you mark as favorite will show up here" : "Soubory a adresáře označené jako oblíbené budou zobrazeny zde",
     "Text file" : "Textový soubor",
-    "New text file.txt" : "Nový textový soubor.txt",
-    "Changed by %2$s" : "Změněno uživatelem %2$s",
-    "Deleted by %2$s" : "Smazáno uživatelem %2$s",
-    "Restored by %2$s" : "Obnoveno uživatelem %2$s",
-    "You changed %1$s" : "Změnili jste %1$s",
-    "You created %1$s" : "Vytvořili jste %1$s",
-    "You deleted %1$s" : "Smazali jste %1$s",
-    "You restored %1$s" : "Obnovili jste %1$s"
+    "New text file.txt" : "Nový textový soubor.txt"
 },
 "nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
