@@ -21,15 +21,27 @@ OC.L10N.register(
     "Invalid directory." : "Cartella non valida.",
     "Files" : "File",
     "All files" : "Tutti i file",
-    "Favorites" : "Preferiti",
+    "File could not be found" : "Il file non può essere trovato",
     "Home" : "Home",
     "Close" : "Chiudi",
+    "Favorites" : "Preferiti",
     "Upload cancelled." : "Caricamento annullato.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossibile caricare {filename} poiché è una cartella oppure ha una dimensione di 0 byte.",
     "Total file size {size1} exceeds upload limit {size2}" : "La dimensione totale del file {size1} supera il limite di caricamento {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Spazio insufficiente, stai caricando {size1}, ma è rimasto solo {size2}",
     "Error uploading file \"{fileName}\": {message}" : "Errore durante il caricamento del file \"{fileName}\": {message}",
     "Could not get result from server." : "Impossibile ottenere il risultato dal server.",
+    "Uploading..." : "Caricamento in corso...",
+    "..." : "...",
+    "{hours}:{minutes}:{seconds} hour{plural_s} left" : "{hours}:{minutes}:{seconds} ore rimanenti",
+    "{hours}:{minutes}h" : "{hours}:{minutes}h",
+    "{minutes}:{seconds} minute{plural_s} left" : "{minutes}:{seconds} minuti rimanenti",
+    "{minutes}:{seconds}m" : "{minutes}:{seconds}m",
+    "{seconds} second{plural_s} left" : "{seconds} secondi rimanenti",
+    "{seconds}s" : "{seconds}s",
+    "Any moment now..." : "Da un momento all'altro...",
+    "Soon..." : "Presto...",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} di {totalSize} ({bitrate})",
     "File upload is in progress. Leaving the page now will cancel the upload." : "Caricamento del file in corso. La chiusura della pagina annullerà il caricamento.",
     "Actions" : "Azioni",
     "Download" : "Scarica",
@@ -75,6 +87,7 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n byte","%n byte"],
     "Favorited" : "Preferiti",
     "Favorite" : "Preferito",
+    "Local link" : "Collegamento locale",
     "Folder" : "Cartella",
     "New folder" : "Nuova cartella",
     "{newname} already exists" : "{newname} esiste già",
@@ -105,9 +118,9 @@ OC.L10N.register(
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "Con PHP-FPM potrebbe richiedere 5 minuti perché le modifiche siano applicate.",
     "Missing permissions to edit from here." : "Permessi mancanti per modificare da qui.",
     "Settings" : "Impostazioni",
+    "Show hidden files" : "Mostra i file nascosti",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Utilizza questo indirizzo per <a href=\"%s\" target=\"_blank\">accedere ai tuoi file con WebDAV</a>",
-    "Cancel upload" : "Annulla caricamento",
+    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Utilizza questo indirizzo per <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">accedere ai tuoi file con WebDAV</a>",
     "No files in here" : "Qui non c'è alcun file",
     "Upload some content or sync with your devices!" : "Carica alcuni contenuti o sincronizza con i tuoi dispositivi!",
     "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
