@@ -21,14 +21,15 @@ OC.L10N.register(
     "Invalid directory." : "Neteisingas aplankas",
     "Files" : "Failai",
     "All files" : "Visi failai",
-    "Favorites" : "Mėgstamiausi",
     "Home" : "Namų",
     "Close" : "Užverti",
+    "Favorites" : "Mėgstamiausi",
     "Upload cancelled." : "Įkėlimas atšauktas.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nepavyksta įkelti {filename}, nes tai katalogas arba yra 0 baitų dydžio",
     "Total file size {size1} exceeds upload limit {size2}" : "Visas failo dydis {size1} viršyja įkėlimo limitą {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nepakanka laisvos vietos. Keliate {size1}, bet tik {size2} yra likę",
     "Could not get result from server." : "Nepavyko gauti rezultato iš serverio.",
+    "Uploading..." : "Įkeliama...",
     "File upload is in progress. Leaving the page now will cancel the upload." : "Failo įkėlimas pradėtas. Jei paliksite šį puslapį, įkėlimas nutrūks.",
     "Actions" : "Veiksmai",
     "Download" : "Atsisiųsti",
@@ -105,8 +106,6 @@ OC.L10N.register(
     "Missing permissions to edit from here." : "Draudžiama iš čia redaguoti",
     "Settings" : "Nustatymai",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Naudokite šį adresą, kad <a href=\"%s\" target=\"_blank\">pasiektumėte savo failus per WebDAV</a>",
-    "Cancel upload" : "Atšaukti siuntimą",
     "No files in here" : "Čia nėra failų",
     "Upload some content or sync with your devices!" : "Įkelkite kokį nors turinį, arba sinchronizuokite su savo įrenginiais!",
     "No entries found in this folder" : "Nerasta įrašų šiame aplanke",
