@@ -21,15 +21,27 @@ OC.L10N.register(
     "Invalid directory." : "Ongeldige directory.",
     "Files" : "Bestanden",
     "All files" : "Alle bestanden",
-    "Favorites" : "Favorieten",
+    "File could not be found" : "Bestand kon niet worden gevonden",
     "Home" : "Thuis",
     "Close" : "Sluiten",
+    "Favorites" : "Favorieten",
     "Upload cancelled." : "Uploaden geannuleerd.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan {filename} niet uploaden omdat het een map is of 0 bytes groot is",
     "Total file size {size1} exceeds upload limit {size2}" : "Totale bestandsgrootte {size1} groter dan uploadlimiet {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Niet genoeg vrije ruimte. U upload {size1}, maar is is slechts {size2} beschikbaar",
     "Error uploading file \"{fileName}\": {message}" : "Fout tijdens het uploaden van bestand \"{fileName}\": {message}",
     "Could not get result from server." : "Kon het resultaat van de server niet terugkrijgen.",
+    "Uploading..." : "Uploading...",
+    "..." : "...",
+    "{hours}:{minutes}:{seconds} hour{plural_s} left" : "{hours}:{minutes}:{seconds} uur{plural_s} over",
+    "{hours}:{minutes}h" : "{hours}:{minutes}h",
+    "{minutes}:{seconds} minute{plural_s} left" : "{minutes}:{seconds} minuten{plural_s} over",
+    "{minutes}:{seconds}m" : "{minutes}:{seconds}m",
+    "{seconds} second{plural_s} left" : "{seconds} seconden{plural_s} over",
+    "{seconds}s" : "{seconds}en",
+    "Any moment now..." : "Heel snel nu...",
+    "Soon..." : "Binnenkort...",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} van {totalSize} ({bitrate})",
     "File upload is in progress. Leaving the page now will cancel the upload." : "Bestandsupload is bezig. Wanneer de pagina nu verlaten wordt, stopt de upload.",
     "Actions" : "Acties",
     "Download" : "Downloaden",
@@ -50,9 +62,9 @@ OC.L10N.register(
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "De naam \"{targetName}\" bestaat al in map \"{dir}\". Kies een andere naam.",
     "Could not rename \"{fileName}\"" : "Kon \"{fileName}\" niet hernoemen",
     "Could not create file \"{file}\"" : "Kon \"{file}\" niet aanmaken",
-    "Could not create file \"{file}\" because it already exists" : "Kon \"{file}\" niet aanmaken omdat het al bestaat",
+    "Could not create file \"{file}\" because it already exists" : "Kon \"{file}\" niet aanmaken, omdat het al bestaat",
     "Could not create folder \"{dir}\"" : "Kon map \"{dir}\" niet aanmaken",
-    "Could not create folder \"{dir}\" because it already exists" : "Kon map \"{dir}\" niet aanmaken omdat die al bestaat",
+    "Could not create folder \"{dir}\" because it already exists" : "Kon map \"{dir}\" niet aanmaken, omdat die al bestaat",
     "Error deleting file \"{fileName}\"." : "Fout bij verwijderen bestand \"{fileName}\".",
     "No entries in this folder match '{filter}'" : "Niets in deze map komt overeen met '{filter}'",
     "Name" : "Naam",
@@ -74,6 +86,7 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
     "Favorited" : "Favoriet",
     "Favorite" : "Favoriet",
+    "Local link" : "Lokale link",
     "Folder" : "Map",
     "New folder" : "Nieuwe map",
     "{newname} already exists" : "{newname} bestaat al",
@@ -83,7 +96,7 @@ OC.L10N.register(
     "A file or folder has been <strong>changed</strong>" : "Een bestand of map is <strong>gewijzigd</strong>",
     "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Beperk meldingen over aanmaken en wijzigen aan uw <strong>favoriete bestanden</strong> <em>(Alleen stream)</em>",
     "A file or folder has been <strong>deleted</strong>" : "Een bestand of map is <strong>verwijderd</strong>",
-    "A file or folder has been <strong>restored</strong>" : "Een bestand of een mmaps is <strong>hersteld</strong>",
+    "A file or folder has been <strong>restored</strong>" : "Een bestand of een map is <strong>hersteld</strong>",
     "You created %1$s" : "Gecreëerd: %1$s",
     "%2$s created %1$s" : "%2$s creëerde %1$s",
     "%1$s was created in a public folder" : "%1$s werd gecreëerd in een openbare map",
@@ -104,9 +117,9 @@ OC.L10N.register(
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "Met PHP-FPM kan het 5 minuten duren voordat wijzigingen zijn doorgevoerd.",
     "Missing permissions to edit from here." : "Ontbrekende rechten om vanaf hier te bewerken.",
     "Settings" : "Instellingen",
+    "Show hidden files" : "Tonen verborgen bestanden",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Gebruik deze link <a href=\"%s\" target=\"_blank\">om uw bestanden via WebDAV te benaderen</a>",
-    "Cancel upload" : "Upload afbreken",
+    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Gebruik deze link <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">om uw bestanden via WebDAV te benaderen</a>",
     "No files in here" : "Hier geen bestanden",
     "Upload some content or sync with your devices!" : "Upload bestanden of synchroniseer met uw apparaten!",
     "No entries found in this folder" : "Niets",
@@ -114,15 +127,8 @@ OC.L10N.register(
     "Upload too large" : "Upload is te groot",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "De bestanden die u probeert te uploaden zijn groter dan de maximaal toegestane  bestandsgrootte voor deze server.",
     "No favorites" : "Geen favorieten",
-    "Files and folders you mark as favorite will show up here" : "Bestanden en mappen die u favoriet vindt worden hier getoont",
+    "Files and folders you mark as favorite will show up here" : "Bestanden en mappen die u favoriet vindt, worden hier getoond",
     "Text file" : "Tekstbestand",
-    "New text file.txt" : "Nieuw tekstbestand.txt",
-    "Changed by %2$s" : "Gewijzigd door %2$s",
-    "Deleted by %2$s" : "Verwijderd door %2$s",
-    "Restored by %2$s" : "Hersteld door %2$s",
-    "You changed %1$s" : "Gewijzigd: %1$s",
-    "You created %1$s" : "Gecreëerd: %1$s",
-    "You deleted %1$s" : "Verwijderd: %1$s",
-    "You restored %1$s" : "Hersteld: %1$s"
+    "New text file.txt" : "Nieuw tekstbestand.txt"
 },
 "nplurals=2; plural=(n != 1);");
