@@ -1,5 +1,6 @@
 <?php
 /**
+ * @author Joas Schilling <nickvergessen@owncloud.com>
  * @author Robin Appelman <icewind@owncloud.com>
  *
  * @copyright Copyright (c) 2016, ownCloud, Inc.
@@ -21,10 +22,10 @@
 
 $installedVersion = \OC::$server->getConfig()->getAppValue('files_external', 'installed_version');
 
-$app = new \OCA\Files_external\Appinfo\Application();
+$app = new \OCA\Files_External\AppInfo\Application();
 
 // Migration to db config
 if (version_compare($installedVersion, '0.5.0', '<')) {
-	$migrator = $app->getContainer()->query('OCA\Files_external\Migration\StorageMigrator');
+	$migrator = $app->getContainer()->query('OCA\Files_External\Migration\StorageMigrator');
 	$migrator->migrateGlobal();
 }
