@@ -7,6 +7,19 @@ OC.L10N.register(
     "Step 1 failed. Exception: %s" : "Langkah 1 gagal. Kecuali: %s",
     "Step 2 failed. Exception: %s" : "Langkah 2 gagal. Kecuali: %s",
     "External storage" : "Penyimpanan eksternal",
+    "Personal" : "Pribadi",
+    "System" : "Sistem",
+    "Grant access" : "Berikan hak akses",
+    "Error configuring OAuth1" : "Kesalahan mengkonfigurasi OAuth1",
+    "Error configuring OAuth2" : "Kesalahan mengkonfigurasi OAuth2",
+    "Generate keys" : "Hasilkan kunci",
+    "Error generating key pair" : "Kesalahan saat menghasilkan pasangan kunci",
+    "All users. Type to select user or group." : "Semua pengguna. Ketik untuk memilih pengguna atau grup.",
+    "(group)" : "(grup)",
+    "Saved" : "Disimpan",
+    "Username" : "Nama Pengguna",
+    "Password" : "Sandi",
+    "Save" : "Simpan",
     "Storage with id \"%i\" not found" : "Penyimpanan dengan id \"%i\" tidak ditemukan",
     "Invalid backend or authentication mechanism class" : "Beckend atau kelas mekanisme otentikasi salah.",
     "Invalid mount point" : "Mount point salah",
@@ -16,25 +29,6 @@ OC.L10N.register(
     "Not permitted to use authentication mechanism \"%s\"" : "Tidak diizinkan menggunakan mekanisme otentikasi \"%s\"",
     "Unsatisfied backend parameters" : "Parameter backend tidak lengkap",
     "Unsatisfied authentication mechanism parameters" : "Parameter mekanisme otentikasi tidak lengkap",
-    "Personal" : "Pribadi",
-    "System" : "Sistem",
-    "Grant access" : "Berikan hak akses",
-    "Access granted" : "Akses diberikan",
-    "Error configuring OAuth1" : "Kesalahan mengkonfigurasi OAuth1",
-    "Error configuring OAuth2" : "Kesalahan mengkonfigurasi OAuth2",
-    "Generate keys" : "Hasilkan kunci",
-    "Error generating key pair" : "Kesalahan saat menghasilkan pasangan kunci",
-    "Enable encryption" : "Aktifkan enkripsi",
-    "Enable previews" : "Aktifkan pratinjau",
-    "Check for changes" : "Periksa perubahan",
-    "Never" : "Jangan pernah",
-    "Once every direct access" : "Setiap kali akses langsung",
-    "All users. Type to select user or group." : "Semua pengguna. Ketik untuk memilih pengguna atau grup.",
-    "(group)" : "(grup)",
-    "Saved" : "Disimpan",
-    "Username" : "Nama Pengguna",
-    "Password" : "Sandi",
-    "Save" : "Simpan",
     "Access key" : "Kunci akses",
     "Secret key" : "Kunci rahasia",
     "Builtin" : "Internal",
@@ -92,6 +86,11 @@ OC.L10N.register(
     "Name" : "Nama",
     "Storage type" : "Tipe penyimpanan",
     "Scope" : "Skop",
+    "Enable encryption" : "Aktifkan enkripsi",
+    "Enable previews" : "Aktifkan pratinjau",
+    "Check for changes" : "Periksa perubahan",
+    "Never" : "Jangan pernah",
+    "Once every direct access" : "Setiap kali akses langsung",
     "External Storage" : "Penyimpanan Eksternal",
     "Folder name" : "Nama folder",
     "Authentication" : "Otentikasi",
@@ -100,7 +99,6 @@ OC.L10N.register(
     "Add storage" : "Tambahkan penyimpanan",
     "Advanced settings" : "Pengaturan Lanjutan",
     "Delete" : "Hapus",
-    "Allow users to mount the following external storage" : "Izinkan pengguna untuk mengaitkan penyimpanan eksternal berikut",
-    "SMB / CIFS" : "SMB / CIFS"
+    "Allow users to mount the following external storage" : "Izinkan pengguna untuk mengaitkan penyimpanan eksternal berikut"
 },
 "nplurals=1; plural=0;");
