@@ -7,6 +7,36 @@ OC.L10N.register(
     "Step 1 failed. Exception: %s" : "ステップ 1 の実行に失敗しました。例外: %s",
     "Step 2 failed. Exception: %s" : "ステップ 2 の実行に失敗しました。例外: %s",
     "External storage" : "外部ストレージ",
+    "Dropbox App Configuration" : "Dropbox アプリ設定",
+    "Google Drive App Configuration" : "Google アプリ設定",
+    "Personal" : "個人",
+    "System" : "システム",
+    "Grant access" : "アクセスを許可",
+    "Error configuring OAuth1" : "OAuth1 設定エラー",
+    "Error configuring OAuth2" : "OAuth2 設定エラー",
+    "Generate keys" : "キーを生成",
+    "Error generating key pair" : "キーペアの生成エラー",
+    "All users. Type to select user or group." : "すべてのユーザー。ユーザー、グループを追加",
+    "(group)" : "(グループ)",
+    "Compatibility with Mac NFD encoding (slow)" : "Mac NFD エンコード互換 (遅い)",
+    "Admin defined" : "管理者設定済",
+    "Saved" : "保存されました",
+    "Empty response from the server" : "サーバーから空の応答がありました",
+    "Couldn't access. Please logout and login to activate this mount point" : "アクセス出来ませんでした｡このマウントポイントを有効にするには一度ログアウトしてからログインしてください。",
+    "Couldn't get the information from the ownCloud server: {code} {type}" : "ownCloud サーバーから情報を取得出来ませんでした。: {code} {type}",
+    "Couldn't get the list of external mount points: {type}" : "外部マウントポイントのリストを取得出来ませんでした。: {type}",
+    "There was an error with message: " : "メッセージ付きのエラーが発生しました：",
+    "External mount error" : "外部マウントエラー",
+    "external-storage" : "外部ストレージ",
+    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Windows ネットワークドライブのマウントポイントリストを取得出来ませんでした:サーバーから空の応答がありました",
+    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "いくつかの設定済み外部マウントポイントに接続できませんでした。詳細情報は赤い行をクリックしてください",
+    "Please enter the credentials for the {mount} mount" : " {mount} をマウントするための必要な資格情報を入力してください",
+    "Username" : "ユーザー名",
+    "Password" : "パスワード",
+    "Credentials saved" : "資格情報を保存しました",
+    "Credentials saving failed" : "資格情報の保存に失敗しました",
+    "Credentials required" : "資格情報が必要です",
+    "Save" : "保存",
     "Storage with id \"%i\" not found" : "ストレージID \"%i\" が見つかりません",
     "Invalid backend or authentication mechanism class" : "バックエンドまたは認証システムクラスが無効",
     "Invalid mount point" : "無効なマウントポイント",
@@ -19,40 +49,6 @@ OC.L10N.register(
     "Insufficient data: %s" : "データが不足しています: %s",
     "%s" : "%s",
     "Storage with id \"%i\" is not user editable" : "ストレージID \"%i\" はユーザーが編集できません",
-    "Personal" : "個人",
-    "System" : "システム",
-    "Grant access" : "アクセスを許可",
-    "Access granted" : "アクセスは許可されました",
-    "Error configuring OAuth1" : "OAuth1 設定エラー",
-    "Error configuring OAuth2" : "OAuth2 設定エラー",
-    "Generate keys" : "キーを生成",
-    "Error generating key pair" : "キーペアの生成エラー",
-    "Enable encryption" : "暗号化を有効に",
-    "Enable previews" : "プレビューを有効に",
-    "Enable sharing" : "共有の有効化",
-    "Check for changes" : "変更点を確認",
-    "Never" : "更新無",
-    "Once every direct access" : "直指定時のみ",
-    "All users. Type to select user or group." : "すべてのユーザー。ユーザー、グループを追加",
-    "(group)" : "(グループ)",
-    "Admin defined" : "管理者設定済",
-    "Saved" : "保存されました",
-    "Empty response from the server" : "サーバーから空の応答がありました",
-    "Couldn't access. Please logout and login to activate this mount point" : "アクセス出来ませんでした｡このマウントポイントを有効にするには一度ログアウトしてからログインしてください。",
-    "Couldn't get the information from the ownCloud server: {code} {type}" : "ownCloud サーバーから情報を取得出来ませんでした。: {code} {type}",
-    "Couldn't get the list of external mount points: {type}" : "外部マウントポイントのリストを取得出来ませんでした。: {type}",
-    "There was an error with message: " : "メッセージ付きのエラーが発生しました：",
-    "External mount error" : "外部マウントエラー",
-    "external-storage" : "外部ストレージ",
-    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Windows ネットワークドライブのマウントポイントリストを取得出来ませんでした:サーバーから空の応答がありました",
-    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "いくつかの設定済み外部マウントポイントに接続できませんでした。詳細情報は赤い行をクリックしてください",
-    "Please enter the credentials for the {mount} mount" : " {mount} のマウントのために必要な資格情報を入力してください",
-    "Username" : "ユーザー名",
-    "Password" : "パスワード",
-    "Credentials saved" : "資格情報を保存しました",
-    "Credentials saving failed" : "資格情報の保存に失敗しました",
-    "Credentials required" : "資格情報が必要です",
-    "Save" : "保存",
     "Access key" : "アクセスキー",
     "Secret key" : "シークレットキー",
     "Builtin" : "ビルトイン",
@@ -111,6 +107,12 @@ OC.L10N.register(
     "Name" : "名前",
     "Storage type" : "ストレージ種別",
     "Scope" : "スコープ",
+    "Enable encryption" : "暗号化を有効に",
+    "Enable previews" : "プレビューを有効に",
+    "Enable sharing" : "共有の有効化",
+    "Check for changes" : "変更点を確認",
+    "Never" : "更新無",
+    "Once every direct access" : "直指定時のみ",
     "External Storage" : "外部ストレージ",
     "Folder name" : "フォルダー名",
     "Authentication" : "認証",
