@@ -7,6 +7,33 @@ OC.L10N.register(
     "Step 1 failed. Exception: %s" : "1단계 실패. 예외: %s",
     "Step 2 failed. Exception: %s" : "2단계 실패. 예외: %s",
     "External storage" : "외부 저장소",
+    "Personal" : "개인",
+    "System" : "시스템",
+    "Grant access" : "접근 권한 부여",
+    "Error configuring OAuth1" : "OAuth1 설정 오류",
+    "Error configuring OAuth2" : "OAuth2 설정 오류",
+    "Generate keys" : "키 생성",
+    "Error generating key pair" : "키 쌍을 생성하는 중 오류 발생",
+    "All users. Type to select user or group." : "모든 사용자입니다. 사용자나 그룹을 선택하려면 입력하십시오",
+    "(group)" : "(그룹)",
+    "Admin defined" : "관리자 지정",
+    "Saved" : "저장됨",
+    "Empty response from the server" : "서버에서 빈 응답이 돌아옴",
+    "Couldn't access. Please logout and login to activate this mount point" : "접근할 수 없습니다. 이 마운트 지점을 활성화하려면 로그아웃 후 로그인하십시오",
+    "Couldn't get the information from the ownCloud server: {code} {type}" : "ownCloud 서버에서 정보를 가져올 수 없음: {code} {type}",
+    "Couldn't get the list of external mount points: {type}" : "외부 마운트 지점 목록을 가져올 수 없음: {type}",
+    "There was an error with message: " : "오류 메시지: ",
+    "External mount error" : "외부 마운트 오류",
+    "external-storage" : "external-storage",
+    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Windows 네트워크 드라이브 마운트 지점 목록을 가져올 수 없음: 서버에서 빈 응답이 돌아옴",
+    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "일부 외부 마운트 지점을 연결할 수 없습니다. 빨간색으로 표시된 줄을 눌러서 더 많은 정보를 확인하십시오",
+    "Please enter the credentials for the {mount} mount" : "{mount} 마운트 인증 정보를 입력하십시오",
+    "Username" : "사용자 이름",
+    "Password" : "암호",
+    "Credentials saved" : "인증 정보 저장됨",
+    "Credentials saving failed" : "인증 정보를 저장할 수 없음",
+    "Credentials required" : "인증 정보 필요함",
+    "Save" : "저장",
     "Storage with id \"%i\" not found" : "ID가 \"%i\"인 저장소를 찾을 수 없음",
     "Invalid backend or authentication mechanism class" : "백엔드나 인증 방식 클래스가 잘못됨",
     "Invalid mount point" : "잘못된 마운트 지점",
@@ -17,25 +44,8 @@ OC.L10N.register(
     "Unsatisfied backend parameters" : "백엔드 인자가 부족함",
     "Unsatisfied authentication mechanism parameters" : "인증 방식 인자가 부족함",
     "Insufficient data: %s" : "충분하지 않은 데이터: %s",
-    "Personal" : "개인",
-    "System" : "시스템",
-    "Grant access" : "접근 권한 부여",
-    "Access granted" : "접근 허가됨",
-    "Error configuring OAuth1" : "OAuth1 설정 오류",
-    "Error configuring OAuth2" : "OAuth2 설정 오류",
-    "Generate keys" : "키 생성",
-    "Error generating key pair" : "키 쌍을 생성하는 중 오류 발생",
-    "Enable encryption" : "암호화 사용",
-    "Enable previews" : "미리 보기 사용",
-    "Check for changes" : "변경 사항 감시",
-    "Never" : "하지 않음",
-    "Once every direct access" : "한 번 직접 접근할 때마다",
-    "All users. Type to select user or group." : "모든 사용자입니다. 사용자나 그룹을 선택하려면 입력하십시오",
-    "(group)" : "(그룹)",
-    "Saved" : "저장됨",
-    "Username" : "사용자 이름",
-    "Password" : "암호",
-    "Save" : "저장",
+    "%s" : "%s",
+    "Storage with id \"%i\" is not user editable" : "저장소 ID \"%i\"을(를) 사용자가 편집할 수 없음",
     "Access key" : "접근 키",
     "Secret key" : "비밀 키",
     "Builtin" : "내장",
@@ -52,6 +62,7 @@ OC.L10N.register(
     "Rackspace" : "Rackspace",
     "API key" : "API 키",
     "Username and password" : "사용자 이름과 암호",
+    "Log-in credentials, save in session" : "로그인 인증 정보, 세션에 저장됨",
     "RSA public key" : "RSA 공개 키",
     "Public key" : "공개 키",
     "Amazon S3" : "Amazon S3",
@@ -93,6 +104,12 @@ OC.L10N.register(
     "Name" : "이름",
     "Storage type" : "저장소 종류",
     "Scope" : "범위",
+    "Enable encryption" : "암호화 사용",
+    "Enable previews" : "미리 보기 사용",
+    "Enable sharing" : "공유 사용",
+    "Check for changes" : "변경 사항 감시",
+    "Never" : "하지 않음",
+    "Once every direct access" : "한 번 직접 접근할 때마다",
     "External Storage" : "외부 저장소",
     "Folder name" : "폴더 이름",
     "Authentication" : "인증",
@@ -102,20 +119,6 @@ OC.L10N.register(
     "Advanced settings" : "고급 설정",
     "Delete" : "삭제",
     "Allow users to mount external storage" : "사용자가 외부 저장소를 마운트하도록 허용",
-    "Allow users to mount the following external storage" : "사용자가 다음 외부 저장소를 마운트할 수 있도록 허용",
-    "Admin defined" : "관리자 지정",
-    "Couldn't access. Please logout and login to activate this mount point" : "접근할 수 없습니다. 이 마운트 지점을 활성화하려면 로그아웃 후 로그인하십시오",
-    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Windows 네트워크 드라이브 마운트 지점 목록을 가져올 수 없음: 서버에서 빈 응답이 돌아옴",
-    "Credentials required" : "인증 정보 필요함",
-    "Credentials saved" : "인증 정보 저장됨",
-    "Credentials saving failed" : "인증 정보를 저장할 수 없음",
-    "Empty response from the server" : "서버에서 빈 응답이 돌아옴",
-    "Enable sharing" : "공유 사용",
-    "External mount error" : "외부 마운트 오류",
-    "external-storage" : "external-storage",
-    "Log-in credentials, save in session" : "로그인 인증 정보, 세션에 저장됨",
-    "Please enter the credentials for the {mount} mount" : "{mount} 마운트 인증 정보를 입력하십시오",
-    "SMB / CIFS" : "SMB/CIFS",
-    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "일부 외부 마운트 지점을 연결할 수 없습니다. 빨간색으로 표시된 줄을 눌러서 더 많은 정보를 확인하십시오"
+    "Allow users to mount the following external storage" : "사용자가 다음 외부 저장소를 마운트할 수 있도록 허용"
 },
 "nplurals=1; plural=0;");
