@@ -11,7 +11,6 @@ OC.L10N.register(
     "Shared with you" : "Sdíleno s vámi",
     "Shared with others" : "Sdíleno s ostatními",
     "Shared by link" : "Sdíleno pomocí odkazu",
-    "Federated sharing" : "Propojené sdílení",
     "Nothing shared with you yet" : "Zatím s vámi nikdo nic nesdílel",
     "Files and folders others share with you will show up here" : "Zde budou zobrazeny soubory a adresáře, které s vámi ostatní sdílí",
     "Nothing shared yet" : "Zatím není nic sdíleno",
@@ -28,8 +27,27 @@ OC.L10N.register(
     "Invalid ownCloud url" : "Neplatná ownCloud url",
     "Shared by" : "Sdílí",
     "Sharing" : "Sdílení",
-    "A file or folder has been <strong>shared</strong>" : "Soubor nebo složka byla <strong>nasdílena</strong>",
-    "A file or folder was shared from <strong>another server</strong>" : "Soubor nebo složka byla nasdílena z <strong>jiného serveru</strong>",
+    "Share API is disabled" : "Sdílení API je zakázané",
+    "Wrong share ID, share doesn't exist" : "Špatné ID sdílení, sdílení neexistuje",
+    "Could not delete share" : "Nelze smazat sdílení",
+    "Please specify a file or folder path" : "Prosím zadejte cestu adresáře nebo souboru",
+    "Wrong path, file/folder doesn't exist" : "Špatná cesta, soubor/adresář neexistuje",
+    "Please specify a valid user" : "Prosím zadejte platného uživatele",
+    "Group sharing is disabled by the administrator" : "Skupinové sdílení bylo zakázáno administrátorem",
+    "Please specify a valid group" : "Prosím zadejte platnou skupinu",
+    "Public link sharing is disabled by the administrator" : "Veřejný odkaz sdílení je zakázán administrátorem",
+    "Public upload disabled by the administrator" : "Veřejné nahrávání zakázáno administrátorem",
+    "Public upload is only possible for publicly shared folders" : "Veřejné nahrávání je možné pouze do veřejně sdílených adresářů",
+    "Invalid date, date format must be YYYY-MM-DD" : "Neplatné datum, formát data musí být YYY-MM-DD",
+    "Sharing %s failed because the back end does not allow shares from type %s" : "Sdílení %s selhalo, podpůrná vrstva nepodporuje typ sdílení %s",
+    "Unknown share type" : "Neznámý typ sdílení",
+    "Not a directory" : "Žádný adresář",
+    "Could not lock path" : "Nepodařilo se uzamknout cestu",
+    "Can't change permissions for public share links" : "Nelze změnit oprávnění pro veřejně sdílené odkazy",
+    "Wrong or no update parameter given" : "Chyba nebo žádná aktualizace dle zadaných parametrů",
+    "Cannot increase permissions" : "Nelze navýšit oprávnění",
+    "A file or folder has been <strong>shared</strong>" : "Soubor nebo adresář byl <strong>nasdílen</strong>",
+    "A file or folder was shared from <strong>another server</strong>" : "Soubor nebo adresář byl nasdílen z <strong>jiného serveru</strong>",
     "A public shared file or folder was <strong>downloaded</strong>" : "Byl <strong>stažen</strong> veřejně sdílený soubor nebo adresář",
     "You received a new remote share %2$s from %1$s" : "Obdrželi jste nové vzdálené sdílení %2$s od uživatele %1$s",
     "You received a new remote share from %s" : "Obdrželi jste nové vzdálené sdílení z %s",
@@ -71,11 +89,6 @@ OC.L10N.register(
     "Public link of %2$s expired" : "Veřejný odkaz %2$s vypršel",
     "Shared by %2$s" : "%2$s sdílel(a)",
     "Shares" : "Sdílení",
-    "You received \"/%2$s\" as a remote share from %1$s" : "Obdržel(a) jsi \"/%2$s\" jako vzdálené sdílení od %1$s",
-    "Accept" : "Přijmout",
-    "Decline" : "Zamítnout",
-    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Sdílej se mnou pomocí mého #ownCloud sdruženého cloud ID, více na %s",
-    "Share with me through my #ownCloud Federated Cloud ID" : "Sdílej se mnou pomocí mého #ownCloud sdruženého cloud ID",
     "This share is password-protected" : "Toto sdílení je chráněno heslem",
     "The password is wrong. Try again." : "Heslo není správné. Zkuste to znovu.",
     "Password" : "Heslo",
@@ -91,29 +104,6 @@ OC.L10N.register(
     "Add to your ownCloud" : "Přidat do svého ownCloudu",
     "Download" : "Stáhnout",
     "Download %s" : "Stáhnout %s",
-    "Direct link" : "Přímý odkaz",
-    "Federated Cloud Sharing" : "Propojené cloudové sdílení",
-    "Open documentation" : "Otevřít dokumentaci",
-    "Allow users on this server to send shares to other servers" : "Povolit uživatelům z tohoto serveru zasílat sdílení na jiné servery",
-    "Allow users on this server to receive shares from other servers" : "Povolit uživatelům z tohoto serveru přijímat sdílení z jiných serverů",
-    "Federated Cloud" : "Sdružený cloud",
-    "Your Federated Cloud ID:" : "Vaše sdružené cloud ID:",
-    "Share it:" : "Sdílet:",
-    "Add to your website" : "Přidat na svou webovou stránku",
-    "Share with me via ownCloud" : "Sdíleno se mnou přes ownCloud",
-    "HTML Code:" : "HTML kód:",
-    "Public link of %2$s expired" : "Veřejný odkaz %2$s vypršel",
-    "Public shared file %1$s was downloaded" : "Byl stažen veřejně sdílený soubor %1$s ",
-    "Public shared folder %1$s was downloaded" : "Byl stažen veřejně sdílený adresář %1$s ",
-    "Removed share for %2$s" : "Odstranil(a) sdílení pro %2$s",
-    "Removed share of group %2$s" : "Odstranil(a) sdílení skupině %2$s",
-    "Shared by %2$s" : "%2$s sdílel(a)",
-    "Shared via link by %2$s" : "%2$s sdílel(a) jako odkaz",
-    "Shared with group %3$s by %2$s" : "%2$s sdílí se skupinou %3$s",
-    "The public link of %2$s for %1$s expired" : "Veřejný odkaz na %2$s pro %1$s vypršel",
-    "You removed the public link for %1$s" : "Odstranil(a) jsi veřejný odkaz na %1$s",
-    "You removed the share of %2$s for %1$s" : "Odstranil(a) jsi sdílení %2$s pro %1$s",
-    "You removed the share of group %2$s for %1$s" : "Odstranil(a) jsi sdílení skupině %2$s pro %1$s",
-    "Your public link for %1$s expired" : "Veřejný odkaz pro %1$s vypršel"
+    "Direct link" : "Přímý odkaz"
 },
 "nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
