@@ -3,15 +3,14 @@ OC.L10N.register(
     {
     "Server to server sharing is not enabled on this server" : "Das Server-zu-Server-Teilen ist auf diesem Server nicht aktiviert",
     "The mountpoint name contains invalid characters." : "Der Name des Einhängepunktes enthält ungültige Zeichen.",
-    "Not allowed to create a federated share with the same user server" : "Nicht erlaubt eine föderierte Freigabe mit dem gleichen Benutzerserver zu erstellen",
+    "Not allowed to create a federated share with the same user server" : "Teilen mit Nutzern auf dem selben Server via Federated Cloud ist nicht erlaubt",
     "Invalid or untrusted SSL certificate" : "Ungültiges oder nicht vertrauenswürdiges SSL-Zertifikat",
     "Could not authenticate to remote share, password might be wrong" : "Die Authentifizierung an der entfernten Freigabe konnte nicht erfolgen, das Passwort könnte falsch sein",
     "Storage not valid" : "Speicher ungültig",
-    "Couldn't add remote share" : "Entfernte Freigabe kann nicht hinzu gefügt werden",
+    "Couldn't add remote share" : "Remotefreigabe kann nicht hinzu gefügt werden",
     "Shared with you" : "Mit Dir geteilt",
     "Shared with others" : "Von Dir geteilt",
     "Shared by link" : "Geteilt über einen Link",
-    "Federated sharing" : "Federated-Sharing",
     "Nothing shared with you yet" : "Bis jetzt wurde nichts mit Dir geteilt",
     "Files and folders others share with you will show up here" : "Mit Dir geteilte Dateien und Ordner anderer werden hier erscheinen",
     "Nothing shared yet" : "Noch nichts geteilt",
@@ -28,6 +27,25 @@ OC.L10N.register(
     "Invalid ownCloud url" : "Ungültige OwnCloud-URL",
     "Shared by" : "Geteilt von ",
     "Sharing" : "Teilen",
+    "Share API is disabled" : "Teilen-API ist deaktivert",
+    "Wrong share ID, share doesn't exist" : "Fehlerhafte Freigabe-ID, Freigabe existiert nicht",
+    "Could not delete share" : "Freigabe konnte nicht gelöscht werden",
+    "Please specify a file or folder path" : "Bitte eine Datei oder  Verzeichnis definieren",
+    "Wrong path, file/folder doesn't exist" : "Falscher Pfad, Datei/Verzeichnis existiert nicht",
+    "Please specify a valid user" : "Bitte gib einen gültigen Nutzer an",
+    "Group sharing is disabled by the administrator" : "Die Gruppenfreigabe ist durch den Administrator deaktiviert",
+    "Please specify a valid group" : "Bitte gib eine gültige Gruppe an",
+    "Public link sharing is disabled by the administrator" : "Die öffentliche Freigabe von Links ist durch den Administrator deaktiviert",
+    "Public upload disabled by the administrator" : "Das öffentliche Hochladen ist durch den Administrator deaktiviert",
+    "Public upload is only possible for publicly shared folders" : "Das öffentliche Hochladen ist nur für öffentlich freigegebene Ordner erlaubt",
+    "Invalid date, date format must be YYYY-MM-DD" : "Ungültiges Datum, das Datumsformat muss JJJJ-MM-TT sein",
+    "Sharing %s failed because the back end does not allow shares from type %s" : "Freigabe von %s fehlgeschlagen, da das Backend die Freigabe vom Typ %s nicht erlaubt.",
+    "Unknown share type" : "Unbekannter Freigabetyp",
+    "Not a directory" : "Kein Verzeichnis",
+    "Could not lock path" : "Pfad konnte nicht gesperrt werden",
+    "Can't change permissions for public share links" : "Berechtigungen für öffentlich freigegebene Links konnten nicht geändert werden",
+    "Wrong or no update parameter given" : "Falscher oder kein Updateparameter wurde übergeben",
+    "Cannot increase permissions" : "Berechtigungen können nicht erhöht werden",
     "A file or folder has been <strong>shared</strong>" : "Eine Datei oder ein Ordner wurde <strong>geteilt</strong>",
     "A file or folder was shared from <strong>another server</strong>" : "Eine Datei oder ein Ordner wurde von <strong>einem anderen Server</strong> geteilt",
     "A public shared file or folder was <strong>downloaded</strong>" : "Eine öffentliche geteilte Datei oder ein öffentlicher geteilter Ordner wurde <strong>heruntergeladen</strong>",
@@ -40,42 +58,37 @@ OC.L10N.register(
     "Public shared file %1$s was downloaded" : "Die öffentliche geteilte Datei %1$s wurde heruntergeladen",
     "You shared %1$s with %2$s" : "Du hast %1$s mit %2$s geteilt",
     "%2$s shared %1$s with %3$s" : "%2$s geteilt %1$s mit %3$s",
-    "You removed the share of %2$s for %1$s" : "Sie haben die Freigabe von %2$s für %1$s",
-    "%2$s removed the share of %3$s for %1$s" : "%2$s entfernt die Freigabe der %3$s für %1$s",
+    "You removed the share of %2$s for %1$s" : "Du hast die Freigabe von %2$s für %1$s entfernt",
+    "%2$s removed the share of %3$s for %1$s" : "%2$s hat die Freigabe der %3$s für %1$s entfernt",
     "You shared %1$s with group %2$s" : "Du hast %1$s mit der Gruppe %2$s geteilt",
-    "%2$s shared %1$s with group %3$s" : "%2$s geteilt %1$s mit Gruppe %3$s",
-    "You removed the share of group %2$s for %1$s" : "Du hast der Gruppe von der Freigabe entfernt %2$s für %1$s",
-    "%2$s removed the share of group %3$s for %1$s" : "%2$s Freigabe der Gruppe entfernt %3$s für %1$s",
-    "%2$s shared %1$s via link" : "%2$s geteilt %1$s via Link",
+    "%2$s shared %1$s with group %3$s" : "%2$s hat %1$s mit Gruppe %3$s geteilt",
+    "You removed the share of group %2$s for %1$s" : "Du hast die Freigabe der Gruppe %2$s für %1$s entfernt",
+    "%2$s removed the share of group %3$s for %1$s" : "%2$s hat die Freigabe der Gruppe %3$s für %1$s entfernt",
+    "%2$s shared %1$s via link" : "%2$s hat %1$s über einen Link freigegeben",
     "You shared %1$s via link" : "Du hast %1$s über einen Link freigegeben",
     "You removed the public link for %1$s" : "Du hast den öffentlichen Link für %1$s entfernt",
-    "%2$s removed the public link for %1$s" : "%2$s entfernte den öffentlichen Link für %1$s",
+    "%2$s removed the public link for %1$s" : "%2$s hat den öffentlichen Link für %1$s entfernt",
     "Your public link for %1$s expired" : "Dein öffentlicher Link für %1$s ist abgelaufen",
     "The public link of %2$s for %1$s expired" : "Der öffentliche Link von %2$s für %1$s ist abgelaufen",
     "%2$s shared %1$s with you" : "%2$s hat %1$s mit Dir geteilt",
-    "%2$s removed the share for %1$s" : "%2$s entfernte die Freigabe für %1$s",
+    "%2$s removed the share for %1$s" : "%2$s hat die Freigabe für %1$s entfernt",
     "Downloaded via public link" : "Runtergeladen mittels öffentlichen Link",
     "Shared with %2$s" : "Geteilt mit %2$s",
     "Shared with %3$s by %2$s" : "Geteilt mit %3$s von %2$s",
-    "Removed share for %2$s" : "Entfernte die Freigabe für %2$s",
-    "%2$s removed share for %3$s" : "%2$s entfernte die Freigabe für %3$s",
+    "Removed share for %2$s" : "Freigabe für %2$s entfernt",
+    "%2$s removed share for %3$s" : "%2$s hat die Freigabe für %3$s entfernt",
     "Shared with group %2$s" : "Geteilt mit Gruppe %2$s",
-    "Shared with group %3$s by %2$s" : "Geteilt mit Gruppe %3$s von %2$s",
-    "Removed share of group %2$s" : "entfernte die Gruppe von der Freigabe %2$s   ",
-    "%2$s removed share of group %3$s" : "%2$s entfernte die Gruppe von der Freigabe %3$s",
+    "Shared with group %3$s by %2$s" : "Freigabe für Gruppe %3$s von %2$s entfernt",
+    "Removed share of group %2$s" : "Freigabe für Gruppe %2$s entfernt",
+    "%2$s removed share of group %3$s" : "%2$s hat die Freigabe für Gruppe %3$s entfernt",
     "Shared via link by %2$s" : "Geteilt mittels Link von %2$s",
     "Shared via public link" : "Geteilt mittels öffentlichen Link",
-    "Removed public link" : "entfernt öffentlichen Link",
-    "%2$s removed public link" : "%2$s entfernte den öffentlichen Link",
+    "Removed public link" : "Öffentlichen Link entfernt",
+    "%2$s removed public link" : "%2$s hat den öffentlichen Link entfernt",
     "Public link expired" : "öffentlicher Link ist abgelaufen",
-    "Public link of %2$s expired" : "öffentlicher Link von %2$s ist abgelaufen",
+    "Public link of %2$s expired" : "Öffentlicher Link von %2$s ist abgelaufen",
     "Shared by %2$s" : "Geteilt von %2$s",
     "Shares" : "Freigaben",
-    "You received \"/%2$s\" as a remote share from %1$s" : "Du empfängst \"/%2$s\" als Remote Freigabe von %1$s",
-    "Accept" : "Ok",
-    "Decline" : "Abgelehnt",
-    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Teile mit mir über meine #ownCloud Federated-Cloud-ID, siehe %s",
-    "Share with me through my #ownCloud Federated Cloud ID" : "Teile mit mir über meine #ownCloud Federated-Cloud-ID",
     "This share is password-protected" : "Diese Freigabe ist durch ein Passwort geschützt",
     "The password is wrong. Try again." : "Bitte überprüfe Dein Passwort und versuche es erneut.",
     "Password" : "Passwort",
@@ -91,16 +104,6 @@ OC.L10N.register(
     "Add to your ownCloud" : "Zu Deiner ownCloud hinzufügen",
     "Download" : "Herunterladen",
     "Download %s" : "Download %s",
-    "Direct link" : "Direkter Link",
-    "Federated Cloud Sharing" : "Federated-Cloud-Sharing",
-    "Open documentation" : "Dokumentation öffnen",
-    "Allow users on this server to send shares to other servers" : "Benutzern auf diesem Server das Senden von Freigaben an andere Server erlauben",
-    "Allow users on this server to receive shares from other servers" : "Benutzern auf diesem Server das Empfangen von Freigaben von anderen Servern erlauben",
-    "Federated Cloud" : "Federated Cloud",
-    "Your Federated Cloud ID:" : "Deine Federated-Cloud-ID:",
-    "Share it:" : "Zum Teilen:",
-    "Add to your website" : "Zu deiner Webseite hinzufügen",
-    "Share with me via ownCloud" : "Teile mit mir über ownCloud",
-    "HTML Code:" : "HTML-Code:"
+    "Direct link" : "Direkter Link"
 },
 "nplurals=2; plural=(n != 1);");
