@@ -11,7 +11,6 @@ OC.L10N.register(
     "Shared with you" : "Поделились с вами",
     "Shared with others" : "Доступные для других",
     "Shared by link" : "Доступные по ссылке",
-    "Federated sharing" : "Общий доступ из объединенного общего хранилища",
     "Nothing shared with you yet" : "С вами пока ничем не поделились",
     "Files and folders others share with you will show up here" : "Здесь появятся файлы и каталоги, которыми с вами поделятся",
     "Nothing shared yet" : "Пока ничего не опубликовано",
@@ -28,6 +27,25 @@ OC.L10N.register(
     "Invalid ownCloud url" : "Неверный адрес ownCloud",
     "Shared by" : "Поделился",
     "Sharing" : "Общий доступ",
+    "Share API is disabled" : "API общего доступа отключён",
+    "Wrong share ID, share doesn't exist" : "Неверный идентификатор публикации, публикация не существует",
+    "Could not delete share" : "Не удалось удалить публикацию",
+    "Please specify a file or folder path" : "Пожалуйста, укажите путь к файлу или каталогу",
+    "Wrong path, file/folder doesn't exist" : "Неверный путь, файл/каталог не существует",
+    "Please specify a valid user" : "Пожалуйста, укажите допустимого пользователя",
+    "Group sharing is disabled by the administrator" : "Общий доступ для групп отключён администратором",
+    "Please specify a valid group" : "Пожалуйста, укажите допустимую группу",
+    "Public link sharing is disabled by the administrator" : "Публикация через общие ссылки отключена администратором",
+    "Public upload disabled by the administrator" : "Загрузка в общедоступную публикацию запрещена администратором",
+    "Public upload is only possible for publicly shared folders" : "Общедоступная загрузка возможна только в папки с общим доступом",
+    "Invalid date, date format must be YYYY-MM-DD" : "Неверная дата, формат даты должен быть ГГГГ-ММ-ДД",
+    "Sharing %s failed because the back end does not allow shares from type %s" : "Не удалось поделиться %s, поскольку механизм удалённого обмена не разрешает публикации типа %s",
+    "Unknown share type" : "Предоставление доступа неизвестного типа",
+    "Not a directory" : "Это не каталог",
+    "Could not lock path" : "Не удалось заблокировать путь",
+    "Can't change permissions for public share links" : "Невозможно изменить права для публикации через ссылку",
+    "Wrong or no update parameter given" : "Параметр для изменения неправилен или не задан",
+    "Cannot increase permissions" : "Нельзя увеличить права",
     "A file or folder has been <strong>shared</strong>" : "<strong>Опубликован</strong> файл или каталог",
     "A file or folder was shared from <strong>another server</strong>" : "Файлом или каталогом поделились с <strong>удаленного сервера</strong>",
     "A public shared file or folder was <strong>downloaded</strong>" : "Общий файл или каталог был <strong>скачан</strong>",
@@ -71,11 +89,6 @@ OC.L10N.register(
     "Public link of %2$s expired" : "Срок действия публичной ссылки к %2$s закончился",
     "Shared by %2$s" : "Поделился %2$s",
     "Shares" : "События обмена файлами",
-    "You received \"/%2$s\" as a remote share from %1$s" : "Вы получили доступ к \"/%2$s\" от пользователя %1$s",
-    "Accept" : "Принять",
-    "Decline" : "Отклонить",
-    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Поделитесь со мной через мой #ownCloud ID в объединении облачных хранилищ, смотрите %s",
-    "Share with me through my #ownCloud Federated Cloud ID" : "Поделитесь со мной через мой #ownCloud ID в объединении облачных хранилищ",
     "This share is password-protected" : "Общий ресурс защищен паролем",
     "The password is wrong. Try again." : "Неверный пароль. Попробуйте еще раз.",
     "Password" : "Пароль",
@@ -91,16 +104,6 @@ OC.L10N.register(
     "Add to your ownCloud" : "Добавить в свой ownCloud",
     "Download" : "Скачать",
     "Download %s" : "Скачать %s",
-    "Direct link" : "Прямая ссылка",
-    "Federated Cloud Sharing" : "Объединение облачных хранилищ",
-    "Open documentation" : "Открыть документацию",
-    "Allow users on this server to send shares to other servers" : "Разрешить пользователям делиться с пользователями других серверов",
-    "Allow users on this server to receive shares from other servers" : "Разрешить пользователям использовать общие ресурсы с других серверов",
-    "Federated Cloud" : "Объединение облачных хранилищ",
-    "Your Federated Cloud ID:" : "Ваш ID в объединении облачных хранилищ:",
-    "Share it:" : "Поделись этим:",
-    "Add to your website" : "Добавить к себе на сайт",
-    "Share with me via ownCloud" : "Поделитесь мной через ownCloud",
-    "HTML Code:" : "HTML код:"
+    "Direct link" : "Прямая ссылка"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
