@@ -3,7 +3,10 @@ OC.L10N.register(
     {
     "Server to server sharing is not enabled on this server" : "Server-till-server-delning är inte aktiverat på denna server",
     "The mountpoint name contains invalid characters." : "Monteringspunktens namn innehåller ogiltiga tecken.",
+    "Not allowed to create a federated share with the same user server" : "Ej tillåten att skapa en federerad delning med samma användarserver.",
     "Invalid or untrusted SSL certificate" : "Ogiltigt eller ej betrott SSL-certifikat",
+    "Could not authenticate to remote share, password might be wrong" : "Kunde ej autensiera fjärrdelningen, lösenordet kan vara fel",
+    "Storage not valid" : "Lagring ej giltig",
     "Couldn't add remote share" : "Kunde inte lägga till fjärrutdelning",
     "Shared with you" : "Delat med dig",
     "Shared with others" : "Delat med andra",
@@ -19,12 +22,15 @@ OC.L10N.register(
     "Remote share password" : "Lösenord för fjärrdelning",
     "Cancel" : "Avbryt",
     "Add remote share" : "Lägg till fjärrdelning",
+    "You can upload into this folder" : "Du kan ladda upp i denna map",
+    "No ownCloud installation (7 or higher) found at {remote}" : "Ingen OwnCloud Installation (7 eller senare) funnen på {remote}",
     "Invalid ownCloud url" : "Felaktig ownCloud url",
     "Shared by" : "Delad av",
     "Sharing" : "Dela",
     "A file or folder has been <strong>shared</strong>" : "En fil eller mapp har <strong>delats</strong>",
     "A file or folder was shared from <strong>another server</strong>" : "En fil eller mapp delades från <strong>en annan server</strong>",
     "A public shared file or folder was <strong>downloaded</strong>" : "En publikt delad fil eller mapp blev <strong>nerladdad</strong>",
+    "You received a new remote share %2$s from %1$s" : "Du har mottagit en fjärrdelning %2$s från %1$s",
     "You received a new remote share from %s" : "Du mottog en ny fjärrdelning från %s",
     "%1$s accepted remote share %2$s" : "%1$s accepterade fjärrdelning %2$s",
     "%1$s declined remote share %2$s" : "%1$s nekade fjärrdelning %2$s",
@@ -32,11 +38,38 @@ OC.L10N.register(
     "Public shared folder %1$s was downloaded" : "Publikt delad mapp %1$s blev nerladdad",
     "Public shared file %1$s was downloaded" : "Publikt delad fil %1$s blev nerladdad",
     "You shared %1$s with %2$s" : "Du delade %1$s med %2$s",
+    "%2$s shared %1$s with %3$s" : "%2$s delade %1$s med %3$s",
+    "You removed the share of %2$s for %1$s" : "Du tog bort delning av %2$s för %1$s",
+    "%2$s removed the share of %3$s for %1$s" : "%2$s tog bort delningen av %3$s för %1$s",
     "You shared %1$s with group %2$s" : "Du delade %1$s med grupp %2$s",
+    "%2$s shared %1$s with group %3$s" : "%2$s delade %1$s med gruppen %3$s",
+    "You removed the share of group %2$s for %1$s" : "Du tog bort delningen av gruppen %2$s för %1$s",
+    "%2$s removed the share of group %3$s for %1$s" : "%2$s tog bort delningen av grupp %3$s för %1$s",
+    "%2$s shared %1$s via link" : "%2$s delade %1$s via länk",
     "You shared %1$s via link" : "Du delade %1$s via länk",
+    "You removed the public link for %1$s" : "Du tog bort den publika länken för %1$s",
+    "%2$s removed the public link for %1$s" : "%2$s tog bort den publika länken för %1$s",
+    "Your public link for %1$s expired" : "Din publika länk för %1$s har löpt ut",
+    "The public link of %2$s for %1$s expired" : "Den publika länken för %2$s av %1$s har löpt ut",
     "%2$s shared %1$s with you" : "%2$s delade %1$s med dig",
+    "%2$s removed the share for %1$s" : "%2$s tog bort delningen av %1$s",
+    "Downloaded via public link" : "Nerladdad via publik länk",
+    "Shared with %2$s" : "Delad med %2$s",
+    "Shared with %3$s by %2$s" : "Delad med %3$s av %2$s",
+    "Removed share for %2$s" : "Tog bort delningen för %2$s",
+    "%2$s removed share for %3$s" : "%2$s tog bort delningen för %3$s",
+    "Shared with group %2$s" : "Delning med grupp %2$s",
+    "Shared with group %3$s by %2$s" : "Delade med grupp %3$s av %2$s",
+    "Removed share of group %2$s" : "Tog bort delning av grupp %2$s",
+    "%2$s removed share of group %3$s" : "%2$s tog bort delningen av grupp %3$s",
+    "Shared via link by %2$s" : "Delad via länk av %2$s",
+    "Shared via public link" : "Delad via publik länk",
+    "Removed public link" : "Tog bort publik länk",
+    "%2$s removed public link" : "%2$s tog bort publik länk",
+    "Public link expired" : "Tidsgräns för publik länk har löpt ut",
+    "Public link of %2$s expired" : "Tidsgräns för publik länk för %2$s har löpt ut",
+    "Shared by %2$s" : "Delad av %2$s",
     "Shares" : "Delningar",
-    "Accept" : "Acceptera",
     "This share is password-protected" : "Den här delningen är lösenordsskyddad",
     "The password is wrong. Try again." : "Lösenordet är fel. Försök igen.",
     "Password" : "Lösenord",
@@ -52,8 +85,6 @@ OC.L10N.register(
     "Add to your ownCloud" : "Lägg till i din ownCloud",
     "Download" : "Ladda ner",
     "Download %s" : "Ladda ner %s",
-    "Direct link" : "Direkt länk",
-    "Allow users on this server to send shares to other servers" : "Tillåt användare på denna server att skicka utdelningar till andra servrar",
-    "Allow users on this server to receive shares from other servers" : "Tillåt användare på denna servern att ta emot utdelningar från andra servrar"
+    "Direct link" : "Direkt länk"
 },
 "nplurals=2; plural=(n != 1);");
