@@ -4,6 +4,8 @@ OC.L10N.register(
     "This file is too big to be opened. Please download the file instead." : "Ez a fájl túl nagy a megnyitáshoz. Kérjük, helyette töltsd le a fájlt.",
     "Cannot read the file." : "Nem olvasható a fájl!",
     "Invalid file path supplied." : "Helytelen elérési utat adott meg.",
+    "The file is locked." : "A fájl zárolva van.",
+    "An internal server error occurred." : "Belső szerverhiba történt.",
     "Cannot save file as it has been modified since opening" : "Nem tudom a fáljt menteni, mert időközben a tartalma megváltozott.",
     "Insufficient permissions" : "Nincs jogosultsága hozzá",
     "File path not supplied" : "Fálj elérést nem adta meg",
@@ -13,6 +15,8 @@ OC.L10N.register(
     "failed!" : "sikertelen!",
     "Saved" : "Elmentve",
     "There was a problem saving your changes. Click to resume editing." : "Hiba történt a módosítások mentésekor. Szerkesztés folytatásához kattints ide.",
-    "An error occurred!" : "Hiba történt!"
+    "An error occurred!" : "Hiba történt!",
+    "Text file" : "Szövegfájl",
+    "New text file.txt" : "Új szöveges fájl.txt"
 },
 "nplurals=2; plural=(n != 1);");
