@@ -5,15 +5,17 @@ OC.L10N.register(
     "Couldn't restore %s" : "Não foi possível restaurar %s",
     "Deleted files" : "Arquivos apagados",
     "Restore" : "Restaurar",
+    "Delete" : "Excluir",
     "Delete permanently" : "Excluir permanentemente",
     "Error" : "Erro",
+    "This operation is forbidden" : "Esta operação é proibida",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Este diretório não está disponível, por favor, verifique os logs ou entre em contato com o administrador",
     "restored" : "restaurado",
-    "No deleted files" : "Aquivos não removidos",
-    "You will be able to recover deleted files from here" : "Você pode recuperar arquivos removidos daqui",
+    "No deleted files" : "Nenhum arquivo excluído",
+    "You will be able to recover deleted files from here" : "Neste local, você será capaz de recuperar arquivos excluídos",
     "No entries found in this folder" : "Nenhuma entrada foi encontrada nesta pasta",
     "Select all" : "Selecionar tudo",
     "Name" : "Nome",
-    "Deleted" : "Excluído",
-    "Delete" : "Excluir"
+    "Deleted" : "Excluído"
 },
 "nplurals=2; plural=(n > 1);");
