@@ -12,9 +12,9 @@ OC.L10N.register(
     "This directory is unavailable, please check the logs or contact the administrator" : "Esta diretoria está indisponível, por favor, verifique os registos ou contacte o administrador",
     "restored" : "Restaurado",
     "No deleted files" : "Sem ficheiros eliminados",
-    "You will be able to recover deleted files from here" : "Poderá recuperar ficheiros apagados aqui",
+    "You will be able to recover deleted files from here" : "Poderá recuperar ficheiros eliminados a partir daqui",
     "No entries found in this folder" : "Não foram encontradas entradas nesta pasta",
-    "Select all" : "Seleccionar todos",
+    "Select all" : "Selecionar todos",
     "Name" : "Nome",
     "Deleted" : "Eliminado"
 },
