@@ -1,11 +1,12 @@
 <?php
 $TRANSLATIONS = array(
-"Welcome to %s" => "Bun venit la %s",
-"Your personal web services. All your files, contacts, calendar and more, in one place." => "Serviciile tale web personale. Toate fișierele, contactele, calendarele și multe altele într-un singur loc.",
+"A safe home for all your data" => "Un spațiu de stocare sigur pentru toate datele tale",
+"Access & share your files, calendars, contacts, mail & more from any device, on your terms" => "Accesează-ți și împărtășește-ți fișierele, calendarele, persoanele de contact, mesajele electronice și multe altele de pe orice dispozitiv, respectând termenii tăi",
 "Get the apps to sync your files" => "Obține aplicația pentru sincronizarea fișierelor",
-"Desktop client" => "Client Desktop",
-"Android app" => "Aplicatie Android",
+"Desktop client" => "Client desktop",
+"Android app" => "Aplicație Android",
 "iOS app" => "Aplicație iOS",
+"Connect your desktop apps to %s" => "Conectează-ți aplicațiile desktop la %s",
 "Connect your Calendar" => "Conectează-ți calendarul",
 "Connect your Contacts" => "Conectează-ți contactele",
 "Documentation" => "Documentație",
