@@ -15,7 +15,7 @@ $TRANSLATIONS = array(
 "Mail Templates" => "E-mail sablonok",
 "Theme" => "Téma",
 "Template" => "Sablon",
-"Please choose a template" => "Kérlek válassz egy sablont!",
+"Please choose a template" => "Kérjük válasszon egy sablont!",
 "Save" => "Mentés"
 );
 $PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
