@@ -2,11 +2,13 @@ OC.L10N.register(
     "updatenotification",
     {
     "{version} is available. Get more information on how to update." : "{version} är tillgänglig. Få mer information om hur du uppdaterar.",
+    "Updated channel" : "Uppdaterad kanal",
     "Updater" : "Uppdaterare",
-    "For security reasons the built-in ownCloud updater is using additional credentials. To visit the updater page please click the following button." : "Utav säkerhetsskäl använder den inbyggda ownCloud-uppdateraren ytterligare inlogginingsiformation. För att öppna sidan för uppdatering vänligen tryck på följande knapp.",
-    "Open updater" : "Öppna uppdateraren",
     "A new version is available: %s" : "En ny version är tillgänglig: %s",
+    "Open updater" : "Öppna uppdateraren",
+    "Your version is up to date." : "Din version är uppdaterad.",
     "Checked on %s" : "Senast kontrollerad %s",
-    "Updated channel" : "Uppdaterad kanal"
+    "Update channel:" : "Uppdateringskanal:",
+    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Du kan alltid uppdatera till en nyare version / experimentell kanal. Men du kan aldrig nedgradera till en mer stabil kanal."
 },
 "nplurals=2; plural=(n != 1);");
