@@ -305,6 +305,7 @@ describe('Core base tests', function() {
 				counter++;
 				xhr.respond(200, {'Content-Type': 'application/json'}, '{}');
 			});
+			$(document).off('ajaxComplete'); // ignore previously registered heartbeats
 		});
 		afterEach(function() {
 			clock.restore();
@@ -312,6 +313,7 @@ describe('Core base tests', function() {
 			window.oc_config = oldConfig;
 			routeStub.restore();
 			$(document).off('ajaxError');
+			$(document).off('ajaxComplete');
 		});
 		it('sends heartbeat half the session lifetime when heartbeat enabled', function() {
 			/* jshint camelcase: false */
@@ -340,7 +342,7 @@ describe('Core base tests', function() {
 			clock.tick(20 * 1000);
 			expect(counter).toEqual(2);
 		});
-		it('does no send heartbeat when heartbeat disabled', function() {
+		it('does not send heartbeat when heartbeat disabled', function() {
 			/* jshint camelcase: false */
 			window.oc_config = {
 				session_keepalive: false,
@@ -470,6 +472,7 @@ describe('Core base tests', function() {
 		var $navigation;
 
 		beforeEach(function() {
+			jQuery.fx.off = true;
 			clock = sinon.useFakeTimers();
 			$('#testArea').append('<div id="header">' +
 				'<a class="menutoggle header-appname-container" href="#">' +
@@ -482,6 +485,7 @@ describe('Core base tests', function() {
 			$navigation = $('#navigation');
 		});
 		afterEach(function() {
+			jQuery.fx.off = false;
 			clock.restore();
 			$(document).off('ajaxError');
 		});
@@ -491,7 +495,6 @@ describe('Core base tests', function() {
 		});
 		it('Clicking menu toggle toggles navigation in', function() {
 			window.initCore();
-			$navigation.hide(); // normally done through media query triggered CSS
 			expect($navigation.is(':visible')).toEqual(false);
 			$toggle.click();
 			clock.tick(1 * 1000);
@@ -935,10 +938,13 @@ describe('Core base tests', function() {
 	});
 	describe('global ajax errors', function() {
 		var reloadStub, ajaxErrorStub, clock;
+		var notificationStub;
+		var waitTimeMs = 6000;
 
 		beforeEach(function() {
 			clock = sinon.useFakeTimers();
 			reloadStub = sinon.stub(OC, 'reload');
+			notificationStub = sinon.stub(OC.Notification, 'show');
 			// unstub the error processing method
 			ajaxErrorStub = OC._processAjaxError;
 			ajaxErrorStub.restore();
@@ -946,6 +952,7 @@ describe('Core base tests', function() {
 		});
 		afterEach(function() {
 			reloadStub.restore();
+			notificationStub.restore();
 			clock.restore();
 		});
 
@@ -970,7 +977,7 @@ describe('Core base tests', function() {
 				$(document).trigger(new $.Event('ajaxError'), xhr);
 
 				// trigger timers
-				clock.tick(1000);
+				clock.tick(waitTimeMs);
 
 				if (expectedCall) {
 					expect(reloadStub.calledOnce).toEqual(true);
@@ -986,7 +993,7 @@ describe('Core base tests', function() {
 			$(document).trigger(new $.Event('ajaxError'), xhr);
 
 			// trigger timers
-			clock.tick(1000);
+			clock.tick(waitTimeMs);
 
 			expect(reloadStub.calledOnce).toEqual(true);
 		});
@@ -997,9 +1004,17 @@ describe('Core base tests', function() {
 
 			$(document).trigger(new $.Event('ajaxError'), xhr);
 
-			clock.tick(1000);
+			clock.tick(waitTimeMs);
 			expect(reloadStub.notCalled).toEqual(true);
 		});
+		it('displays notification', function() {
+			var xhr = { status: 401 };
+
+			$(document).trigger(new $.Event('ajaxError'), xhr);
+
+			clock.tick(waitTimeMs);
+			expect(notificationStub.calledOnce).toEqual(true);
+		});
 	});
 });
 
