@@ -1,11 +1,12 @@
 OC.L10N.register(
     "core",
     {
-    "Updated database" : "قاعدة بيانات المرفوعات",
     "No image or file provided" : "لم يتم توفير صورة أو ملف",
     "Unknown filetype" : "نوع الملف غير معروف",
     "Invalid image" : "الصورة غير صالحة",
     "%s password reset" : "تمت إعادة ضبط كلمة مرور %s",
+    "Error deleting tag(s)" : "خطأ أثناء حذف العلامة (العلامات)",
+    "Updated database" : "قاعدة بيانات المرفوعات",
     "Sunday" : "الأحد",
     "Monday" : "الأثنين",
     "Tuesday" : "الثلاثاء",
@@ -75,8 +76,6 @@ OC.L10N.register(
     "Expiration" : "إنتهاء",
     "Expiration date" : "تاريخ إنتهاء الصلاحية",
     "Choose a password for the public link" : "اختر كلمة مرور للرابط العام",
-    "Sending ..." : "جاري الارسال ...",
-    "Email sent" : "تم ارسال البريد الالكتروني",
     "Resharing is not allowed" : "لا يسمح بعملية إعادة المشاركة",
     "Share link" : "شارك الرابط",
     "Link" : "الرابط",
@@ -85,6 +84,8 @@ OC.L10N.register(
     "Allow editing" : "السماح بالتعديلات",
     "Email link to person" : "ارسل الرابط بالبريد الى صديق",
     "Send" : "أرسل",
+    "Sending ..." : "جاري الارسال ...",
+    "Email sent" : "تم ارسال البريد الالكتروني",
     "Shared with you and the group {group} by {owner}" : "شورك معك ومع المجموعة {group} من قبل {owner}",
     "Shared with you by {owner}" : "شورك معك من قبل {owner}",
     "group" : "مجموعة",
@@ -98,14 +99,13 @@ OC.L10N.register(
     "delete" : "حذف",
     "access control" : "ضبط الوصول",
     "Share" : "شارك",
-    "Share with users or groups …" : "شارِك مع مستخدمين أو مجموعات",
-    "Share with users, groups or remote users …" : "شارِك مع مستخدمين أو مجموعات أو مستخدمين عن بُعد",
     "Warning" : "تحذير",
     "Delete" : "إلغاء",
     "Rename" : "إعادة التسمية",
     "The object type is not specified." : "نوع العنصر غير محدد.",
     "Enter new" : "إدخال جديد",
     "Add" : "اضف",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "حصل خطأ في عملية التحديث, يرجى ارسال تقرير بهذه المشكلة الى <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>.",
     "The update was successful. Redirecting you to ownCloud now." : "تم التحديث بنجاح , يتم اعادة توجيهك الان الى Owncloud",
     "Personal" : "شخصي",
     "Users" : "المستخدمين",
@@ -114,7 +114,6 @@ OC.L10N.register(
     "Help" : "المساعدة",
     "Access forbidden" : "التوصّل محظور",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "مجلدات البيانات والملفات الخاصة قد تكون قابلة للوصول اليها عن طريق شبكة الانترنت وذلك بسبب ان ملف .htaccess  لا يعمل بشكل صحيح.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "لمزيد من المعلومات عن كيفية إعداد خادمك، يرجى الاطلاع على <a href=\"%s\" target=\"_blank\">صفحة المساعدة</a>.",
     "Create an <strong>admin account</strong>" : "أضف </strong>مستخدم رئيسي <strong>",
     "Username" : "إسم المستخدم",
     "Data folder" : "مجلد المعلومات",
@@ -131,7 +130,6 @@ OC.L10N.register(
     "Alternative Logins" : "اسماء دخول بديلة",
     "Use the following link to reset your password: {link}" : "استخدم هذه الوصلة لاسترجاع كلمة السر: {link}",
     "New password" : "كلمات سر جديدة",
-    "Reset password" : "تعديل كلمة السر",
-    "Password can not be changed. Please contact your administrator." : "كلمة المرور لا يمكن تغييرها. فضلاً تحدث مع المسؤول"
+    "Reset password" : "تعديل كلمة السر"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
