@@ -1,29 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Couldn't send mail to following users: %s ",
-    "Preparing update" : "Preparing update",
-    "Turned on maintenance mode" : "Turned on maintenance mode",
-    "Turned off maintenance mode" : "Turned off maintenance mode",
-    "Maintenance mode is kept active" : "Maintenance mode is kept active",
-    "Updating database schema" : "Updating database schema",
-    "Updated database" : "Updated database",
-    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Checking whether the database schema can be updated (this can take a long time depending on the database size)",
-    "Checked database schema update" : "Checked database schema update",
-    "Checking updates of apps" : "Checking updates of apps",
-    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)",
-    "Checked database schema update for apps" : "Checked database schema update for apps",
-    "Updated \"%s\" to %s" : "Updated \"%s\" to %s",
-    "Repair warning: " : "Repair warning: ",
-    "Repair error: " : "Repair error: ",
-    "Set log level to debug" : "Set log level to debug",
-    "Reset log level" : "Reset log level",
-    "Starting code integrity check" : "Starting code integrity check",
-    "Finished code integrity check" : "Finished code integrity check",
-    "%s (3rdparty)" : "%s (3rdparty)",
-    "%s (incompatible)" : "%s (incompatible)",
-    "Following apps have been disabled: %s" : "Following apps have been disabled: %s",
-    "Already up to date" : "Already up to date",
     "Please select a file." : "Please select a file.",
     "File is too big" : "File is too big",
     "Invalid file provided" : "Invalid file provided",
@@ -41,6 +18,39 @@ OC.L10N.register(
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Could not send reset email because there is no email address for this username. Please contact your administrator.",
     "%s password reset" : "%s password reset",
     "Couldn't send reset email. Please contact your administrator." : "Couldn't send reset email. Please contact your administrator.",
+    "Error loading tags" : "Error loading tags",
+    "Tag already exists" : "Tag already exists",
+    "Error deleting tag(s)" : "Error deleting tag(s)",
+    "Error tagging" : "Error tagging",
+    "Error untagging" : "Error untagging",
+    "Error favoriting" : "Error favouriting",
+    "Error unfavoriting" : "Error unfavouriting",
+    "Couldn't send mail to following users: %s " : "Couldn't send mail to following users: %s ",
+    "Preparing update" : "Preparing update",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair warning: " : "Repair warning: ",
+    "Repair error: " : "Repair error: ",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "Please use the command line updater because automatic updating is disabled in the config.php.",
+    "[%d / %d]: Checking table %s" : "[%d / %d]: Checking table %s",
+    "Turned on maintenance mode" : "Turned on maintenance mode",
+    "Turned off maintenance mode" : "Turned off maintenance mode",
+    "Maintenance mode is kept active" : "Maintenance mode is kept active",
+    "Updating database schema" : "Updating database schema",
+    "Updated database" : "Updated database",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Checking whether the database schema can be updated (this can take a long time depending on the database size)",
+    "Checked database schema update" : "Checked database schema update",
+    "Checking updates of apps" : "Checking updates of apps",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)",
+    "Checked database schema update for apps" : "Checked database schema update for apps",
+    "Updated \"%s\" to %s" : "Updated \"%s\" to %s",
+    "Set log level to debug" : "Set log level to debug",
+    "Reset log level" : "Reset log level",
+    "Starting code integrity check" : "Starting code integrity check",
+    "Finished code integrity check" : "Finished code integrity check",
+    "%s (3rdparty)" : "%s (3rdparty)",
+    "%s (incompatible)" : "%s (incompatible)",
+    "Following apps have been disabled: %s" : "Following apps have been disabled: %s",
+    "Already up to date" : "Already up to date",
     "Sunday" : "Sunday",
     "Monday" : "Monday",
     "Tuesday" : "Tuesday",
@@ -88,6 +98,7 @@ OC.L10N.register(
     "Dec." : "Dec.",
     "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>",
     "Settings" : "Settings",
+    "Problem loading page, reloading in 5 seconds" : "Problem loading page, reloading in 5 seconds",
     "Saving..." : "Saving...",
     "Dismiss" : "Dismiss",
     "seconds ago" : "seconds ago",
@@ -119,18 +130,18 @@ OC.L10N.register(
     "Good password" : "Good password",
     "Strong password" : "Strong password",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Your web server is not yet set up properly to allow file synchronisation because the WebDAV interface seems to be broken.",
-    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>.",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest enabling the Internet connection for this server.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>.",
-    "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP.",
-    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>.",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>.",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>.",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>.",
+    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it.",
+    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>.",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)",
     "Error occurred while checking server setup" : "Error occurred whilst checking server setup",
     "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting.",
-    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>.",
+    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>.",
     "Shared" : "Shared",
     "Shared with {recipients}" : "Shared with {recipients}",
@@ -143,8 +154,6 @@ OC.L10N.register(
     "Expiration" : "Expiration",
     "Expiration date" : "Expiration date",
     "Choose a password for the public link" : "Choose a password for the public link",
-    "Sending ..." : "Sending ...",
-    "Email sent" : "Email sent",
     "Resharing is not allowed" : "Resharing is not allowed",
     "Share link" : "Share link",
     "Link" : "Link",
@@ -153,6 +162,9 @@ OC.L10N.register(
     "Allow editing" : "Allow editing",
     "Email link to person" : "Email link to person",
     "Send" : "Send",
+    "Sending ..." : "Sending ...",
+    "Email sent" : "Email sent",
+    "Send link via email" : "Send link via email",
     "Shared with you and the group {group} by {owner}" : "Shared with you and the group {group} by {owner}",
     "Shared with you by {owner}" : "Shared with you by {owner}",
     "group" : "group",
@@ -168,19 +180,22 @@ OC.L10N.register(
     "Could not unshare" : "Could not unshare",
     "Share details could not be loaded for this item." : "Share details could not be loaded for this item.",
     "No users or groups found for {search}" : "No users or groups found for {search}",
-    "An error occured. Please try again" : "An error occured. Please try again",
+    "No users found for {search}" : "No users found for {search}",
+    "An error occurred. Please try again" : "An error occurred. Please try again",
     "{sharee} (group)" : "{sharee} (group)",
     "{sharee} (at {server})" : "{sharee} (at {server})",
     "{sharee} (remote)" : "{sharee} (remote)",
     "Share" : "Share",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Share with people on other ownClouds using the syntax username@example.com/owncloud",
-    "Share with users or groups …" : "Share with users or groups …",
-    "Share with users, groups or remote users …" : "Share with users, groups or remote users …",
+    "Share with users…" : "Share with users…",
+    "Share with users, groups or remote users…" : "Share with users, groups or remote users…",
+    "Share with users or groups…" : "Share with users or groups…",
+    "Share with users or remote users…" : "Share with users or remote users…",
     "Error removing share" : "Error removing share",
     "Warning" : "Warning",
     "Error while sending notification" : "Error whilst sending notification",
     "Non-existing tag #{tag}" : "Non-existing tag #{tag}",
-    "not assignable" : "not assignable",
+    "restricted" : "restricted",
     "invisible" : "invisible",
     "({scope})" : "({scope})",
     "Delete" : "Delete",
@@ -197,13 +212,14 @@ OC.L10N.register(
     "sunny" : "sunny",
     "Hello {name}, the weather is {weather}" : "Hello {name}, the weather is {weather}",
     "Hello {name}" : "Hello {name}",
+    "new" : "new",
     "_download %n file_::_download %n files_" : ["download %n file","download %n files"],
     "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "The upgrade is in progress, leaving this page might interrupt the process in some environments.",
-    "Updating {productName} to version {version}, this may take a while." : "Updating {productName} to version {version}, this may take a while.",
+    "Updating to {version}" : "Updating to {version}",
     "An error occurred." : "An error occurred.",
     "Please reload the page." : "Please reload the page.",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue.",
-    "The update was unsuccessful. " : "The update was unsuccessful. ",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>.",
     "The update was successful. There were warnings." : "The update was successful. There were warnings.",
     "The update was successful. Redirecting you to ownCloud now." : "The update was successful. Redirecting you to ownCloud now.",
     "Searching other places" : "Searching other places",
@@ -214,13 +230,6 @@ OC.L10N.register(
     "Apps" : "Apps",
     "Admin" : "Admin",
     "Help" : "Help",
-    "Error loading tags" : "Error loading tags",
-    "Tag already exists" : "Tag already exists",
-    "Error deleting tag(s)" : "Error deleting tag(s)",
-    "Error tagging" : "Error tagging",
-    "Error untagging" : "Error untagging",
-    "Error favoriting" : "Error favouriting",
-    "Error unfavoriting" : "Error unfavouriting",
     "Access forbidden" : "Access denied",
     "File not found" : "File not found",
     "The specified document has not been found on the server." : "The specified document has not been found on the server.",
@@ -243,7 +252,7 @@ OC.L10N.register(
     "Trace" : "Trace",
     "Security warning" : "Security warning",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Your data directory and files are probably accessible from the internet because the .htaccess file does not work.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">documentation</a>." : "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">documentation</a>.",
     "Create an <strong>admin account</strong>" : "Create an <strong>admin account</strong>",
     "Username" : "Username",
     "Storage & database" : "Storage & database",
@@ -271,8 +280,9 @@ OC.L10N.register(
     "Search" : "Search",
     "Server side authentication failed!" : "Server side authentication failed!",
     "Please contact your administrator." : "Please contact your administrator.",
-    "An internal error occured." : "An internal error occured.",
+    "An internal error occurred." : "An internal error occurred.",
     "Please try again or contact your administrator." : "Please try again or contact your administrator.",
+    "Username or email" : "Username or email",
     "Log in" : "Log in",
     "Wrong password. Reset it?" : "Wrong password. Reset it?",
     "Wrong password." : "Wrong password.",
@@ -286,6 +296,11 @@ OC.L10N.register(
     "This means only administrators can use the instance." : "This means only administrators can use the instance.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contact your system administrator if this message persists or appeared unexpectedly.",
     "Thank you for your patience." : "Thank you for your patience.",
+    "Two-step verification" : "Two-step verification",
+    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "Enhanced security has been enabled for your account. Please authenticate using a second factor.",
+    "Cancel login" : "Cancel login",
+    "Please authenticate using the selected factor." : "Please authenticate using the selected factor.",
+    "An error occured while verifying the token" : "An error occured while verifying the token",
     "You are accessing the server from an untrusted domain." : "You are accessing the server from an untrusted domain.",
     "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain.",
@@ -298,9 +313,11 @@ OC.L10N.register(
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Please make sure that the database, the config folder and the data folder have been backed up before proceeding.",
     "Start update" : "Start update",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:",
+    "Detailed logs" : "Detailed logs",
+    "Update needed" : "Update needed",
+    "Please use the command line updater because you have a big instance." : "Please use the command line updater because you have a big instance.",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "This %s instance is currently in maintenance mode, which may take a while.",
-    "This page will refresh itself when the %s instance is available again." : "This page will refresh itself when the %s instance is available again.",
-    "Error loading file picker template: {error}" : "Error loading file picker template: {error}",
-    "Password can not be changed. Please contact your administrator." : "Password can not be changed. Please contact your administrator."
+    "This page will refresh itself when the %s instance is available again." : "This page will refresh itself when the %s instance is available again."
 },
 "nplurals=2; plural=(n != 1);");
