@@ -1,32 +1,9 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "No se pudo enviar el mensaje a los siguientes usuarios: %s",
-    "Preparing update" : "Preparando la actualización",
-    "Turned on maintenance mode" : "Modo mantenimiento activado",
-    "Turned off maintenance mode" : "Modo mantenimiento desactivado",
-    "Maintenance mode is kept active" : "El modo mantenimiento aún está activo.",
-    "Updating database schema" : "Actualizando el esquema del base de datos",
-    "Updated database" : "Base de datos actualizada",
-    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Comprobar si se puede actualizar el esquema de la base de datos (esto puede tardar bastante tiempo, dependiendo del tamaño de la base de datos)",
-    "Checked database schema update" : "Actualización del esquema de base de datos revisado",
-    "Checking updates of apps" : "Comprobar actualizaciones de apps",
-    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Comprobar si se puede actualizar el esquema de la base de datos %s (esto puede tardar bastante tiempo, dependiendo del tamaño de la base de datos)",
-    "Checked database schema update for apps" : "Comprobada la actualización del esquema de la base de datos para aplicaciones",
-    "Updated \"%s\" to %s" : "Se ha actualizado \"%s\" a %s",
-    "Repair warning: " : "Advertencia de reparación:",
-    "Repair error: " : "Error que reparar:",
-    "Set log level to debug" : "Establecer el nivel de registro a depuración",
-    "Reset log level" : "Restablecer el nivel de registro",
-    "Starting code integrity check" : "Comenzando comprobación de integridad de código",
-    "Finished code integrity check" : "Terminando comprobación de integridad de código",
-    "%s (3rdparty)" : "%s (tercer parte)",
-    "%s (incompatible)" : "%s (incompatible)",
-    "Following apps have been disabled: %s" : "Siguiendo aplicaciones ha sido deshabilitado: %s",
-    "Already up to date" : "Ya actualizado",
     "Please select a file." : "Por favor, seleccione un archivo",
     "File is too big" : "El archivo es demasiado grande",
-    "Invalid file provided" : "Archivo inválido",
+    "Invalid file provided" : "Archivo no válido",
     "No image or file provided" : "No se especificó ningún archivo o imagen",
     "Unknown filetype" : "Tipo de archivo desconocido",
     "Invalid image" : "Imagen inválida",
@@ -41,6 +18,39 @@ OC.L10N.register(
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "No se pudo enviar el correo electrónico de restablecimiento porque no hay una dirección de correo electrónico para este nombre de usuario. Póngase en contacto con un administrador.",
     "%s password reset" : "%s restablecer contraseña",
     "Couldn't send reset email. Please contact your administrator." : "No pudo enviarse el correo para restablecer la contraseña. Por favor, contacte con su administrador.",
+    "Error loading tags" : "Error al cargar las etiquetas.",
+    "Tag already exists" : "La etiqueta ya existe",
+    "Error deleting tag(s)" : "Error al borrar etiqueta(s)",
+    "Error tagging" : "Error al etiquetar",
+    "Error untagging" : "Error al quitar etiqueta",
+    "Error favoriting" : "Error al marcar como favorito",
+    "Error unfavoriting" : "Error al quitar como favorito",
+    "Couldn't send mail to following users: %s " : "No se pudo enviar el mensaje a los siguientes usuarios: %s",
+    "Preparing update" : "Preparando la actualización",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair warning: " : "Advertencia de reparación:",
+    "Repair error: " : "Error que reparar:",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "Por favor utilice la actualización mediante la linea de comandos porque la actualización automática está desactivada en config.php.",
+    "[%d / %d]: Checking table %s" : "[%d / %d]: Comprobando cuadro %s",
+    "Turned on maintenance mode" : "Modo mantenimiento activado",
+    "Turned off maintenance mode" : "Modo mantenimiento desactivado",
+    "Maintenance mode is kept active" : "El modo mantenimiento aún está activo.",
+    "Updating database schema" : "Actualizando el esquema del base de datos",
+    "Updated database" : "Base de datos actualizada",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Comprobar si se puede actualizar el esquema de la base de datos (esto puede tardar bastante tiempo, dependiendo del tamaño de la base de datos)",
+    "Checked database schema update" : "Actualización del esquema de base de datos revisado",
+    "Checking updates of apps" : "Comprobar actualizaciones de apps",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Comprobar si se puede actualizar el esquema de la base de datos %s (esto puede tardar bastante tiempo, dependiendo del tamaño de la base de datos)",
+    "Checked database schema update for apps" : "Comprobada la actualización del esquema de la base de datos para aplicaciones",
+    "Updated \"%s\" to %s" : "Se ha actualizado \"%s\" a %s",
+    "Set log level to debug" : "Establecer el nivel de registro a depuración",
+    "Reset log level" : "Restablecer el nivel de registro",
+    "Starting code integrity check" : "Comenzando comprobación de integridad de código",
+    "Finished code integrity check" : "Terminando comprobación de integridad de código",
+    "%s (3rdparty)" : "%s (tercer parte)",
+    "%s (incompatible)" : "%s (incompatible)",
+    "Following apps have been disabled: %s" : "Siguiendo aplicaciones ha sido deshabilitado: %s",
+    "Already up to date" : "Ya actualizado",
     "Sunday" : "Domingo",
     "Monday" : "Lunes",
     "Tuesday" : "Martes",
@@ -51,10 +61,10 @@ OC.L10N.register(
     "Sun." : "Dom.",
     "Mon." : "Lun.",
     "Tue." : "Mar.",
-    "Wed." : "Mier.",
+    "Wed." : "Mié.",
     "Thu." : "Jue.",
     "Fri." : "Vie.",
-    "Sat." : "Sab.",
+    "Sat." : "Sáb.",
     "Su" : "Do",
     "Mo" : "Lu",
     "Tu" : "Ma",
@@ -88,6 +98,7 @@ OC.L10N.register(
     "Dec." : "Dic.",
     "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Ha habido problemas durante la comprobación de la integridad del código. Más información…</a>",
     "Settings" : "Ajustes",
+    "Problem loading page, reloading in 5 seconds" : "Problema al cargar la página, recargando en 5 segundos",
     "Saving..." : "Guardando...",
     "Dismiss" : "Descartar",
     "seconds ago" : "hace segundos",
@@ -119,18 +130,18 @@ OC.L10N.register(
     "Good password" : "Contraseña buena",
     "Strong password" : "Contraseña muy buena",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Su servidor web aún no está configurado adecuadamente para permitir sincronización de archivos ya que la interfaz WebDAV parece no estar funcionando.",
-    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Su servidor web no está configurado correctamente para resolver \"{url}\". Más información puede ser encontrada en nuestra <a target=\"_blank\" href=\"{docLink}\">documentación</a>.",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Su servidor no ha sido correctamente configurado para resolver \"{url}\". Puede encontrar más información en nuestra <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentación</a>.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Este servidor no tiene una conexión a Internet. Esto significa que algunas de las características como el montaje de almacenamiento externo, las notificaciones sobre actualizaciones o instalación de aplicaciones de terceros no funcionan. Podría no funcionar el acceso a los archivos de forma remota y el envío de correos electrónicos de notificación. Sugerimos habilitar la conexión a Internet de este servidor, si quiere tener todas las funciones.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "La memoria caché no ha sido configurada. Para aumentar su rendimiento por favor configure memcache si está disponible. Más información puede ser encontrada en nuestra <a target=\"_blank\" href=\"{docLink}\">documentación</a>.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "/dev/urandom no es legible por PHP el mismo es altamente desalentado por razones de seguridad. Más información puede ser encontrada en nuestra <a target=\"_blank\" href=\"{docLink}\">documentación</a>.",
-    "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "Su versión PHP ({version}) ya no es <a target=\"_blank\" href=\"{phpLink}\">respaldada por PHP</a>.  Recomendamos actualizar su versión de PHP para aprovechar las actualizaciones de rendimiento y seguridad proporcionadas por PHP.",
-    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "La configuración de las cabeceras inversas del proxy son incorrectas, o está accediendo a ownCloud desde un proxy confiable. Si no está accediendo a ownCloud desde un proxy certificado y confiable, este es un problema de seguridad y puede permitirle a un hacker camuflar su dirección IP a ownCloud. Más información puede ser encontrada en nuestra <a target=\"_blank\" href=\"{docLink}\">documentación</a>.",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "memcached es un sistema de cache distribuido. pero ha sido instalado por error el modulo PHP memcache.\nConsulte <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki acerca de ambos modulos</a>",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Algunos archivos no han superado la comprobación de integridad. Para más información sobre cómo resolver este inconveniente consulte nuestra <a target=\"_blank\" href=\"{docLink}\">documentación</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Lista de archivos inválidos…</a> / <a href=\"{rescanEndpoint}\">Reescanear…</a>)",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "La memoria caché no ha sido configurada. Para mejorar su desempeño, por favor, configure la memcache si está disponible. Puede encontrar más información en nuestra  <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "PHP no tiene acceso a /dev/urandom lo cual es desaconsejable por razones de seguridad. Puede encontrar más información en nuestra our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>.",
+    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Actualmente utiliza PHP {version}. Le aconsejamos que actualice su versión de PHP para beneficiarse de <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">mejoras de desempeño y seguridad que aporta PHP Group</a> en cuanto su distribución lo soporte.",
+    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "La configuración de las cabeceras inversas del proxy son incorrectas, o está accediendo a ownCloud desde un proxy confiable. Si no está accediendo a ownCloud desde un proxy certificado y confiable, este es un problema de seguridad y puede permitirle a un hacker camuflar su dirección IP a ownCloud. Más información puede ser encontrada en nuestra <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentación</a>.",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "memcached es un sistema de cache distribuido. pero ha sido instalado por error el modulo PHP memcache.\nConsulte  <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki acerca de ambos modulos</a>.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Algunos archivos no han superado la comprobación de integridad. Para más información sobre cómo resolver este inconveniente consulte nuestra documentación <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)",
     "Error occurred while checking server setup" : "Ha ocurrido un error al revisar la configuración del servidor",
     "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Su directorio de datos y sus archivos probablemente sean accesibles desde Internet. El archivo .htaccess no está funcionando. Le sugerimos encarecidamente que configure su servidor web de modo que el directorio de datos ya no sea accesible o que mueva el directorio de datos fuera de la raíz de documentos del servidor web.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "La \"{header}\" cabecera HTTP no está configurado para ser igual a \"{expected}\". Esto puede suponer un riesgo para la seguridad o la privacidad, por lo que se recomienda ajustar esta opción.",
-    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "La cabecera HTTP \"Strict-Transport-Security\" no está configurada en al menos \"{segundos}\" segundos. Para una mejor seguridad recomendamos que habilite HSTS como se describe en nuestros <a href=\"{docUrl}\">consejos de seguridad</a>.",
+    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "La cabecera HTTP \"Strict-Transport-Security\" no está configurada en al menos \"{segundos}\" segundos. Para una mejor seguridad recomendamos que habilite HSTS como se describe en <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Está ingresando a este sitio de internet vía HTTP. Le sugerimos enérgicamente que configure su servidor que utilice HTTPS como se describe en nuestros <a href=\"{docUrl}\">consejos de seguridad</a>.",
     "Shared" : "Compartido",
     "Shared with {recipients}" : "Compartido con {recipients}",
@@ -143,8 +154,6 @@ OC.L10N.register(
     "Expiration" : "Expira en:",
     "Expiration date" : "Fecha de caducidad",
     "Choose a password for the public link" : "Elija una contraseña para el enlace publico",
-    "Sending ..." : "Enviando...",
-    "Email sent" : "Correo electrónico enviado",
     "Resharing is not allowed" : "No se permite compartir de nuevo",
     "Share link" : "Enlace compartido",
     "Link" : "Enlace",
@@ -153,6 +162,9 @@ OC.L10N.register(
     "Allow editing" : "Permitir edición",
     "Email link to person" : "Enviar enlace por correo electrónico a una persona",
     "Send" : "Enviar",
+    "Sending ..." : "Enviando...",
+    "Email sent" : "Correo electrónico enviado",
+    "Send link via email" : "Enviar el link por email",
     "Shared with you and the group {group} by {owner}" : "Compartido contigo y el grupo {group} por {owner}",
     "Shared with you by {owner}" : "Compartido contigo por {owner}",
     "group" : "grupo",
@@ -168,19 +180,22 @@ OC.L10N.register(
     "Could not unshare" : "No se puede quitar el comparto",
     "Share details could not be loaded for this item." : "No se han podido cargar los detalles de compartición para este elemento.",
     "No users or groups found for {search}" : "No se han encontrado usuarios ni grupos para {search}",
-    "An error occured. Please try again" : "Un error ocurrió. Por favor reinténtelo nuevamente.",
+    "No users found for {search}" : "No se han encontrado usuarios para {search}",
+    "An error occurred. Please try again" : "Ha ocurrido un error. Por favor inténtelo de nuevo",
     "{sharee} (group)" : "{sharee} (grupo)",
     "{sharee} (at {server})" : "{sharee} (en {server})",
     "{sharee} (remote)" : "{sharee} (remoto)",
     "Share" : "Compartir",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Comparta con personas en otros ownClouds utilizando la sintáxis username@example.com/owncloud",
-    "Share with users or groups …" : "Compartir con usuarios o grupos ...",
-    "Share with users, groups or remote users …" : "Comparte con usuarios, grupos o usuarios remotos...",
+    "Share with users…" : "Compartir con usuarios...",
+    "Share with users, groups or remote users…" : "Compartir con usuarios, grupos o usuarios remotos...",
+    "Share with users or groups…" : "Compartir con usuarios o grupos...",
+    "Share with users or remote users…" : "Compartir con usuarios o usuarios remotos...",
     "Error removing share" : "Error quitando el comparto",
     "Warning" : "Precaución",
     "Error while sending notification" : "Error mientras se enviaba la notificación",
     "Non-existing tag #{tag}" : "Categoría #{tag} no existente",
-    "not assignable" : "no asignable",
+    "restricted" : "Restringido",
     "invisible" : "invisible",
     "({scope})" : "({scope})",
     "Delete" : "Eliminar",
@@ -197,13 +212,14 @@ OC.L10N.register(
     "sunny" : "soleado",
     "Hello {name}, the weather is {weather}" : "Hola {name}, el día es {weather}",
     "Hello {name}" : "Hola {name}",
+    "new" : "Nuevo",
     "_download %n file_::_download %n files_" : ["descargar %n ficheros","descargar %n archivos"],
     "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "La actualización está en curso, salir de esta página podrían interrumpir el proceso en algunos entornos.",
-    "Updating {productName} to version {version}, this may take a while." : "Actualizando {productName} a la versión {version}. Esto puede tardar un poco.",
+    "Updating to {version}" : "Actualizando a {version}",
     "An error occurred." : "Ocurrió un error.",
     "Please reload the page." : "Recargue/Actualice la página",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La actualización tuvo un problema. Para más información <a href=\"{url}\">consulta nuestro artículo del foro</a> para arreglar este problema.",
-    "The update was unsuccessful. " : "La actualización ha fallado.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "La actualización ha fracasado. Por favor, informe de este problema a la <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">Comunidad de ownCloud</a>.",
     "The update was successful. There were warnings." : "La actualización fue exitosa. Había advertencias.",
     "The update was successful. Redirecting you to ownCloud now." : "La actualización se ha realizado con éxito. Redireccionando a ownCloud ahora.",
     "Searching other places" : "Buscando en otros lugares",
@@ -214,13 +230,6 @@ OC.L10N.register(
     "Apps" : "Aplicaciones",
     "Admin" : "Administración",
     "Help" : "Ayuda",
-    "Error loading tags" : "Error al cargar las etiquetas.",
-    "Tag already exists" : "La etiqueta ya existe",
-    "Error deleting tag(s)" : "Error al borrar etiqueta(s)",
-    "Error tagging" : "Error al etiquetar",
-    "Error untagging" : "Error al quitar etiqueta",
-    "Error favoriting" : "Error al marcar como favorito",
-    "Error unfavoriting" : "Error al quitar como favorito",
     "Access forbidden" : "Acceso denegado",
     "File not found" : "Archivo no encontrado",
     "The specified document has not been found on the server." : "El documento indicado no se ha encontrado en el servidor.",
@@ -243,7 +252,7 @@ OC.L10N.register(
     "Trace" : "Trazas",
     "Security warning" : "Advertencia de seguridad",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Su directorio de datos y sus archivos probablemente sean accesibles a través de internet ya que el archivo .htaccess no funciona.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Para información de cómo configurar apropiadamente su servidor, por favor vea la <a href=\"%s\" target=\"_blank\">documentación</a>.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">documentation</a>." : "Para información de como configurar adecuadamente el servidor, por favor revise  <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">la documentación</a>.",
     "Create an <strong>admin account</strong>" : "Crear una <strong>cuenta de administrador</strong>",
     "Username" : "Nombre de usuario",
     "Storage & database" : "Almacenamiento y base de datos",
@@ -271,9 +280,10 @@ OC.L10N.register(
     "Search" : "Buscar",
     "Server side authentication failed!" : "La autenticación a fallado en el servidor.",
     "Please contact your administrator." : "Por favor, contacte con el administrador.",
-    "An internal error occured." : "Un error interno ocurrió.",
+    "An internal error occurred." : "Ha habido un error interno.",
     "Please try again or contact your administrator." : "Por favor reintente nuevamente o contáctese con su administrador.",
-    "Log in" : "Ingresar",
+    "Username or email" : "Nombre de usuario o email",
+    "Log in" : "Iniciar sesión",
     "Wrong password. Reset it?" : "Contraseña incorrecta. ¿Restablecerla?",
     "Wrong password." : "Contraseña incorrecta.",
     "Stay logged in" : "Permanecer autenticado",
@@ -286,10 +296,15 @@ OC.L10N.register(
     "This means only administrators can use the instance." : "Esto quiere decir que solo un administrador puede usarla.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte con su administrador de sistemas si este mensaje persiste o aparece de forma inesperada.",
     "Thank you for your patience." : "Gracias por su paciencia.",
+    "Two-step verification" : "Verificación en dos pasos",
+    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "La seguridad mejorada se ha habilitado para tu cuenta. Por favor, autenticar utilizando un segundo factor.",
+    "Cancel login" : "Cancelar inicio de sesión",
+    "Please authenticate using the selected factor." : "Por favor, autenticar utilizando el factor seleccionado.",
+    "An error occured while verifying the token" : "Ocurrió un error mientras se verificaba el \"token\".",
     "You are accessing the server from an untrusted domain." : "Está accediendo al servidor desde un dominio inseguro.",
     "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Contacte con su administrador. Si usted es el administrador, configure \"trusted_domains\" en config/config.php. En config/config.sample.php se encuentra un ejemplo para la configuración.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Dependiendo de su configuración, como administrador, debería poder usar el botón de abajo para confiar en este dominio.",
-    "Add \"%s\" as trusted domain" : "Agregar \"%s\" como dominio de confianza",
+    "Add \"%s\" as trusted domain" : "Añadir \"%s\" como dominio de confianza",
     "App update required" : "Es necesaria una actualización en la aplicación",
     "%s will be updated to version %s" : "%s será actualizada a la versión %s",
     "These apps will be updated:" : "Estas aplicaciones serán actualizadas:",
@@ -298,9 +313,11 @@ OC.L10N.register(
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Antes de proceder, asegúrese de que se haya hecho un respaldo de la base de datos, la carpeta de configuración y la carpeta de datos.",
     "Start update" : "Iniciar actualización",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar tiempos de espera en grandes instalaciones, en su lugar puede ejecutar el siguiente comando desde el directorio de instalación:",
+    "Detailed logs" : "Registros detallados",
+    "Update needed" : "Se necesita actualización",
+    "Please use the command line updater because you have a big instance." : "Por favor utilice la actualización mediante la linea de comandos porque tiene pendiente una gran actualización.",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Para ayuda, mirar  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\"> la documentación</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Está instancia %s está en modo mantenimiento, por lo que puede llevar un tiempo.",
-    "This page will refresh itself when the %s instance is available again." : "La página se refrescará cuando la instalación %s vuelva a estar disponible.",
-    "Repair error: " : "Error que reparar:",
-    "Password can not be changed. Please contact your administrator." : "La contraseña no se puede cambiar. Por favor, contacte a su administrador."
+    "This page will refresh itself when the %s instance is available again." : "La página se refrescará cuando la instalación %s vuelva a estar disponible."
 },
 "nplurals=2; plural=(n != 1);");
