@@ -1,16 +1,23 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "No se pudo enviar el mensaje a los siguientes usuarios: %s",
-    "Turned on maintenance mode" : "Modo mantenimiento activado",
-    "Turned off maintenance mode" : "Modo mantenimiento desactivado",
-    "Updated database" : "Base de datos actualizada",
     "No image or file provided" : "No se especificó ningún archivo o imagen",
     "Unknown filetype" : "Tipo de archivo desconocido",
     "Invalid image" : "Imagen inválida",
     "No temporary profile picture available, try again" : "No hay disponible una imagen temporal de perfil, pruebe de nuevo",
     "No crop data provided" : "No se proporcionó datos del recorte",
     "%s password reset" : "%s restablecer contraseña",
+    "Error loading tags" : "Error cargando etiquetas.",
+    "Tag already exists" : "La etiqueta ya existe",
+    "Error deleting tag(s)" : "Error borrando etiqueta(s)",
+    "Error tagging" : "Error al etiquetar",
+    "Error untagging" : "Error al quitar etiqueta",
+    "Error favoriting" : "Error al marcar como favorito",
+    "Error unfavoriting" : "Error al quitar como favorito",
+    "Couldn't send mail to following users: %s " : "No se pudo enviar el mensaje a los siguientes usuarios: %s",
+    "Turned on maintenance mode" : "Modo mantenimiento activado",
+    "Turned off maintenance mode" : "Modo mantenimiento desactivado",
+    "Updated database" : "Base de datos actualizada",
     "Sunday" : "Domingo",
     "Monday" : "Lunes",
     "Tuesday" : "Martes",
@@ -75,14 +82,14 @@ OC.L10N.register(
     "Set expiration date" : "Establecer fecha de caducidad",
     "Expiration" : "Caducidad",
     "Expiration date" : "Fecha de caducidad",
-    "Sending ..." : "Enviando...",
-    "Email sent" : "Correo electrónico enviado",
     "Resharing is not allowed" : "No se permite compartir de nuevo",
     "Share link" : "Enlace compartido",
     "Password protect" : "Protección con contraseña",
     "Password" : "Contraseña",
     "Email link to person" : "Enviar enlace por correo electrónico a una persona",
     "Send" : "Enviar",
+    "Sending ..." : "Enviando...",
+    "Email sent" : "Correo electrónico enviado",
     "Shared with you and the group {group} by {owner}" : "Compartido contigo y el grupo {group} por {owner}",
     "Shared with you by {owner}" : "Compartido contigo por {owner}",
     "group" : "grupo",
@@ -104,25 +111,18 @@ OC.L10N.register(
     "Error loading dialog template: {error}" : "Error cargando plantilla de diálogo: {error}",
     "No tags selected for deletion." : "No hay etiquetas seleccionadas para borrar.",
     "Please reload the page." : "Vuelva a cargar la página.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "La actualización ha fracasado. Por favor, informe de este problema a la <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">Comunidad de ownCloud</a>.",
     "The update was successful. Redirecting you to ownCloud now." : "La actualización se ha realizado con éxito. Redireccionando a ownCloud ahora.",
     "Personal" : "Personal",
     "Users" : "Usuarios",
     "Apps" : "Aplicaciones",
     "Admin" : "Administración",
     "Help" : "Ayuda",
-    "Error loading tags" : "Error cargando etiquetas.",
-    "Tag already exists" : "La etiqueta ya existe",
-    "Error deleting tag(s)" : "Error borrando etiqueta(s)",
-    "Error tagging" : "Error al etiquetar",
-    "Error untagging" : "Error al quitar etiqueta",
-    "Error favoriting" : "Error al marcar como favorito",
-    "Error unfavoriting" : "Error al quitar como favorito",
     "Access forbidden" : "Acceso denegado",
     "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Hola:\n\nTan solo queremos informarte que %s compartió %s contigo.\nMíralo aquí: %s\n\n",
     "The share will expire on %s." : "El objeto dejará de ser compartido el %s.",
     "Cheers!" : "¡Saludos!",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Su directorio de datos y sus archivos probablemente sean accesibles a través de internet ya que el archivo .htaccess no funciona.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Para información de cómo configurar apropiadamente su servidor, por favor vea la <a href=\"%s\" target=\"_blank\">documentación</a>.",
     "Create an <strong>admin account</strong>" : "Crear una <strong>cuenta de administrador</strong>",
     "Username" : "Nombre de usuario",
     "Data folder" : "Directorio de datos",
@@ -146,8 +146,6 @@ OC.L10N.register(
     "This ownCloud instance is currently in single user mode." : "Esta instalación de ownCloud se encuentra en modo de usuario único.",
     "This means only administrators can use the instance." : "Esto quiere decir que solo un administrador puede usarla.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte con su administrador de sistemas si este mensaje persiste o aparece de forma inesperada.",
-    "Thank you for your patience." : "Gracias por su paciencia.",
-    "Error loading file picker template: {error}" : "Error cargando plantilla del seleccionador de archivos: {error}",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Su directorio de datos y sus archivos probablemente sean accesibles a través de internet ya que el archivo .htaccess no funciona."
+    "Thank you for your patience." : "Gracias por su paciencia."
 },
 "nplurals=2; plural=(n != 1);");
