@@ -1,21 +1,7 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Kirja saatmine järgnevatele kasutajatele ebaõnnestus: %s ",
-    "Preparing update" : "Uuendamise ettevalmistamine",
-    "Turned on maintenance mode" : "Haldusrežiimis sisse lülitatud",
-    "Turned off maintenance mode" : "Haldusrežiimis välja lülitatud",
-    "Maintenance mode is kept active" : "Hooldusrežiim on aktiivne",
-    "Updated database" : "Uuendatud andmebaas",
-    "Checked database schema update" : "Andmebaasi skeemi uuendus kontrollitud",
-    "Checked database schema update for apps" : "Andmebaasi skeemi uuendus rakendustele on kontrollitud",
-    "Updated \"%s\" to %s" : "Uuendatud \"%s\" -> %s",
-    "Repair warning: " : "Paranda hoiatus:",
-    "Repair error: " : "Paranda viga:",
-    "%s (3rdparty)" : "%s (3nda osapoole arendaja)",
-    "%s (incompatible)" : "%s (pole ühilduv)",
-    "Following apps have been disabled: %s" : "Järgnevad rakendused on välja lülitatud: %s",
-    "Already up to date" : "On juba ajakohane",
+    "Please select a file." : "Palun vali fail.",
     "File is too big" : "Fail on liiga suur",
     "Invalid file provided" : "Vigane fail",
     "No image or file provided" : "Ühtegi pilti või faili pole pakutud",
@@ -29,6 +15,30 @@ OC.L10N.register(
     "Couldn't send reset email. Please make sure your username is correct." : "Ei suutnud lähtestada e-maili. Palun veendu, et kasutajatunnus on õige.",
     "%s password reset" : "%s parooli lähtestus",
     "Couldn't send reset email. Please contact your administrator." : "Ei suutnud lähtestada e-maili. Palun kontakteeru süsteemihalduriga.",
+    "Error loading tags" : "Viga siltide laadimisel",
+    "Tag already exists" : "Silt on juba olemas",
+    "Error deleting tag(s)" : "Viga sildi (siltide) kustutamisel",
+    "Error tagging" : "Viga sildi lisamisel",
+    "Error untagging" : "Viga sildi eemaldamisel",
+    "Error favoriting" : "Viga lemmikuks lisamisel",
+    "Error unfavoriting" : "Viga lemmikutest eemaldamisel",
+    "Couldn't send mail to following users: %s " : "Kirja saatmine järgnevatele kasutajatele ebaõnnestus: %s ",
+    "Preparing update" : "Uuendamise ettevalmistamine",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair warning: " : "Paranda hoiatus:",
+    "Repair error: " : "Paranda viga:",
+    "Turned on maintenance mode" : "Haldusrežiimis sisse lülitatud",
+    "Turned off maintenance mode" : "Haldusrežiimis välja lülitatud",
+    "Maintenance mode is kept active" : "Hooldusrežiim on aktiivne",
+    "Updating database schema" : "Andmebaasi skeemi uuendamine",
+    "Updated database" : "Uuendatud andmebaas",
+    "Checked database schema update" : "Andmebaasi skeemi uuendus kontrollitud",
+    "Checked database schema update for apps" : "Andmebaasi skeemi uuendus rakendustele on kontrollitud",
+    "Updated \"%s\" to %s" : "Uuendatud \"%s\" -> %s",
+    "%s (3rdparty)" : "%s (3nda osapoole arendaja)",
+    "%s (incompatible)" : "%s (pole ühilduv)",
+    "Following apps have been disabled: %s" : "Järgnevad rakendused on välja lülitatud: %s",
+    "Already up to date" : "On juba ajakohane",
     "Sunday" : "Pühapäev",
     "Monday" : "Esmaspäev",
     "Tuesday" : "Teisipäev",
@@ -118,8 +128,6 @@ OC.L10N.register(
     "Expiration" : "Aegumine",
     "Expiration date" : "Aegumise kuupäev",
     "Choose a password for the public link" : "Vali avaliku lingi jaoks parool",
-    "Sending ..." : "Saatmine ...",
-    "Email sent" : "E-kiri on saadetud",
     "Resharing is not allowed" : "Edasijagamine pole lubatud",
     "Share link" : "Jaga linki",
     "Link" : "Link",
@@ -128,6 +136,8 @@ OC.L10N.register(
     "Allow editing" : "Luba muutmine",
     "Email link to person" : "Saada link isikule e-postiga",
     "Send" : "Saada",
+    "Sending ..." : "Saatmine ...",
+    "Email sent" : "E-kiri on saadetud",
     "Shared with you and the group {group} by {owner}" : "Jagatud sinu ja {group} grupiga {owner} poolt",
     "Shared with you by {owner}" : "Sinuga jagas {owner}",
     "group" : "grupp",
@@ -140,13 +150,12 @@ OC.L10N.register(
     "delete" : "kustuta",
     "access control" : "ligipääsukontroll",
     "Could not unshare" : "Jagamise lõpetamine ebaõnnestus",
-    "An error occured. Please try again" : "Tekkis tõrge. Palun proovi uuesti",
+    "{sharee} (group)" : "{sharee} (group)",
+    "{sharee} (at {server})" : "{sharee} (serveris {server})",
+    "{sharee} (remote)" : "{sharee} (mujal serveris)",
     "Share" : "Jaga",
-    "Share with users or groups …" : "Jaga kasutajate või gruppidega ...",
-    "Share with users, groups or remote users …" : "Jaga kasutajate, gruppide või eemal olevate kasutajatega ...",
     "Warning" : "Hoiatus",
     "Error while sending notification" : "Tõrge teavituse saatmisel",
-    "not assignable" : "pole määratav",
     "invisible" : "nähtamatu",
     "({scope})" : "({scope})",
     "Delete" : "Kustuta",
@@ -162,11 +171,13 @@ OC.L10N.register(
     "sunny" : "päikeseline",
     "Hello {name}, the weather is {weather}" : "Tere {name}, ilm on {weather}",
     "Hello {name}" : "Tere, {name}",
+    "new" : "uus",
     "_download %n file_::_download %n files_" : ["laadi alla %n fail","laadi alla %n faili"],
-    "Updating {productName} to version {version}, this may take a while." : "Uuendan {productName} versioonile {version}, see võtab veidi aega.",
+    "Updating to {version}" : "Uuendamine versioonile {version}",
     "An error occurred." : "Tekkis tõrge.",
     "Please reload the page." : "Palun laadi see uuesti.",
-    "The update was unsuccessful. " : "Uuendamine ebaõnnestus.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Uuendus ebaõnnestus. Palun teavita probleemidest  <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud kogukonda</a>.",
+    "The update was successful. There were warnings." : "Uuendamine läks kenasti. hoiatusi polnud.",
     "The update was successful. Redirecting you to ownCloud now." : "Uuendus oli edukas. Kohe suunatakse Sind ownCloudi.",
     "Searching other places" : "Otsi teistest kohtadest",
     "Personal" : "Isiklik",
@@ -174,13 +185,6 @@ OC.L10N.register(
     "Apps" : "Rakendused",
     "Admin" : "Admin",
     "Help" : "Abiinfo",
-    "Error loading tags" : "Viga siltide laadimisel",
-    "Tag already exists" : "Silt on juba olemas",
-    "Error deleting tag(s)" : "Viga sildi (siltide) kustutamisel",
-    "Error tagging" : "Viga sildi lisamisel",
-    "Error untagging" : "Viga sildi eemaldamisel",
-    "Error favoriting" : "Viga lemmikuks lisamisel",
-    "Error unfavoriting" : "Viga lemmikutest eemaldamisel",
     "Access forbidden" : "Ligipääs on keelatud",
     "File not found" : "Faili ei leitud",
     "The specified document has not been found on the server." : "Määratud dokumenti serverist ei leitud.",
@@ -203,7 +207,6 @@ OC.L10N.register(
     "Trace" : "Jälita",
     "Security warning" : "Turvahoiatus",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Su andmete kataloog ja failid on tõenäoliselt internetist vabalt saadaval kuna .htaccess fail ei toimi.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Serveri korrektseks seadistuseks palun tutvu <a href=\"%s\" target=\"_blank\">dokumentatsiooniga</a>.",
     "Create an <strong>admin account</strong>" : "Loo <strong>admini konto</strong>",
     "Username" : "Kasutajanimi",
     "Storage & database" : "Andmehoidla ja andmebaas",
@@ -228,7 +231,6 @@ OC.L10N.register(
     "Search" : "Otsi",
     "Server side authentication failed!" : "Serveripoolne autentimine ebaõnnestus!",
     "Please contact your administrator." : "Palun kontakteeru oma süsteemihalduriga.",
-    "An internal error occured." : "Tekkis sisemine tõrge.",
     "Please try again or contact your administrator." : "Palun proovi uuesti või võta ühendust oma administraatoriga.",
     "Log in" : "Logi sisse",
     "Wrong password. Reset it?" : "Vale parool. Kas vajad parooli taastamist?",
@@ -253,9 +255,6 @@ OC.L10N.register(
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Enne jätkamist veendu, et andmebaas, seadete ning andmete kataloog on varundatud.",
     "Start update" : "Käivita uuendus",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Suurtel saitidel aegumise vältimiseks võid sa paigalduskaustas käivitada järgmise käsu:",
-    "This page will refresh itself when the %s instance is available again." : "Se leht laetakse uuesti, kui %s instantsi on uuesti saadaval.",
-    "Error loading file picker template: {error}" : "Viga failivalija malli laadimisel:  {error}",
-    "Password can not be changed. Please contact your administrator." : "Parooli ei saa muuta. Palun kontakteeru oma süsteemihalduriga.",
-    "Share with users, groups or remote users …" : "Jaga kasutajate, gruppide või eemal olevate kasutajatega ..."
+    "This page will refresh itself when the %s instance is available again." : "Se leht laetakse uuesti, kui %s instantsi on uuesti saadaval."
 },
 "nplurals=2; plural=(n != 1);");
