@@ -1,13 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Ezin izan da posta bidali hurrengo erabiltzaileei: %s",
-    "Turned on maintenance mode" : "Mantenu modua gaitu da",
-    "Turned off maintenance mode" : "Mantenu modua desgaitu da",
-    "Updated database" : "Datu basea eguneratu da",
-    "Checked database schema update" : "Egiaztatuta datu-basearen zerbitzariaren eguneraketa",
-    "Checked database schema update for apps" : "Egiaztatuta aplikazioen datu-basearen zerbitzariaren eguneraketa",
-    "Updated \"%s\" to %s" : "\"%s\" %s-ra eguneratua",
     "No image or file provided" : "Ez da irudi edo fitxategirik zehaztu",
     "Unknown filetype" : "Fitxategi mota ezezaguna",
     "Invalid image" : "Baliogabeko irudia",
@@ -17,6 +10,20 @@ OC.L10N.register(
     "Couldn't send reset email. Please make sure your username is correct." : "Ezin izan da berrezartzeko eposta bidali. Ziurtatu zure erabiltzaile izena egokia dela.",
     "%s password reset" : "%s pasahitza berrezarri",
     "Couldn't send reset email. Please contact your administrator." : "Ezin da berrezartzeko eposta bidali. Mesedez jarri harremetan zure administradorearekin.",
+    "Error loading tags" : "Errore bat izan da etiketak kargatzearkoan.",
+    "Tag already exists" : "Etiketa dagoeneko existitzen da",
+    "Error deleting tag(s)" : "Errore bat izan da etiketa(k) ezabatzerakoan",
+    "Error tagging" : "Errorea etiketa ezartzerakoan",
+    "Error untagging" : "Errorea etiketa kentzerakoan",
+    "Error favoriting" : "Errorea gogokoetara gehitzerakoan",
+    "Error unfavoriting" : "Errorea gogokoetatik kentzerakoan",
+    "Couldn't send mail to following users: %s " : "Ezin izan da posta bidali hurrengo erabiltzaileei: %s",
+    "Turned on maintenance mode" : "Mantenu modua gaitu da",
+    "Turned off maintenance mode" : "Mantenu modua desgaitu da",
+    "Updated database" : "Datu basea eguneratu da",
+    "Checked database schema update" : "Egiaztatuta datu-basearen zerbitzariaren eguneraketa",
+    "Checked database schema update for apps" : "Egiaztatuta aplikazioen datu-basearen zerbitzariaren eguneraketa",
+    "Updated \"%s\" to %s" : "\"%s\" %s-ra eguneratua",
     "Sunday" : "Igandea",
     "Monday" : "Astelehena",
     "Tuesday" : "Asteartea",
@@ -99,8 +106,6 @@ OC.L10N.register(
     "Expiration" : "Iraungitzea",
     "Expiration date" : "Muga data",
     "Choose a password for the public link" : "Aukeratu pasahitz bat esteka publikorako",
-    "Sending ..." : "Bidaltzen ...",
-    "Email sent" : "Eposta bidalia",
     "Resharing is not allowed" : "Berriz elkarbanatzea ez dago baimendua",
     "Share link" : "Elkarbanatu lotura",
     "Link" : "Esteka",
@@ -109,6 +114,8 @@ OC.L10N.register(
     "Allow editing" : "Baimendu editatzea",
     "Email link to person" : "Postaz bidali lotura ",
     "Send" : "Bidali",
+    "Sending ..." : "Bidaltzen ...",
+    "Email sent" : "Eposta bidalia",
     "Shared with you and the group {group} by {owner}" : "{owner}-k zu eta {group} taldearekin elkarbanatuta",
     "Shared with you by {owner}" : "{owner}-k zurekin elkarbanatuta",
     "group" : "taldea",
@@ -137,10 +144,9 @@ OC.L10N.register(
     "Hello {name}, the weather is {weather}" : "Kaixo {name}, eguraldia {weather} da",
     "Hello {name}" : "Kaixo {name}",
     "_download %n file_::_download %n files_" : ["%n fitxategia jaitsi","jaitsi %n fitxategiak"],
-    "Updating {productName} to version {version}, this may take a while." : "Eguneratu  {productName} {version} bertsiora, bere denbora behar du.",
     "An error occurred." : "Errore bat gertatu da.",
     "Please reload the page." : "Mesedez birkargatu orria.",
-    "The update was unsuccessful. " : "Eguneraketa ongi burutu da.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Eguneraketa ez da ongi egin. Mesedez egin arazoaren txosten bat <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud komunitatearentzako</a>.",
     "The update was successful. Redirecting you to ownCloud now." : "Eguneraketa ongi egin da. Orain zure ownClouderea berbideratua izango zara.",
     "Searching other places" : "Beste lekuak bilatzen",
     "No search results in other folders" : "Ez da bilaketaren emaitzik lortu beste karpetatan",
@@ -149,13 +155,6 @@ OC.L10N.register(
     "Apps" : "Aplikazioak",
     "Admin" : "Admin",
     "Help" : "Laguntza",
-    "Error loading tags" : "Errore bat izan da etiketak kargatzearkoan.",
-    "Tag already exists" : "Etiketa dagoeneko existitzen da",
-    "Error deleting tag(s)" : "Errore bat izan da etiketa(k) ezabatzerakoan",
-    "Error tagging" : "Errorea etiketa ezartzerakoan",
-    "Error untagging" : "Errorea etiketa kentzerakoan",
-    "Error favoriting" : "Errorea gogokoetara gehitzerakoan",
-    "Error unfavoriting" : "Errorea gogokoetatik kentzerakoan",
     "Access forbidden" : "Sarrera debekatuta",
     "File not found" : "Ez da fitxategia aurkitu",
     "The specified document has not been found on the server." : "Zehaztutako dokumentua ez da zerbitzarian aurkitu.",
@@ -177,7 +176,6 @@ OC.L10N.register(
     "Trace" : "Arrastoa",
     "Security warning" : "Segurtasun abisua",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Zure data karpeta eta fitxategiak interneten bidez eskuragarri egon daitezke .htaccess fitxategia ez delako funtzionatzen ari.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Zure zerbitrzaria ongi konfiguratzeko, mezedez <a href=\"%s\" target=\"_blank\">dokumentazioa</a> ikusi.",
     "Create an <strong>admin account</strong>" : "Sortu <strong>kudeatzaile kontu<strong> bat",
     "Username" : "Erabiltzaile izena",
     "Storage & database" : "Biltegia & datubasea",
