@@ -1,29 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Sähköpostin lähetys seuraaville käyttäjille epäonnistui: %s",
-    "Preparing update" : "Valmistellaan päivitystä",
-    "Turned on maintenance mode" : "Siirrytty huoltotilaan",
-    "Turned off maintenance mode" : "Huoltotila asetettu pois päältä",
-    "Maintenance mode is kept active" : "Huoltotila pidetään aktiivisena",
-    "Updating database schema" : "Päivitetään tietokannan skeemaa",
-    "Updated database" : "Tietokanta ajan tasalla",
-    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Tarkistetaan onko tietokannan skeemaa mahdollista päivittää (tämä saattaa kestää kauan riippuen tietokannan koosta)",
-    "Checked database schema update" : "Tarkistettu tietokannan skeemapäivitys",
-    "Checking updates of apps" : "Tarkistetaan sovellusten päivityksiä",
-    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Tarkistetaan onko kohteen %s tietokannan skeemaa mahdollista päivittää (tämä saattaa kestää kauan riippuen tietokannan koosta)",
-    "Checked database schema update for apps" : "Tarkistettu tietokannan skeemapäivitys sovelluksille",
-    "Updated \"%s\" to %s" : "Päivitetty \"%s\" versioon %s",
-    "Repair warning: " : "Korjausvaroitus:",
-    "Repair error: " : "Korjausvirhe:",
-    "Set log level to debug" : "Aseta lokitustasoksi vianetsintä",
-    "Reset log level" : "Nollaa lokitustaso",
-    "Starting code integrity check" : "Aloitetaan koodin eheystarkistus",
-    "Finished code integrity check" : "Koodin eheystarkistus suoritettu",
-    "%s (3rdparty)" : "%s (kolmannen osapuolen)",
-    "%s (incompatible)" : "%s (ei yhteensopiva)",
-    "Following apps have been disabled: %s" : "Seuraavat sovellukset on poistettu käytöstä: %s",
-    "Already up to date" : "Kaikki on jo ajan tasalla",
     "Please select a file." : "Valitse tiedosto.",
     "File is too big" : "Tiedosto on liian suuri",
     "Invalid file provided" : "Määritetty virheellinen tiedosto",
@@ -41,6 +18,39 @@ OC.L10N.register(
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Salasanan palautusiviestiä ei voitu lähettää sähköpostitse, koska tälle käyttäjätunnukselle ei ole määritetty sähköpostiosoitetta. Ota yhteys ylläpitäjään.",
     "%s password reset" : "%s salasanan palautus",
     "Couldn't send reset email. Please contact your administrator." : "Palautussähköpostin lähettäminen ei onnistunut. Ota yhteys ylläpitäjään.",
+    "Error loading tags" : "Virhe tunnisteita ladattaessa",
+    "Tag already exists" : "Tunniste on jo olemassa",
+    "Error deleting tag(s)" : "Virhe tunnisteita poistaessa",
+    "Error tagging" : "Tunnisteiden kirjoitusvirhe",
+    "Error untagging" : "Tunisteiden poisto virhe",
+    "Error favoriting" : "Suosituksen kirjoitusvirhe",
+    "Error unfavoriting" : "Suosituksen poisto virhe",
+    "Couldn't send mail to following users: %s " : "Sähköpostin lähetys seuraaville käyttäjille epäonnistui: %s",
+    "Preparing update" : "Valmistellaan päivitystä",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair warning: " : "Korjausvaroitus:",
+    "Repair error: " : "Korjausvirhe:",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "Käytä komentorivipäivitintä, koska automaattinen päivitys on estetty config.php-asetustiedostossa.",
+    "[%d / %d]: Checking table %s" : "[%d / %d]: Tarkistetaan taulua %s",
+    "Turned on maintenance mode" : "Siirrytty huoltotilaan",
+    "Turned off maintenance mode" : "Huoltotila asetettu pois päältä",
+    "Maintenance mode is kept active" : "Huoltotila pidetään aktiivisena",
+    "Updating database schema" : "Päivitetään tietokannan skeemaa",
+    "Updated database" : "Tietokanta ajan tasalla",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Tarkistetaan onko tietokannan skeemaa mahdollista päivittää (tämä saattaa kestää kauan riippuen tietokannan koosta)",
+    "Checked database schema update" : "Tarkistettu tietokannan skeemapäivitys",
+    "Checking updates of apps" : "Tarkistetaan sovellusten päivityksiä",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Tarkistetaan onko kohteen %s tietokannan skeemaa mahdollista päivittää (tämä saattaa kestää kauan riippuen tietokannan koosta)",
+    "Checked database schema update for apps" : "Tarkistettu tietokannan skeemapäivitys sovelluksille",
+    "Updated \"%s\" to %s" : "Päivitetty \"%s\" versioon %s",
+    "Set log level to debug" : "Aseta lokitustasoksi vianetsintä",
+    "Reset log level" : "Nollaa lokitustaso",
+    "Starting code integrity check" : "Aloitetaan koodin eheystarkistus",
+    "Finished code integrity check" : "Koodin eheystarkistus suoritettu",
+    "%s (3rdparty)" : "%s (kolmannen osapuolen)",
+    "%s (incompatible)" : "%s (ei yhteensopiva)",
+    "Following apps have been disabled: %s" : "Seuraavat sovellukset on poistettu käytöstä: %s",
+    "Already up to date" : "Kaikki on jo ajan tasalla",
     "Sunday" : "sunnuntai",
     "Monday" : "maanantai",
     "Tuesday" : "tiistai",
@@ -88,6 +98,7 @@ OC.L10N.register(
     "Dec." : "Joulu",
     "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Eheystarkistus tuotti ongelmia. Lisätietoja…</a>",
     "Settings" : "Asetukset",
+    "Problem loading page, reloading in 5 seconds" : "Ongelma sivun lataamisessa, päivitetään 5 sekunnin kuluttua",
     "Saving..." : "Tallennetaan...",
     "Dismiss" : "Hylkää",
     "seconds ago" : "sekuntia sitten",
@@ -119,18 +130,10 @@ OC.L10N.register(
     "Good password" : "Hyvä salasana",
     "Strong password" : "Vahva salasana",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "HTTP-palvelinta ei ole määritetty oikein tiedostojen synkronointia varten, koska WebDAV-liittymä vaikuttaa olevan rikki.",
-    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "HTTP-palvelintasi ei ole määritetty kelvollisesti selvittämään osoitetta \"{url}\". Lisätietoja on saatavilla <a target=\"_blank\" href=\"{docLink}\">dokumentaatiosta</a>.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Tällä palvelimella ei ole toimivaa internetyhteyttä. Sen seurauksena jotkin ominaisuudet, kuten erillinen tallennustila, ilmoitukset päivityksistä ja kolmansien osapuolten sovellusten asennus eivät toimi. Tiedostojen käyttö etänä tai ilmoitusten lähetys sähköpostitse eivät välttämättä toimi myöskään. Suosittelemme kytkemään palvelimen internetyhteyteen, jos haluat käyttää kaikkia ownCloudin ominaisuuksia.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Välimuistia ei ole määritetty. Paranna suorituskykyä ottamalla memcache käyttöön. Lisätietoja on saatavilla <a target=\"_blank\" href=\"{docLink}\">dokumentaatiossa</a>.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "/dev/urandom ei ole PHP:n luettavissa, eikä tätä missään tapauksessa suositella tietoturvasyistä. Lisätietoja on saatavilla <a target=\"_blank\" href=\"{docLink}\">dokumentaatiossa</a>.",
-    "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "PHP-versiosi ({version}) ei ole enää tuettu <a target=\"_blank\" href=\"{phpLink}\"> PHP:n toimesta</a>. Suosittelemme päivittämään PHP:n version, jotta hyödyt suorituskykyparannuksista sekä tietoturvakorjauksista.",
-    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Käänteisen välityspalvelimen otsakemääritykset ovat väärin, tai olet yhteydessä ownCloudiin luotetun välityspalvelimen kautta. Jos et ole yhteydessä luotetun välityspalvelimen kautta, kyseessä on tietoturvaongelma, joka mahdollistaa hyökkääjän väärentävän ownCloudille näkyvän IP-osoitteen. Lisätietoja on saatavilla <a target=\"_blank\" href=\"{docLink}\">dokumentaatiossa</a>.",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached on määritetty hajautetuksi välimuistiksi, mutta väärä PHP-moduuli \"memcache\" on asennettu. \\OC\\Memcache\\Memcached tukee vain moduulia \"memcached\", ei moduulia \"memcache\". Lisätietoja <a target=\"_blank\" href=\"{wikiLink}\">memcachedin wikissä molemmista moduuleista</a>.",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Jotkin tiedostot eivät läpäisseet eheystarkistusta. Lisätietoja ongelman selvittämiseksi on saatavilla <a target=\"_blank\" href=\"{docLink}\">dokumentaatiossa</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Luettelo virheellisistä tiedostoista…</a> / <a href=\"{rescanEndpoint}\">Tarkista uudelleen…</a>)",
     "Error occurred while checking server setup" : "Virhe palvelimen määrityksiä tarkistaessa",
     "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Datahakemistosi ja tiedostosi ovat luultavasti käytettävissä suoraan internetistä. .htaccess-tiedosto ei toimi oikein. Suosittelemme määrittämään http-palvelimen asetukset siten, ettei datahakemisto ole suoraan käytettävissä internetistä, tai siirtämään datahakemiston http-palvelimen juurihakemiston ulkopuolelle.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "HTTP-otsaketta \"{header}\" ei ole määritetty vastaamaan arvoa \"{expected}\". Kyseessä on mahdollinen tietoturvaan tai -suojaan liittyvä riski, joten suosittelemme muuttamaan asetuksen arvoa.",
-    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "HTTP-otsaketta \"Strict-Transport-Security\" ei ole määritetty vähintään \"{seconds}\" sekunniksi. Suosittelemme lisäturvan vuoksi ottamaan HSTS:n käyttöön <a href=\"{docUrl}\">turvallisuusohjeiden</a> mukaisesti.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Käytät sivustoa HTTP-yhteydellä. Suosittelemme asettamaan palvelimen vaatimaan HTTPS-yhteyden, kuten <a href=\"{docUrl}\">tietoturvavinkeissä</a> neuvotaan.",
     "Shared" : "Jaettu",
     "Shared with {recipients}" : "Jaettu henkilöiden {recipients} kanssa",
@@ -143,8 +146,6 @@ OC.L10N.register(
     "Expiration" : "Erääntyminen",
     "Expiration date" : "Päättymispäivä",
     "Choose a password for the public link" : "Valitse salasana julkiselle linkille",
-    "Sending ..." : "Lähetetään...",
-    "Email sent" : "Sähköposti lähetetty",
     "Resharing is not allowed" : "Jakaminen uudelleen ei ole salittu",
     "Share link" : "Jaa linkki",
     "Link" : "Linkki",
@@ -153,6 +154,9 @@ OC.L10N.register(
     "Allow editing" : "Salli muokkaus",
     "Email link to person" : "Lähetä linkki sähköpostitse",
     "Send" : "Lähetä",
+    "Sending ..." : "Lähetetään...",
+    "Email sent" : "Sähköposti lähetetty",
+    "Send link via email" : "Lähetä linkki sähköpostitse",
     "Shared with you and the group {group} by {owner}" : "Jaettu sinun ja ryhmän {group} kanssa käyttäjän {owner} toimesta",
     "Shared with you by {owner}" : "Jaettu kanssasi käyttäjän {owner} toimesta",
     "group" : "ryhmä",
@@ -168,19 +172,22 @@ OC.L10N.register(
     "Could not unshare" : "Jakamisen lopettaminen epäonnistui",
     "Share details could not be loaded for this item." : "Tämän kohteen jakamistietoja ei voitu ladata.",
     "No users or groups found for {search}" : "Haulla {search} ei löytynyt käyttäjiä tai ryhmiä",
-    "An error occured. Please try again" : "Tapahtui virhe. Yritä myöhemmin uudestaan",
+    "No users found for {search}" : "Haulla {search} ei löytynyt käyttäjiä",
+    "An error occurred. Please try again" : "Tapahtui virhe, yritä uudelleen",
     "{sharee} (group)" : "{sharee} (ryhmä)",
     "{sharee} (at {server})" : "{sharee} (palvelimella {server})",
     "{sharee} (remote)" : "{sharee} (etä)",
     "Share" : "Jaa",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Jaa toisia ownCloud-järjestelmiä käyttävien kesken käyttäen syntaksia käyttäjätunnus@esimerkki.fi/owncloud",
-    "Share with users or groups …" : "Jaa käyttäjien tai ryhmien kanssa…",
-    "Share with users, groups or remote users …" : "Jaa käyttäjien, ryhmien tai etäkäyttäjien kanssa…",
+    "Share with users…" : "Jaa käyttäjien kanssa…",
+    "Share with users, groups or remote users…" : "Jaa käyttäjien, ryhmien tai etäkäyttäjien kanssa…",
+    "Share with users or groups…" : "Jaa käyttäjien tai ryhmien kanssa…",
+    "Share with users or remote users…" : "Jaa käyttäjien tai etäkäyttäjien kanssa…",
     "Error removing share" : "Virhe jakoa poistaessa",
     "Warning" : "Varoitus",
     "Error while sending notification" : "Virhe ilmoitusta lähettäessä",
     "Non-existing tag #{tag}" : "Ei olemassa oleva tunniste #{tag}",
-    "not assignable" : "ei määritettävissä",
+    "restricted" : "rajoitettu",
     "invisible" : "näkymätön",
     "({scope})" : "({scope})",
     "Delete" : "Poista",
@@ -197,13 +204,14 @@ OC.L10N.register(
     "sunny" : "aurinkoinen",
     "Hello {name}, the weather is {weather}" : "Hei {name}, sää on {weather}",
     "Hello {name}" : "Hei {name}",
+    "new" : "uusi",
     "_download %n file_::_download %n files_" : ["lataa %n tiedosto","lataa %n tiedostoa"],
     "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Päivitys on meneillään. Poistuminen tältä sivulta saattaa keskeyttää toimenpiteen joissain käyttöympäristöissä.",
-    "Updating {productName} to version {version}, this may take a while." : "Päivitetään {productName} versioon {version}, tämä saattaa kestää hetken.",
+    "Updating to {version}" : "Päivitetään versioon {version}",
     "An error occurred." : "Tapahtui virhe.",
     "Please reload the page." : "Päivitä sivu.",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Päivitys epäonnistui. Katso lisätietoja tähän ongelmaan liittyen <a href=\"{url}\">keskustelupalstan viestistä</a>.",
-    "The update was unsuccessful. " : "Päivitys epäonnistui.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Päivitys epäonnistui. Ilmoita ongelmasta <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud-yhteisölle</a>.",
     "The update was successful. There were warnings." : "Päivitys onnistui, tosin ilmeni varoituksia.",
     "The update was successful. Redirecting you to ownCloud now." : "Päivitys onnistui. Selain ohjautuu nyt ownCloudiisi.",
     "Searching other places" : "Etsitään muista paikoista",
@@ -214,13 +222,6 @@ OC.L10N.register(
     "Apps" : "Sovellukset",
     "Admin" : "Ylläpito",
     "Help" : "Ohje",
-    "Error loading tags" : "Virhe tunnisteita ladattaessa",
-    "Tag already exists" : "Tunniste on jo olemassa",
-    "Error deleting tag(s)" : "Virhe tunnisteita poistaessa",
-    "Error tagging" : "Tunnisteiden kirjoitusvirhe",
-    "Error untagging" : "Tunisteiden poisto virhe",
-    "Error favoriting" : "Suosituksen kirjoitusvirhe",
-    "Error unfavoriting" : "Suosituksen poisto virhe",
     "Access forbidden" : "Pääsy estetty",
     "File not found" : "Tiedostoa ei löytynyt",
     "The specified document has not been found on the server." : "Määritettyä asiakirjaa ei löytynyt palvelimelta.",
@@ -243,7 +244,7 @@ OC.L10N.register(
     "Trace" : "Jälki",
     "Security warning" : "Turvallisuusvaroitus",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Datakansiosi ja tiedostosi ovat mitä luultavimmin muiden saavutettavissa internetistä, koska .htaccess-tiedosto ei toimi.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Lisätietoja palvelimen asetuksien määrittämisestä on saatavilla <a href=\"%s\" target=\"_blank\">dokumentaatiosta</a>.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">documentation</a>." : "Lisätietoja palvelimen oikeaoppiseen määritykseen on saatavilla <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">dokumentaatiossa</a>.",
     "Create an <strong>admin account</strong>" : "Luo <strong>ylläpitäjän tunnus</strong>",
     "Username" : "Käyttäjätunnus",
     "Storage & database" : "Tallennus ja tietokanta",
@@ -271,8 +272,9 @@ OC.L10N.register(
     "Search" : "Etsi",
     "Server side authentication failed!" : "Palvelimen puoleinen tunnistautuminen epäonnistui!",
     "Please contact your administrator." : "Ota yhteys ylläpitäjään.",
-    "An internal error occured." : "Tapahtui sisäinen virhe.",
+    "An internal error occurred." : "Tapahtui sisäinen virhe",
     "Please try again or contact your administrator." : "Yritä uudestaan tai ota yhteys ylläpitäjään.",
+    "Username or email" : "Käyttäjätunnus tai sähköpostiosoite",
     "Log in" : "Kirjaudu sisään",
     "Wrong password. Reset it?" : "Väärä salasana. Haluatko palauttaa salasanan?",
     "Wrong password." : "Väärä salasana.",
@@ -286,6 +288,10 @@ OC.L10N.register(
     "This means only administrators can use the instance." : "Se tarkoittaa, että vain ylläpitäjät voivat nyt käyttää tätä ownCloudia.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Ota yhteys järjestelmän ylläpitäjään, jos tämä viesti ilmenee uudelleen tai odottamatta.",
     "Thank you for your patience." : "Kiitos kärsivällisyydestäsi.",
+    "Two-step verification" : "Kaksivaiheinen vahvistus",
+    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "Tililläsi on käytössä lisäturvatoimia. Tunnistaudu käyttäen kaksivaiheista vahvistusta.",
+    "Cancel login" : "Peru kirjautuminen",
+    "Please authenticate using the selected factor." : "Tunnistaudu käyttäen valittua vahvistusta.",
     "You are accessing the server from an untrusted domain." : "Olet yhteydessä palvelimeen epäluotettavasta verkko-osoitteesta.",
     "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Ota yhteys ylläpitoon. Jos olet tämän asennuksen ylläpitäjä, määritä \"trusted_domains\"-asetus config/config.php-tiedostossa. Esimerkkimääritys on tarjolla tiedostossa config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Riippuen määrityksistä, ylläpitäjänä saatat kyetä käyttämään alla olevaa painiketta luodaksesi luottamussuhteen tähän toimialueeseen.",
@@ -298,10 +304,11 @@ OC.L10N.register(
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Varmista ennen jatkamista, että tietokanta, asetuskansio ja datakansio on varmuuskopioitu.",
     "Start update" : "Käynnistä päivitys",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Välttääksesi aikakatkaisuja suurikokoisten asennusten kanssa, voit suorittaa vaihtoehtoisesti seuraavan komennon asennushakemistossa:",
+    "Detailed logs" : "Yksityiskohtainen loki",
+    "Update needed" : "Päivitys vaaditaan",
+    "Please use the command line updater because you have a big instance." : "Käytä komentorivipäivitintä, koska käyttämäsi ownCloud on sen verran suuri.",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Apua saat <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentaatiosta</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Tämä %s-instanssi on parhaillaan huoltotilassa, huollossa saattaa kestää hetki.",
-    "This page will refresh itself when the %s instance is available again." : "Tämä sivu päivittää itsensä, kun %s on jälleen käytettävissä.",
-    "Error loading file picker template: {error}" : "Virhe ladatessa tiedostopohjia: {error}",
-    "Password can not be changed. Please contact your administrator." : "Salasanan vaihtaminen ei onnistunut. Ota yhteys ylläpitäjään.",
-    "Sun." : "Su"
+    "This page will refresh itself when the %s instance is available again." : "Tämä sivu päivittää itsensä, kun %s on jälleen käytettävissä."
 },
 "nplurals=2; plural=(n != 1);");
