@@ -1,29 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Gat ekki sent póst á eftirfarandi notendur: %s",
-    "Preparing update" : "Undirbý uppfærslu",
-    "Turned on maintenance mode" : "Kveikt á viðhaldsham",
-    "Turned off maintenance mode" : "Slökkt á viðhaldsham",
-    "Maintenance mode is kept active" : "Viðhaldsham er haldið virkum",
-    "Updating database schema" : "Uppfæri gagnagrunnsskema",
-    "Updated database" : "Uppfærði gagnagrunn",
-    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Athuga hvort hægt sé að uppfæra gagnagrunnsskema (þetta getur tekið langan tíma ef gagnagrunnurinn er mjög stór)",
-    "Checked database schema update" : "Athugaði uppfærslu á gagnagrunnsskema.",
-    "Checking updates of apps" : "Athuga með uppfærslur á öppum",
-    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Athuga hvort hægt sé að uppfæra gagnagrunnsskema fyrir %s (þetta getur tekið langan tíma ef gagnagrunnurinn er mjög stór)",
-    "Checked database schema update for apps" : "Athugaði uppfærslu á gagnagrunnsskema fyrir öpp",
-    "Updated \"%s\" to %s" : "Uppfærði \"%s\" í %s",
-    "Repair warning: " : "Viðvörun vegna viðgerðar: ",
-    "Repair error: " : "Villa í viðgerð:",
-    "Set log level to debug" : "Setja annálsstig á aflúsun",
-    "Reset log level" : "Frumstilla annálsstig",
-    "Starting code integrity check" : "Ræsi athugun á áreiðanleika kóða",
-    "Finished code integrity check" : "Lauk athugun á áreiðanleika kóða",
-    "%s (3rdparty)" : "%s (frá 3. aðila)",
-    "%s (incompatible)" : "%s (ósamhæft)",
-    "Following apps have been disabled: %s" : "Eftirfarandi forrit hafa verið gerð óvirk: %s",
-    "Already up to date" : "Allt uppfært nú þegar",
     "Please select a file." : "Veldu skrá.",
     "File is too big" : "Skrá er of stór",
     "Invalid file provided" : "Ógild skrá gefin",
@@ -41,6 +18,36 @@ OC.L10N.register(
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Gat ekki sent endurstillingu í tölvupósti því það er ekkert gilt tölvupóstfang fyrir þennan notanda. Hafðu samband við kerfisstjóra.",
     "%s password reset" : "%s lykilorð endurstillt",
     "Couldn't send reset email. Please contact your administrator." : "Gat ekki sent endurstillingu í tölvupósti. Hafðu samband við kerfisstjóra.",
+    "Error loading tags" : "Villa við að hlaða inn merkjum",
+    "Tag already exists" : "Merki er þegar til",
+    "Error deleting tag(s)" : "Villa við að eyða merki/merkjum",
+    "Error tagging" : "Villa við að merkja",
+    "Error untagging" : "Villa við afmerkja",
+    "Error favoriting" : "Villa við bókmerkingu ",
+    "Error unfavoriting" : "Villa við afmá bókmerkingu",
+    "Couldn't send mail to following users: %s " : "Gat ekki sent póst á eftirfarandi notendur: %s",
+    "Preparing update" : "Undirbý uppfærslu",
+    "Repair warning: " : "Viðvörun vegna viðgerðar: ",
+    "Repair error: " : "Villa í viðgerð:",
+    "Turned on maintenance mode" : "Kveikt á viðhaldsham",
+    "Turned off maintenance mode" : "Slökkt á viðhaldsham",
+    "Maintenance mode is kept active" : "Viðhaldsham er haldið virkum",
+    "Updating database schema" : "Uppfæri gagnagrunnsskema",
+    "Updated database" : "Uppfærði gagnagrunn",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Athuga hvort hægt sé að uppfæra gagnagrunnsskema (þetta getur tekið langan tíma ef gagnagrunnurinn er mjög stór)",
+    "Checked database schema update" : "Athugaði uppfærslu á gagnagrunnsskema.",
+    "Checking updates of apps" : "Athuga með uppfærslur á öppum",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Athuga hvort hægt sé að uppfæra gagnagrunnsskema fyrir %s (þetta getur tekið langan tíma ef gagnagrunnurinn er mjög stór)",
+    "Checked database schema update for apps" : "Athugaði uppfærslu á gagnagrunnsskema fyrir öpp",
+    "Updated \"%s\" to %s" : "Uppfærði \"%s\" í %s",
+    "Set log level to debug" : "Setja annálsstig á aflúsun",
+    "Reset log level" : "Frumstilla annálsstig",
+    "Starting code integrity check" : "Ræsi athugun á áreiðanleika kóða",
+    "Finished code integrity check" : "Lauk athugun á áreiðanleika kóða",
+    "%s (3rdparty)" : "%s (frá 3. aðila)",
+    "%s (incompatible)" : "%s (ósamhæft)",
+    "Following apps have been disabled: %s" : "Eftirfarandi forrit hafa verið gerð óvirk: %s",
+    "Already up to date" : "Allt uppfært nú þegar",
     "Sunday" : "Sunnudagur",
     "Monday" : "Mánudagur",
     "Tuesday" : "Þriðjudagur",
@@ -89,6 +96,7 @@ OC.L10N.register(
     "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Það komu upp vandamál með athugun á áreiðanleika kóða. Nánari upplýsingar…</a>",
     "Settings" : "Stillingar",
     "Saving..." : "Er að vista ...",
+    "Dismiss" : "Hafna",
     "seconds ago" : "sekúndum síðan",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Tengillinn til að endurstilla lykilorðið þitt hefur verið sendur á netfangið þitt. Ef þú færð ekki póstinn innan hæfilegs tíma, athugaðu þá ruslpóstmöppuna.<br>Ef hann er ekki þar, spurðu þá kerfisstjórann þinn.",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Skrárnar þínar eru dulritaðar. Ef þú hefur ekki virkjað endurheimtingarlykilinn, þá verður engin leið til að fá gögnin þín til baka eftir lykilorðið þitt er endurstillt.<br />Ef þú ert ekki viss hvað eigi að gera, skaltu hafa samband við kerfisstjórann áður en þú heldur áfram. <br />Viltu halda áfram?",
@@ -118,13 +126,7 @@ OC.L10N.register(
     "Good password" : "Gott lykilorð",
     "Strong password" : "Sterkt lykilorð",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Vefþjónninn er ekki enn sett upp á réttan hátt til að leyfa skráasamstillingu því WebDAV viðmótið virðist vera skemmt.",
-    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Vefþjónninn þinn er ekki uppsettur þannig að hann geti leyst \"{url}\". Frekari upplýsingar er að finna í <a target=\"_blank\" href=\"{docLink}\">hjálparskjölum</a> okkar.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Þessi þjónn er ekki með virka nettengingu. Þetta þýðir að sumir eiginleikar eins og að virkja ytri gagnageymslu, tilkynningar um uppfærslur eða uppsetningu á forritum þriðja aðila, mun ekki virka. Fjartengdur aðgangur að skrám og sending tilkynninga í tölvupósti virka líklega ekki heldur. Við leggjum til að internettenging sé virkjuð fyrir þennan vefþjón ef þú vilt hafa alla eiginleika tiltæka.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Ekkert skyndiminni (cache) hefur verið stillt. Til að auka afköst ættirðu að setja upp skyndiminni (með memcache) ef það er tiltækt. Hægt er að finna nánari upplýsingar um þetta í <a target=\"_blank\" href=\"{docLink}\">hjálparskjölum</a> okkar.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "/dev/urandom er ekki lesanlegt af PHP sem er mjög óráðlegt af öryggisástæðum. Hægt er að finna nánari upplýsingar um þetta í <a target=\"_blank\" href=\"{docLink}\">hjálparskjölum</a> okkar.",
-    "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "PHP-útgáfan þín, ({version}) er ekki lengur <a target=\"_blank\" href=\"{phpLink}\">studd af PHP</a>. Við hvetjum þig til að uppfæra PHP útgáfuna til að geta nýtt aukin afköst og betra öryggi með uppfærslunum frá PHP.",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached er sett upp sem dreift skyndiminni, en hinsvegar er ranga PHP-einingin \"memcache\" uppsett. \\OC\\Memcache\\Memcached styður einungis \"memcached\" en ekki \"memcache\". Skoðaðu <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki-síðurnar um báðar einingarnar</a>.",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Sumar skrár hafa ekki staðist áreiðanleikaprófun. Hægt er að finna nánari upplýsingar um þetta í <a target=\"_blank\" href=\"{docLink}\">hjálparskjölum</a> okkar. (<a href=\"{codeIntegrityDownloadEndpoint}\">Listi yfir ógildar skrár…</a> / <a href=\"{rescanEndpoint}\">Endurskanna…</a>)",
     "Error occurred while checking server setup" : "Villa kom upp við athugun á uppsetningu þjóns",
     "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Gagnamappan og skrárnar þínar eru líklega aðgengilegar öllum af internetinu vegna þess að .htaccess skrá er ekki virk. Við mælum eindregið með að þú stillir vefþjóninn þinn á þann hátt að gagnamappa er ekki lengur aðgengileg eða þú færir gagnamöppu út fyrir skjalarót vefþjóns.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "\"{header}\" HTTP-haus er ekki stilltur til jafns við \"{expected}\". Þetta er möguleg áhætta varðandi  öryggi og gagnaleynd, við mælum með því að laga þessa stillingu.",
@@ -140,8 +142,6 @@ OC.L10N.register(
     "Expiration" : "Rennur út",
     "Expiration date" : "Gildir til",
     "Choose a password for the public link" : "Veldu þér lykilorð fyrir almenningstengil",
-    "Sending ..." : "Sendi ...",
-    "Email sent" : "Tölvupóstur sendur",
     "Resharing is not allowed" : "Endurdeiling er ekki leyfð",
     "Share link" : "Deila tengli",
     "Link" : "Tengill",
@@ -150,6 +150,8 @@ OC.L10N.register(
     "Allow editing" : "Leyfa breytingar",
     "Email link to person" : "Senda veftengil í tölvupósti til notanda",
     "Send" : "Senda",
+    "Sending ..." : "Sendi ...",
+    "Email sent" : "Tölvupóstur sendur",
     "Shared with you and the group {group} by {owner}" : "Deilt með þér og hópnum {group} af {owner}",
     "Shared with you by {owner}" : "Deilt með þér af {owner}",
     "group" : "hópur",
@@ -165,23 +167,25 @@ OC.L10N.register(
     "Could not unshare" : "Gat ekki hætt deilingu",
     "Share details could not be loaded for this item." : "Ekki tókst að hlaða inn upplýsingum um sameign varðandi þetta atriði.",
     "No users or groups found for {search}" : "Engir notendur eða hópar fundust í {search}",
-    "An error occured. Please try again" : "Villa kom upp. Endilega reyndu aftur",
+    "No users found for {search}" : "Engir notendur fundust með {search}",
     "{sharee} (group)" : "{sharee} (hópur)",
     "{sharee} (at {server})" : "{sharee} (á {server})",
     "{sharee} (remote)" : "{sharee} (fjartengdur)",
     "Share" : "Deila",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Deila með fólki í öðrum ownCloud-skýjum með skipuninni notandanafn@dæmi.is/owncloud",
-    "Share with users or groups …" : "Deila með notendum eða hópum ...",
-    "Share with users, groups or remote users …" : "Deila með notendum, hópum eða fjartengdum notendum ...",
+    "Share with users…" : "Deila með notendum...",
+    "Share with users, groups or remote users…" : "Deila með notendum, hópa eða fjartengdum notendum...",
+    "Share with users or groups…" : "Deila með notendum eða hópum...",
+    "Share with users or remote users…" : "Deila með notendum, hópa eða fjartengdum notendum...",
     "Error removing share" : "Villa við að fjarlægja sameign",
     "Warning" : "Aðvörun",
     "Error while sending notification" : "Villa við að senda tilkynningu",
     "Non-existing tag #{tag}" : "Merki sem er ekki til #{tag}",
-    "not assignable" : "ekki úthlutanlegt",
     "invisible" : "ósýnilegt",
     "({scope})" : "({scope})",
     "Delete" : "Eyða",
     "Rename" : "Endurnefna",
+    "Collaborative tags" : "Samstarfsmerkingar",
     "The object type is not specified." : "Tegund hlutar ekki tilgreind",
     "Enter new" : "Sláðu inn nýtt",
     "Add" : "Bæta við",
@@ -193,13 +197,12 @@ OC.L10N.register(
     "sunny" : "sólríkt",
     "Hello {name}, the weather is {weather}" : "Halló {name},veðrið er {weather}",
     "Hello {name}" : "Halló {name}",
+    "new" : "nýtt",
     "_download %n file_::_download %n files_" : ["sækja %n skrá","sækja %n skrár"],
     "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Uppfærslan er í gangi, ef farið er af þessari síðu gæti það truflað ferlið á sumum kerfum.",
-    "Updating {productName} to version {version}, this may take a while." : "Uppfæri {productName} í útgáfu {version}, þetta getur tekið smá stund.",
     "An error occurred." : "Villa átti sér stað.",
     "Please reload the page." : "Þú ættir að hlaða síðunni aftur inn.",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Uppfærslan tókst ekki. Til að fá frekari upplýsingar <a href=\"{url}\">skoðaðu færslu á spjallsvæðinu okkar</a> sem fjallar um þetta mál.",
-    "The update was unsuccessful. " : "Uppfærslan tókst ekki.",
     "The update was successful. There were warnings." : "Uppfærslan tókst. Það voru viðvaranir.",
     "The update was successful. Redirecting you to ownCloud now." : "Uppfærslan heppnaðist. Beini þér til ownCloud nú.",
     "Searching other places" : "Leitað á öðrum stöðum",
@@ -210,13 +213,6 @@ OC.L10N.register(
     "Apps" : "Forrit",
     "Admin" : "Stjórnun",
     "Help" : "Hjálp",
-    "Error loading tags" : "Villa við að hlaða inn merkjum",
-    "Tag already exists" : "Merki er þegar til",
-    "Error deleting tag(s)" : "Villa við að eyða merki/merkjum",
-    "Error tagging" : "Villa við að merkja",
-    "Error untagging" : "Villa við afmerkja",
-    "Error favoriting" : "Villa við bókmerkingu ",
-    "Error unfavoriting" : "Villa við afmá bókmerkingu",
     "Access forbidden" : "Aðgangur bannaður",
     "File not found" : "Skrá finnst ekki",
     "The specified document has not been found on the server." : "Tiltekið skjal hefur ekki fundist á þjóninum.",
@@ -239,7 +235,6 @@ OC.L10N.register(
     "Trace" : "Rekja",
     "Security warning" : "Öryggisviðvörun",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Gagnamappan og skrárnar eru líklega aðgengilegar af internetinu vegna þess að .htaccess skrá er ekki virk.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Til að fá upplýsingar hvernig á að stilla miðlara rétt, skaltu skoða <a href=\\\"%s\\\" target=\\\"_blank\\\">hjálparskjölin</a>.",
     "Create an <strong>admin account</strong>" : "Útbúa <strong>kerfisstjóraaðgang</strong>",
     "Username" : "Notandanafn",
     "Storage & database" : "Geymsla & gagnagrunnur",
@@ -267,7 +262,6 @@ OC.L10N.register(
     "Search" : "Leita",
     "Server side authentication failed!" : "Auðkenning af hálfu þjóns tókst ekki!",
     "Please contact your administrator." : "Hafðu samband við kerfisstjóra.",
-    "An internal error occured." : "Innri villa kom upp.",
     "Please try again or contact your administrator." : "Reyndu aftur eða hafðu samband við kerfisstjóra.",
     "Log in" : "Skrá inn",
     "Wrong password. Reset it?" : "Rangt lykilorð. Endursetja?",
@@ -295,10 +289,6 @@ OC.L10N.register(
     "Start update" : "Hefja uppfærslu",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Til að forðast að falla á tímamörkum með stærri uppsetningar, getur þú í staðinn keyrt eftirfarandi skipun úr uppsetningarmöppunni:",
     "This %s instance is currently in maintenance mode, which may take a while." : "Þessi %s er nú í viðhaldsham, sem getur tekið smá stund.",
-    "This page will refresh itself when the %s instance is available again." : "Þessi síða mun uppfæra sig þegar %s er í boði á ný.",
-    "Collaborative tags" : "Samstarfsmerkingar",
-    "Dismiss" : "Hafna",
-    "Error loading file picker template: {error}" : "Villa við að hlaða inn sniðmáti fyrir skráaveljara: {error}",
-    "Password can not be changed. Please contact your administrator." : "Ekki er hægt að breyta lykilorði. Hafðu samband við kerfisstjóra."
+    "This page will refresh itself when the %s instance is available again." : "Þessi síða mun uppfæra sig þegar %s er í boði á ný."
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
