@@ -1,20 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Nepavyko nusiųsti el. pašto šiems naudotojams: %s ",
-    "Preparing update" : "Ruošiamasi atnaujinimui",
-    "Turned on maintenance mode" : "Įjungta priežiūros veiksena",
-    "Turned off maintenance mode" : "Išjungta priežiūros veiksena",
-    "Maintenance mode is kept active" : "Priežiūros veiksena yra aktyvi",
-    "Updating database schema" : "Atnaujinama duomenų bazės struktūra",
-    "Updated database" : "Atnaujinta duomenų bazė",
-    "Checked database schema update" : "Tikrinama duomenų bazės struktūra",
-    "Checked database schema update for apps" : "Tikrinama duomenų bazės struktūra įskiepiams",
-    "Updated \"%s\" to %s" : "Atnaujinta \"%s\" į %s",
-    "Repair warning: " : "Taisymo perspėjimas:",
-    "Repair error: " : "Taisymo klaida:",
-    "Following apps have been disabled: %s" : "Išjungti įskiepiai: %s",
-    "Already up to date" : "Jau naujausia",
     "File is too big" : "Per didelis failas",
     "Invalid file provided" : "Netinkamas failas",
     "No image or file provided" : "Nenurodytas paveikslėlis ar failas",
@@ -24,6 +10,27 @@ OC.L10N.register(
     "No crop data provided" : "Nenurodyti apkirpimo duomenys",
     "%s password reset" : "%s slaptažodžio atnaujinimas",
     "Couldn't send reset email. Please contact your administrator." : "Nepavyko išsiųsti atkūrimo laiško, susisiekite su administratoriumi.",
+    "Error loading tags" : "Klaida įkeliant žymes",
+    "Tag already exists" : "Žymė jau egzistuoja",
+    "Error deleting tag(s)" : "Klaida trinant žymę(-es)",
+    "Error tagging" : "Klaida pridedant žymę",
+    "Error untagging" : "Klaida šalinant žymę",
+    "Error favoriting" : "Klaida įtraukiant į mėgstamus.",
+    "Error unfavoriting" : "Klaida pašalinant iš mėgstamų.",
+    "Couldn't send mail to following users: %s " : "Nepavyko nusiųsti el. pašto šiems naudotojams: %s ",
+    "Preparing update" : "Ruošiamasi atnaujinimui",
+    "Repair warning: " : "Taisymo perspėjimas:",
+    "Repair error: " : "Taisymo klaida:",
+    "Turned on maintenance mode" : "Įjungta priežiūros veiksena",
+    "Turned off maintenance mode" : "Išjungta priežiūros veiksena",
+    "Maintenance mode is kept active" : "Priežiūros veiksena yra aktyvi",
+    "Updating database schema" : "Atnaujinama duomenų bazės struktūra",
+    "Updated database" : "Atnaujinta duomenų bazė",
+    "Checked database schema update" : "Tikrinama duomenų bazės struktūra",
+    "Checked database schema update for apps" : "Tikrinama duomenų bazės struktūra įskiepiams",
+    "Updated \"%s\" to %s" : "Atnaujinta \"%s\" į %s",
+    "Following apps have been disabled: %s" : "Išjungti įskiepiai: %s",
+    "Already up to date" : "Jau naujausia",
     "Sunday" : "Sekmadienis",
     "Monday" : "Pirmadienis",
     "Tuesday" : "Antradienis",
@@ -107,8 +114,6 @@ OC.L10N.register(
     "Expiration" : "Galiojimo laikas",
     "Expiration date" : "Galiojimo laikas",
     "Choose a password for the public link" : "Viešos nuorodos slaptažodis",
-    "Sending ..." : "Siunčiama...",
-    "Email sent" : "Laiškas išsiųstas",
     "Resharing is not allowed" : "Dalijinasis išnaujo negalimas",
     "Share link" : "Dalintis nuoroda",
     "Link" : "Nuoroda",
@@ -117,6 +122,8 @@ OC.L10N.register(
     "Allow editing" : "Leisti redaguoti",
     "Email link to person" : "Nusiųsti nuorodą paštu",
     "Send" : "Siųsti",
+    "Sending ..." : "Siunčiama...",
+    "Email sent" : "Laiškas išsiųstas",
     "Shared with you and the group {group} by {owner}" : "Pasidalino su Jumis ir {group} grupe {owner}",
     "Shared with you by {owner}" : "Pasidalino su Jumis {owner}",
     "group" : "grupė",
@@ -129,11 +136,8 @@ OC.L10N.register(
     "change" : "keisti",
     "delete" : "ištrinti",
     "access control" : "priėjimo kontrolė",
-    "An error occured. Please try again" : "Klaida, prašau bandyti dar kartą.",
     "Share" : "Dalintis",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Dalintis su vartotoju kitame ownCloud debesyje, sintaksė vartotojas@example.com/owncloud",
-    "Share with users or groups …" : "Dalintis su vartotoju ar grupe",
-    "Share with users, groups or remote users …" : "Dalintis su vartotoju, grupe, ar nutolusiu vartotoju...",
     "Warning" : "Įspėjimas",
     "Delete" : "Ištrinti",
     "Rename" : "Pervadinti",
@@ -146,19 +150,13 @@ OC.L10N.register(
     "Hello world!" : "Sveikas pasauli!",
     "sunny" : "saulėta",
     "Please reload the page." : "Prašome perkrauti puslapį.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Atnaujinimas buvo nesėkmingas. PApie tai prašome pranešti the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud bendruomenei</a>.",
     "The update was successful. Redirecting you to ownCloud now." : "Atnaujinimas buvo sėkmingas. Nukreipiame į jūsų ownCloud.",
     "Personal" : "Asmeniniai",
     "Users" : "Vartotojai",
     "Apps" : "Programos",
     "Admin" : "Administravimas",
     "Help" : "Pagalba",
-    "Error loading tags" : "Klaida įkeliant žymes",
-    "Tag already exists" : "Žymė jau egzistuoja",
-    "Error deleting tag(s)" : "Klaida trinant žymę(-es)",
-    "Error tagging" : "Klaida pridedant žymę",
-    "Error untagging" : "Klaida šalinant žymę",
-    "Error favoriting" : "Klaida įtraukiant į mėgstamus.",
-    "Error unfavoriting" : "Klaida pašalinant iš mėgstamų.",
     "Access forbidden" : "Priėjimas draudžiamas",
     "File not found" : "Failas nerastas",
     "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Labas,\n\nInformuojame, kad %s pasidalino su Jumis %s.\nPažiūrėti tai: %s\n",
@@ -169,7 +167,6 @@ OC.L10N.register(
     "Trace" : "Sekti",
     "Security warning" : "Saugumo perspėjimas",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Jūsų failai yra tikriausiai prieinami per internetą nes .htaccess failas neveikia.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Kad gauti informaciją apie tai kaip tinkamai sukonfigūruoti savo serverį, prašome skaityti <a href=\"%s\" target=\"_blank\">dokumentaciją</a>.",
     "Create an <strong>admin account</strong>" : "Sukurti <strong>administratoriaus paskyrą</strong>",
     "Username" : "Prisijungimo vardas",
     "Data folder" : "Duomenų katalogas",
@@ -194,8 +191,6 @@ OC.L10N.register(
     "This ownCloud instance is currently in single user mode." : "Ši ownCloud sistema yra vieno naudotojo veiksenoje.",
     "This means only administrators can use the instance." : "Tai reiškia, kad tik administratorius gali naudotis sistema.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Susisiekite su savo sistemos administratoriumi jei šis pranešimas nedingsta arba jei jis pasirodė netikėtai.",
-    "Thank you for your patience." : "Dėkojame už jūsų kantrumą.",
-    "Error loading file picker template: {error}" : "Klaida įkeliant failo parinkimo ruošinį: {error}",
-    "Password can not be changed. Please contact your administrator." : "Slaptažodis negali būti pakeistas, susisiekite su administratoriumi."
+    "Thank you for your patience." : "Dėkojame už jūsų kantrumą."
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");
