@@ -1,25 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Impossible de mandar un corrièl als utilizaires seguents : %s",
-    "Preparing update" : "Preparacion de la mesa a jorn",
-    "Turned on maintenance mode" : "Mòde de mantenença activat",
-    "Turned off maintenance mode" : "Mòde de mantenença desactivat",
-    "Maintenance mode is kept active" : "Lo mòde de mantenença es daissat actiu",
-    "Updating database schema" : "Mesa a jorn de l'esquèma de la banca de donadas",
-    "Updated database" : "Banca de donadas mesa a jorn",
-    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Verificacion de la possibilitat de metre a jorn l'esquèma de la banca de donadas (aquò pòt préner un certan temps que depend de la talha de la banca de donadas)",
-    "Checked database schema update" : "Mesa a jorn de l'esquèma de la banca de donadas verificada",
-    "Checking updates of apps" : "Recèrca de mesas a jorn d'aplicacions",
-    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Verificacion de la possibilitat de metre a jorn l'esquèma de la banca de donadas per %s (aquò pòt préner un certan temps que depend de la talha de la banca de donadas)",
-    "Checked database schema update for apps" : "Mesa a jorn de l'esquèma de la banca de donadas per las aplicacions verificada",
-    "Updated \"%s\" to %s" : "Mesa a jorn de « %s » cap a %s",
-    "Repair warning: " : "Avertiment de reparacion :",
-    "Repair error: " : "Error de reparacion :",
-    "%s (3rdparty)" : "%s (origina tèrça)",
-    "%s (incompatible)" : "%s (incompatible)",
-    "Following apps have been disabled: %s" : "Las aplicacions seguentas son estadas desactivadas : %s",
-    "Already up to date" : "Ja a jorn",
     "File is too big" : "Fichièr tròp voluminós",
     "Invalid file provided" : "Fichièr invalid",
     "No image or file provided" : "Cap de fichièr pas provesit",
@@ -35,6 +16,32 @@ OC.L10N.register(
     "Couldn't send reset email. Please make sure your username is correct." : "Impossible de mandar lo corrièl de reïnicializacion. Verificatz que vòstre nom d'utilizaire es corrècte.",
     "%s password reset" : "Reïnicializacion de vòstre senhal %s",
     "Couldn't send reset email. Please contact your administrator." : "Impossible de mandar lo corrièl de reïnicializacion. Contactatz vòstre administrator.",
+    "Error loading tags" : "Error al moment del cargament de las etiquetas",
+    "Tag already exists" : "L'etiqueta existís ja.",
+    "Error deleting tag(s)" : "Error de supression d'etiqueta(s)",
+    "Error tagging" : "Error al moment de l'etiquetatge",
+    "Error untagging" : "Error al moment del desetiquetatge",
+    "Error favoriting" : "Error al moment de la mesa en favorit",
+    "Error unfavoriting" : "Error al moment de la supression dels favorits",
+    "Couldn't send mail to following users: %s " : "Impossible de mandar un corrièl als utilizaires seguents : %s",
+    "Preparing update" : "Preparacion de la mesa a jorn",
+    "Repair warning: " : "Avertiment de reparacion :",
+    "Repair error: " : "Error de reparacion :",
+    "Turned on maintenance mode" : "Mòde de mantenença activat",
+    "Turned off maintenance mode" : "Mòde de mantenença desactivat",
+    "Maintenance mode is kept active" : "Lo mòde de mantenença es daissat actiu",
+    "Updating database schema" : "Mesa a jorn de l'esquèma de la banca de donadas",
+    "Updated database" : "Banca de donadas mesa a jorn",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Verificacion de la possibilitat de metre a jorn l'esquèma de la banca de donadas (aquò pòt préner un certan temps que depend de la talha de la banca de donadas)",
+    "Checked database schema update" : "Mesa a jorn de l'esquèma de la banca de donadas verificada",
+    "Checking updates of apps" : "Recèrca de mesas a jorn d'aplicacions",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Verificacion de la possibilitat de metre a jorn l'esquèma de la banca de donadas per %s (aquò pòt préner un certan temps que depend de la talha de la banca de donadas)",
+    "Checked database schema update for apps" : "Mesa a jorn de l'esquèma de la banca de donadas per las aplicacions verificada",
+    "Updated \"%s\" to %s" : "Mesa a jorn de « %s » cap a %s",
+    "%s (3rdparty)" : "%s (origina tèrça)",
+    "%s (incompatible)" : "%s (incompatible)",
+    "Following apps have been disabled: %s" : "Las aplicacions seguentas son estadas desactivadas : %s",
+    "Already up to date" : "Ja a jorn",
     "Sunday" : "Dimenge",
     "Monday" : "Diluns",
     "Tuesday" : "Dimars",
@@ -128,8 +135,6 @@ OC.L10N.register(
     "Expiration" : "Expiracion",
     "Expiration date" : "Data d'expiracion",
     "Choose a password for the public link" : "Causissètz un senhal pel ligam public",
-    "Sending ..." : "Mandadís…",
-    "Email sent" : "Corrièl mandat",
     "Resharing is not allowed" : "Lo repartiment es pas autorizat",
     "Share link" : "Partejar per ligam public",
     "Link" : "Ligam",
@@ -138,6 +143,8 @@ OC.L10N.register(
     "Allow editing" : "Permetre la modificacion",
     "Email link to person" : "Mandar lo ligam per corrièl",
     "Send" : "Mandar",
+    "Sending ..." : "Mandadís…",
+    "Email sent" : "Corrièl mandat",
     "Shared with you and the group {group} by {owner}" : "Partejat amb vos e lo grop {group} per {owner}",
     "Shared with you by {owner}" : "Partejat amb vos per {owner}",
     "group" : "grop",
@@ -151,11 +158,8 @@ OC.L10N.register(
     "delete" : "suprimir",
     "access control" : "contraròtle d'accès",
     "Share details could not be loaded for this item." : "Las informacions de partiment an pas pogut èsser cargadas per aqueste element.",
-    "An error occured. Please try again" : "Una error s'es produsida. Mercé d'ensajar tornamai",
     "Share" : "Partejar",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Partejatz amb de personas sus d'autres ownClouds en utilizant la sintaxi utilizaire@exemple.com/owncloud",
-    "Share with users or groups …" : "Partejar amb d'utilizaires o gropes...",
-    "Share with users, groups or remote users …" : "Partejar amb d'utilizaires, gropes, o utilizaires distants",
     "Warning" : "Atencion",
     "Error while sending notification" : "Error al moment del mandadís de la notificacion",
     "Delete" : "Suprimir",
@@ -173,10 +177,8 @@ OC.L10N.register(
     "Hello {name}" : "Adiu {name}",
     "_download %n file_::_download %n files_" : ["Telecargar %n fichièr","Telecargar %n fichièrs"],
     "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "La mesa a jorn es en cors. Segon la configuracion, lo fach de quitar aquesta pagina pòt entraïnar l'interrupcion de la procedura.",
-    "Updating {productName} to version {version}, this may take a while." : "La mesa a jorn de {productName} cap a la version {version} es en cors. Aquò pòt prene un certan temps.",
     "An error occurred." : "Una error s'es produsida.",
     "Please reload the page." : "Recargatz la pagina.",
-    "The update was unsuccessful. " : "La mesa a jorn a fracassat.",
     "The update was successful. There were warnings." : "La mesa a jorn a capitat, mas i a agut d'avertiments",
     "The update was successful. Redirecting you to ownCloud now." : "La mesa a jorn a capitat. Ara sètz redirigit cap a ownCloud.",
     "Searching other places" : "Recèrca en cors dins d'autres emplaçaments",
@@ -187,13 +189,6 @@ OC.L10N.register(
     "Apps" : "Aplicacions",
     "Admin" : "Administracion",
     "Help" : "Ajuda",
-    "Error loading tags" : "Error al moment del cargament de las etiquetas",
-    "Tag already exists" : "L'etiqueta existís ja.",
-    "Error deleting tag(s)" : "Error de supression d'etiqueta(s)",
-    "Error tagging" : "Error al moment de l'etiquetatge",
-    "Error untagging" : "Error al moment del desetiquetatge",
-    "Error favoriting" : "Error al moment de la mesa en favorit",
-    "Error unfavoriting" : "Error al moment de la supression dels favorits",
     "Access forbidden" : "Accès interdich",
     "File not found" : "Fichièr pas trobat",
     "The specified document has not been found on the server." : "Impossible de trobar lo document especificat sul servidor.",
@@ -216,7 +211,6 @@ OC.L10N.register(
     "Trace" : "Traça",
     "Security warning" : "Avertiment de seguretat",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Vòstre repertòri de donadas es segurament accessible dempuèi l'internet perque lo fichièr .htaccess fonciona pas.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Per las informacions de configuracion de vòstre servidor, legissètz la <a href=\"%s\" target=\"_blank\">documentacion</a>.",
     "Create an <strong>admin account</strong>" : "Crear un <strong>compte administrator</strong>",
     "Username" : "Nom d'utilizaire",
     "Storage & database" : "Emmagazinatge & banca de donadas",
@@ -244,7 +238,6 @@ OC.L10N.register(
     "Search" : "Recercar",
     "Server side authentication failed!" : "L'autentificacion sul servidor a fracassat !",
     "Please contact your administrator." : "Contactatz vòstre administrator.",
-    "An internal error occured." : "Una error intèrna s'es produsida.",
     "Please try again or contact your administrator." : "Reensajatz o contactatz vòstre administrator.",
     "Log in" : "Connexion",
     "Wrong password. Reset it?" : "Senhal incorrècte. Reïnicializar ?",
@@ -270,8 +263,6 @@ OC.L10N.register(
     "Start update" : "Aviar la mesa a jorn",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Per fin d'evitar los timeouts amb las installacions de volum consequent, podètz executar la comanda seguenta dempuèi lo repertòri d'installacion :",
     "This %s instance is currently in maintenance mode, which may take a while." : "Aquesta instància de %s es en cors de mantenença, aquò pòt prene de temps.",
-    "This page will refresh itself when the %s instance is available again." : "Aquesta pagina se refrescarà d'ela-meteissa quand l'instància %s serà disponibla tornamai.",
-    "Repair error: " : "Error de reparacion :",
-    "Password can not be changed. Please contact your administrator." : "Lo senhal pòt pas èsser modificat. Contactatz vòstre administrator."
+    "This page will refresh itself when the %s instance is available again." : "Aquesta pagina se refrescarà d'ela-meteissa quand l'instància %s serà disponibla tornamai."
 },
 "nplurals=2; plural=(n > 1);");
