@@ -17,14 +17,6 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "Følgende platforme understøttes: %s",
     "ownCloud %s or higher is required." : "Der kræves ownCloud %s eller højere.",
     "ownCloud %s or lower is required." : "ownCloud %s eller lavere er påkrævet.",
-    "Help" : "Hjælp",
-    "Personal" : "Personligt",
-    "Users" : "Brugere",
-    "Admin" : "Admin",
-    "Recommended" : "Anbefalet",
-    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "App'en \"%s\" kan ikke installeres, da den er ikke er kompatibel med denne version af ownCloud.",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "App'en \"%s\" kan ikke installeres, da følgende krav ikke er opfyldt: %s ",
-    "No app name specified" : "Intet app-navn angivet",
     "Unknown filetype" : "Ukendt filtype",
     "Invalid image" : "Ugyldigt billede",
     "today" : "i dag",
@@ -37,7 +29,6 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["%n time siden","%n timer siden"],
     "_%n minute ago_::_%n minutes ago_" : ["%n minut siden","%n minutter siden"],
     "seconds ago" : "sekunder siden",
-    "web services under your control" : "Webtjenester under din kontrol",
     "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modulet med id'et %s findes ikke. Slå det venligst til i dine app-indstillinger eller kontakt din administrator.",
     "Empty filename is not allowed" : "Tomme filnavne er ikke tilladt",
     "Dot files are not allowed" : "Filer med punktummer er ikke tilladt",
@@ -45,8 +36,6 @@ OC.L10N.register(
     "File name is a reserved word" : "Filnavnet er et reserveret ord",
     "File name contains at least one invalid character" : "Filnavnet indeholder mindst ét ugyldigt tegn",
     "File name is too long" : "Filnavnet er for langt",
-    "File is currently busy, please try again later" : "Filen er i øjeblikket optaget - forsøg igen senere",
-    "Can't read file" : "Kan ikke læse filen",
     "App directory already exists" : "App-mappe findes allerede",
     "Can't create app folder. Please fix permissions. %s" : "Kan ikke oprette app-mappe. Ret tilladelser. %s",
     "Archive does not contain a directory named %s" : "Arkivet indeholder ike en mappe kaldet %s",
@@ -59,10 +48,6 @@ OC.L10N.register(
     "App can't be installed because of not allowed code in the App" : "Appen kan ikke installeres, da den indeholder ikke-tilladt kode",
     "App can't be installed because it is not compatible with this version of ownCloud" : "Appen kan ikke installeres, da den ikke er kompatibel med denne version af ownCloud.",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Appen kan ikke installeres, da den indeholder mærket <shipped>true</shipped>, hvilket ikke er tilladt for ikke-medfølgende apps",
-    "Application is not enabled" : "Programmet er ikke aktiveret",
-    "Authentication error" : "Adgangsfejl",
-    "Token expired. Please reload page." : "Adgang er udløbet. Genindlæs siden.",
-    "Unknown user" : "Ukendt bruger",
     "%s enter the database username." : "%s indtast database brugernavnet.",
     "%s enter the database name." : "%s indtast database navnet.",
     "%s you may not use dots in the database name" : "%s du må ikke bruge punktummer i databasenavnet.",
@@ -95,6 +80,7 @@ OC.L10N.register(
     "Sharing %s failed, because %s is not a member of the group %s" : "Der skete en fejl ved deling af %s, fordi %s ikke er medlem af gruppen %s",
     "You need to provide a password to create a public link, only protected links are allowed" : "Du skal angive et kodeord for at oprette et offentligt link - kun beskyttede links er tilladt",
     "Sharing %s failed, because sharing with links is not allowed" : "Der skete en fejl ved deling af %s, det er ikke tilladt at dele links",
+    "Not allowed to create a federated share with the same user" : "Det er ikke tilladt at danne et datafællesskab med samme bruger",
     "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Deling af %s mislykkedes - kunne ikke finde %s. Måske er serveren ikke tilgængelig i øjeblikket.",
     "Share type %s is not valid for %s" : "Delingstypen %s er ikke gyldig for %s",
     "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Angivelse af tilladelser for %s mislykkedes, fordi tilladelserne overskred de som var tildelt %s",
@@ -110,11 +96,29 @@ OC.L10N.register(
     "Sharing %s failed, because resharing is not allowed" : "Deling af %s mislykkedes, fordi videredeling ikke er tilladt",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Deling af %s mislykkedes, fordi back-enden ikke kunne finde kilden til %s",
     "Sharing %s failed, because the file could not be found in the file cache" : "Deling af %s mislykkedes, fordi filen ikke kunne findes i fil-cachen",
+    "Cannot increase permissions of %s" : "Kan give yderigere rettigheder til %s",
+    "Expiration date is in the past" : "Udløbsdatoen ligger tilbage i tid",
+    "Cannot set expiration date more than %s days in the future" : "Udløbsdato kan ikke sættes mere end %s dage ud i fremtiden",
     "Could not find category \"%s\"" : "Kunne ikke finde kategorien \"%s\"",
     "Apps" : "Apps",
     "A valid username must be provided" : "Et gyldigt brugernavn skal angives",
     "A valid password must be provided" : "En gyldig adgangskode skal angives",
     "The username is already being used" : "Brugernavnet er allerede i brug",
+    "Help" : "Hjælp",
+    "Personal" : "Personligt",
+    "Users" : "Brugere",
+    "Admin" : "Admin",
+    "Recommended" : "Anbefalet",
+    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "App'en \"%s\" kan ikke installeres, da den er ikke er kompatibel med denne version af ownCloud.",
+    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "App'en \"%s\" kan ikke installeres, da følgende krav ikke er opfyldt: %s ",
+    "No app name specified" : "Intet app-navn angivet",
+    "web services under your control" : "Webtjenester under din kontrol",
+    "File is currently busy, please try again later" : "Filen er i øjeblikket optaget - forsøg igen senere",
+    "Can't read file" : "Kan ikke læse filen",
+    "Application is not enabled" : "Programmet er ikke aktiveret",
+    "Authentication error" : "Adgangsfejl",
+    "Token expired. Please reload page." : "Adgang er udløbet. Genindlæs siden.",
+    "Unknown user" : "Ukendt bruger",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Ingen database driver (sqlite, mysql eller postgresql) er installeret.",
     "Microsoft Windows Platform is not supported" : "Microsoft Windows platformen er ikke understøttet",
     "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "OwnCloud på en Micorsoft Windows platform er ikke understøttet. Vi foreslår du bruger en Linux server på en virtuel maskine, hvis du ikke har mulighed for at migrere til en fysisk server. Find Linux pakker og nemme udrulnings virtuelle maskine-installationer på <a href=\"%s\">%s</a>. For migrering af eksisterende installationer til Linux kan du finde tips og migrerings scripts i <a href=\"%s\">vores dokumentation</a>.",
@@ -122,7 +126,6 @@ OC.L10N.register(
     "Cannot write into \"apps\" directory" : "Kan ikke skrive til mappen \"apps\"",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Dette kan som regel rettes ved at %sgive webserveren skriveadgang til apps-mappen%s eller slå appstore fra i config-filen.",
     "Cannot create \"data\" directory (%s)" : "Kan ikke oprette mappen \"data\" (%s)",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Dette kan som regel rettes ved <a href=\"%s\" target=\"_blank\">give webserveren skriveadgang til rodmappen</a>.",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Rettigheder kan som regel rettes ved %sat give webserveren skriveadgang til rodmappen%s.",
     "Setting locale to %s failed" : "Angivelse af %s for lokalitet mislykkedes",
     "Please install one of these locales on your system and restart your webserver." : "Installér venligst én af disse lokaliteter på dit system, og genstart din webserver.",
