@@ -9,6 +9,7 @@ OC.L10N.register(
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "È stato rilevato che la configurazione di esempio è stata copiata. Ciò può compromettere la tua installazione e non è supportato. Leggi la documentazione prima di modificare il file config.php",
     "PHP %s or higher is required." : "Richiesto PHP %s o superiore",
     "PHP with a version lower than %s is required." : "Richiesta una versione di PHP minore di %s.",
+    "%sbit or higher PHP required." : "Richiesto PHP %sbit o superiore.",
     "Following databases are supported: %s" : "I seguenti database sono supportati: %s",
     "The command line tool %s could not be found" : "Lo strumento da riga di comando %s non è stato trovato",
     "The library %s is not available." : "La libreria %s non è disponibile.",
@@ -17,14 +18,6 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "Sono supportate le seguenti piattaforme: %s",
     "ownCloud %s or higher is required." : "Richiesto ownCloud %s o superiore.",
     "ownCloud %s or lower is required." : "Richiesto ownCloud %s o inferiore.",
-    "Help" : "Aiuto",
-    "Personal" : "Personale",
-    "Users" : "Utenti",
-    "Admin" : "Admin",
-    "Recommended" : "Consigliata",
-    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "L'applicazione \"%s\" non può essere installata poiché non è compatibile con questa versione di ownCloud.",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "L'applicazione \"%s\" non può essere installata poiché le seguenti dipendenze non sono soddisfatte: %s",
-    "No app name specified" : "Il nome dell'applicazione non è specificato",
     "Unknown filetype" : "Tipo di file sconosciuto",
     "Invalid image" : "Immagine non valida",
     "today" : "oggi",
@@ -37,7 +30,6 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["%n ora fa","%n ore fa"],
     "_%n minute ago_::_%n minutes ago_" : ["%n minuto fa","%n minuti fa"],
     "seconds ago" : "secondi fa",
-    "web services under your control" : "servizi web nelle tue mani",
     "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Il modulo con id: %s non esiste. Abilitalo nelle impostazioni delle applicazioni o contatta il tuo amministratore.",
     "Empty filename is not allowed" : "Un nome di file vuoto non è consentito",
     "Dot files are not allowed" : "I file con un punto iniziale non sono consentiti",
@@ -45,8 +37,6 @@ OC.L10N.register(
     "File name is a reserved word" : "Il nome del file è una parola riservata",
     "File name contains at least one invalid character" : "Il nome del file contiene almeno un carattere non valido",
     "File name is too long" : "Il nome del file è troppo lungo",
-    "File is currently busy, please try again later" : "Il file è attualmente occupato, riprova più tardi",
-    "Can't read file" : "Impossibile leggere il file",
     "App directory already exists" : "La cartella dell'applicazione esiste già",
     "Can't create app folder. Please fix permissions. %s" : "Impossibile creare la cartella dell'applicazione. Correggi i permessi. %s",
     "Archive does not contain a directory named %s" : "L'archivio non contiene una cartella con nome %s",
@@ -56,15 +46,13 @@ OC.L10N.register(
     "Archives of type %s are not supported" : "Gli archivi di tipo %s non sono supportati",
     "Failed to open archive when installing app" : "Apertura archivio non riuscita durante l'installazione dell'applicazione",
     "App does not provide an info.xml file" : "L'applicazione non fornisce un file info.xml",
+    "App cannot be installed because appinfo file cannot be read." : "L'applicazione non può essere installata poiché il file appinfo non può essere letto.",
     "Signature could not get checked. Please contact the app developer and check your admin screen." : "La firma non può essere verificata. Contatta lo sviluppatore dell'applicazione e controlla la schermata di amministrazione.",
     "App can't be installed because of not allowed code in the App" : "L'applicazione non può essere installata a causa di codice non consentito al suo interno",
     "App can't be installed because it is not compatible with this version of ownCloud" : "L'applicazione non può essere installata poiché non è compatibile con questa versione di ownCloud",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "L'applicazione non può essere installata poiché contiene il tag <shipped>true<shipped> che è consentito per le applicazioni native",
     "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "L'applicazione non può essere installata poiché la versione nel file info.xml non è la stessa riportata dall'app store",
-    "Application is not enabled" : "L'applicazione  non è abilitata",
-    "Authentication error" : "Errore di autenticazione",
-    "Token expired. Please reload page." : "Token scaduto. Ricarica la pagina.",
-    "Unknown user" : "Utente sconosciuto",
+    "%s enter the database username and name." : "%s digita il nome utente e il nome del database.",
     "%s enter the database username." : "%s digita il nome utente del database.",
     "%s enter the database name." : "%s digita il nome del database.",
     "%s you may not use dots in the database name" : "%s non dovresti utilizzare punti nel nome del database",
@@ -114,6 +102,8 @@ OC.L10N.register(
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Condivisione di %s non riuscita, poiché il motore di condivisione per %s non riesce a trovare la sua fonte",
     "Sharing %s failed, because the file could not be found in the file cache" : "Condivisione di %s non riuscita, poiché il file non è stato trovato nella cache",
     "Cannot increase permissions of %s" : "Impossibile aumentare i permessi di %s",
+    "Files can't be shared with delete permissions" : "I file non possono essere condivisi con permessi di eliminazione",
+    "Files can't be shared with create permissions" : "I file non possono essere condivisi con permessi di creazione",
     "Expiration date is in the past" : "La data di scadenza è nel passato",
     "Cannot set expiration date more than %s days in the future" : "Impossibile impostare la data di scadenza a più di %s giorni nel futuro",
     "Could not find category \"%s\"" : "Impossibile trovare la categoria \"%s\"",
@@ -123,6 +113,24 @@ OC.L10N.register(
     "Username contains whitespace at the beginning or at the end" : "Il nome utente contiene spazi all'inizio o alla fine",
     "A valid password must be provided" : "Deve essere fornita una password valida",
     "The username is already being used" : "Il nome utente è già utilizzato",
+    "Login canceled by app" : "Accesso annullato dall'applicazione",
+    "User disabled" : "Utente disabilitato",
+    "Help" : "Aiuto",
+    "Personal" : "Personale",
+    "Users" : "Utenti",
+    "Admin" : "Admin",
+    "Recommended" : "Consigliata",
+    "App \"%s\" cannot be installed because appinfo file cannot be read." : "L'applicazione \"%s\" non può essere installata poiché il file appinfo non può essere letto.",
+    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "L'applicazione \"%s\" non può essere installata poiché non è compatibile con questa versione di ownCloud.",
+    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "L'applicazione \"%s\" non può essere installata poiché le seguenti dipendenze non sono soddisfatte: %s",
+    "No app name specified" : "Il nome dell'applicazione non è specificato",
+    "web services under your control" : "servizi web nelle tue mani",
+    "File is currently busy, please try again later" : "Il file è attualmente occupato, riprova più tardi",
+    "Can't read file" : "Impossibile leggere il file",
+    "Application is not enabled" : "L'applicazione  non è abilitata",
+    "Authentication error" : "Errore di autenticazione",
+    "Token expired. Please reload page." : "Token scaduto. Ricarica la pagina.",
+    "Unknown user" : "Utente sconosciuto",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Nessun driver di database (sqlite, mysql o postgresql) installato",
     "Microsoft Windows Platform is not supported" : "La piattaforma Microsoft Windows non è supportata",
     "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "L'esecuzione del server ownCloud sulla piattaforma Microsoft Windows non è supportata. Ti suggeriamo di utilizzare un server Linux in una macchina virtuale, se non hai la possibilità di migrare il server. Puoi trovare i pacchetti per Linux o immagini di macchine virtuali da istanziare su <a href=\"%s\">%s</a>. Per la migrazione di installazioni esistenti su Linux, puoi trovare alcuni suggerimenti e uno script di migrazione nella <a href=\"%s\">nostra documentazione</a>.",
@@ -130,7 +138,7 @@ OC.L10N.register(
     "Cannot write into \"apps\" directory" : "Impossibile scrivere nella cartella \"apps\"",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Ciò può essere normalmente corretto %sfornendo al server web accesso in scrittura alla cartella \"apps\"%s o disabilitando il negozio di applicazioni nel file di configurazione.",
     "Cannot create \"data\" directory (%s)" : "Impossibile creare la cartella \"data\" (%s)",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Ciò può essere normalmente corretto <a href=\"%s\" target=\"_blank\">fornendo al server web accesso in scrittura alla cartella radice</a>.",
+    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Ciò può essere normalmente corretto <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">fornendo al server web accesso in scrittura alla cartella radice</a>.",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "I permessi possono essere normalmente corretti %sfornendo al server web accesso in scrittura alla cartella radice%s.",
     "Setting locale to %s failed" : "L'impostazione della localizzazione a %s non è riuscita",
     "Please install one of these locales on your system and restart your webserver." : "Installa una delle seguenti localizzazioni sul tuo sistema e riavvia il server web.",
@@ -140,6 +148,8 @@ OC.L10N.register(
     "Adjusting this setting in php.ini will make ownCloud run again" : "La modifica di questa impostazione nel file php.ini permetterà nuovamente l'esecuzione di ownCloud",
     "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload è impostata a \"%s\" invece del valore atteso \"0\"",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Per correggere questo problema, imposta <code>mbstring.func_overload</code> a <code>0</code> nel tuo php.ini",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "È richiesta almeno la versione 2.7.0 di libxml2. Quella attualmente installata è la %s.",
+    "To fix this issue update your libxml2 version and restart your web server." : "Per risolvere questo problema, aggiorna la tua versione di libxml2 e riavvia il server web.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Sembra che PHP sia configurato per rimuovere i blocchi di documentazione in linea. Ciò renderà inaccessibili diverse applicazioni principali.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ciò è causato probabilmente da una cache/acceleratore come Zend OPcache o eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Sono stati installati moduli PHP, ma sono elencati ancora come mancanti?",
