@@ -1,13 +1,13 @@
 OC.L10N.register(
     "lib",
     {
-    "Help" : "సహాయం",
-    "Personal" : "వ్యక్తిగతం",
-    "Users" : "వాడుకరులు",
     "today" : "ఈరోజు",
     "yesterday" : "నిన్న",
     "last month" : "పోయిన నెల",
     "last year" : "పోయిన సంవత్సరం",
-    "seconds ago" : "క్షణాల క్రితం"
+    "seconds ago" : "క్షణాల క్రితం",
+    "Help" : "సహాయం",
+    "Personal" : "వ్యక్తిగతం",
+    "Users" : "వాడుకరులు"
 },
 "nplurals=2; plural=(n != 1);");
