@@ -1,22 +1,9 @@
 OC.L10N.register(
     "settings",
     {
-    "Security & setup warnings" : "Təhlükəsizlik & işə salma xəbərdarlıqları",
-    "Sharing" : "Paylaşılır",
-    "External Storage" : "Kənar depo",
-    "Cron" : "Cron",
-    "Log" : "Jurnal",
-    "Updates" : "Yenilənmələr",
-    "Couldn't remove app." : "Proqram təminatını silmək mümkün olmadı.",
-    "Language changed" : "Dil dəyişdirildi",
-    "Invalid request" : "Səhv müraciət",
-    "Authentication error" : "Təyinat metodikası",
-    "Admins can't remove themself from the admin group" : "İnzibatçılar özlərini inzibatçı qrupundan silə bilməz",
-    "Unable to add user to group %s" : "İstifadəçini %s qrupuna əlavə etmək mümkün olmadı",
-    "Unable to remove user from group %s" : "İstifadəçini %s qrupundan silmək mümkün olmadı",
-    "Couldn't update app." : "Proqram təminatını yeniləmək mümkün deyil.",
     "Wrong password" : "Yalnış şifrə",
     "No user supplied" : "Heç bir istifadəçiyə mənimsədilmir",
+    "Authentication error" : "Təyinat metodikası",
     "Please provide an admin recovery password, otherwise all user data will be lost" : "Xahış olunur inzibatçı geriyə qayıdış şifrəsini təqdim edəsiniz, əks halda bütün istfadəçi datası itəcək.",
     "Wrong admin recovery password. Please check the password and try again." : "İnzibatçı geriyə qayıdış şifrəsi yalnışdır. Xahiş olunur şifrəni yoxlayıb yenidən təkrar edəsiniz.",
     "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Arxa sonluq şifrənin dəyişdirilməsini dəstəkləmir ancaq, istifadəçi şifrələmə açarı uğurla yeniləndi.",
@@ -44,6 +31,19 @@ OC.L10N.register(
     "Email saved" : "Məktub yadda saxlanıldı",
     "Your full name has been changed." : "Sizin tam adınız dəyişdirildi.",
     "Unable to change full name" : "Tam adı dəyişmək olmur",
+    "Security & setup warnings" : "Təhlükəsizlik & işə salma xəbərdarlıqları",
+    "Sharing" : "Paylaşılır",
+    "External Storage" : "Kənar depo",
+    "Cron" : "Cron",
+    "Log" : "Jurnal",
+    "Updates" : "Yenilənmələr",
+    "Couldn't remove app." : "Proqram təminatını silmək mümkün olmadı.",
+    "Language changed" : "Dil dəyişdirildi",
+    "Invalid request" : "Səhv müraciət",
+    "Admins can't remove themself from the admin group" : "İnzibatçılar özlərini inzibatçı qrupundan silə bilməz",
+    "Unable to add user to group %s" : "İstifadəçini %s qrupuna əlavə etmək mümkün olmadı",
+    "Unable to remove user from group %s" : "İstifadəçini %s qrupundan silmək mümkün olmadı",
+    "Couldn't update app." : "Proqram təminatını yeniləmək mümkün deyil.",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "\"{domain}\" adını inamlı domainlər siyahısına əlavə etməyinizdən əminsinizmi?",
     "Add trusted domain" : "İnamlı domainlərə əlavə et",
     "Sending..." : "Göndərilir...",
@@ -83,6 +83,7 @@ OC.L10N.register(
     "A valid password must be provided" : "Düzgün şifrə daxil edilməlidir",
     "A valid email must be provided" : "Düzgün email təqdim edilməlidir",
     "__language_name__" : "__AZ_Azerbaijan__",
+    "Unlimited" : "Limitsiz",
     "Personal info" : "Şəxsi məlumat",
     "Sync clients" : "Müştəriləri sinxronizasiya et",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Hər şey(ən pis hadisələr, səhvlər, xəbərdarlıqlar, məlmat, araşdırma səhvləri)",
@@ -109,10 +110,10 @@ OC.L10N.register(
     "Open documentation" : "Sənədləri aç",
     "Allow apps to use the Share API" : "Proqramlara izin verin ki, Paylaşım API-sindən istifadə edə bilsinlər.",
     "Allow users to share via link" : "Istifadəçilərə link üzərindən paylaşım etməyə izin vermək",
-    "Enforce password protection" : "Şifrə müdafiəsini həyata keçirmək",
     "Allow public uploads" : "Ümumi yüklənmələrə izin vermək",
-    "Allow users to send mail notification for shared files" : "Yayımlanmış fayllar üçün, istifadəçilərə məktubla xəbərdarlığın yollanmasına izin verir",
+    "Enforce password protection" : "Şifrə müdafiəsini həyata keçirmək",
     "Set default expiration date" : "Susmaya görə olan bitmə vaxtını təyin edin",
+    "Allow users to send mail notification for shared files" : "Yayımlanmış fayllar üçün, istifadəçilərə məktubla xəbərdarlığın yollanmasına izin verir",
     "Expire after " : "Bitir sonra",
     "days" : "günlər",
     "Enforce expiration date" : "Bitmə tarixini həyata keçir",
@@ -184,6 +185,9 @@ OC.L10N.register(
     "Change password" : "Şifrəni dəyiş",
     "Language" : "Dil",
     "Help translate" : "Tərcüməyə kömək",
+    "Name" : "Ad",
+    "Username" : "İstifadəçi adı",
+    "Done" : "Edildi",
     "Get the apps to sync your files" : "Fayllarınızın sinxronizasiyası üçün proqramları götürün",
     "Desktop client" : "Desktop client",
     "Android app" : "Android proqramı",
@@ -196,7 +200,6 @@ OC.L10N.register(
     "Show user backend" : "Daxili istifadəçini göstər",
     "Send email to new user" : "Yeni istifadəçiyə məktub yolla",
     "Show email address" : "Email ünvanını göstər",
-    "Username" : "İstifadəçi adı",
     "E-Mail" : "E-Mail",
     "Create" : "Yarat",
     "Admin Recovery Password" : "İnzibatçı bərpa şifrəsi",
@@ -207,7 +210,6 @@ OC.L10N.register(
     "Admins" : "İnzibatçılar",
     "Default Quota" : "Susmaya görə olan norma",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Xahiş olunur depo normasını daxil edəsiniz (Məs: \"512 MB\" yada \"12 GB\")",
-    "Unlimited" : "Limitsiz",
     "Other" : "Digər",
     "Full Name" : "Tam ad",
     "Group Admin for" : "üçün qrup inzibatçısı",
