@@ -1,34 +1,18 @@
 OC.L10N.register(
     "settings",
     {
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Security & setup warnings" : "Sicherheits- & Einrichtungswarnungen",
-    "Sharing" : "Teilen",
-    "Server-side encryption" : "Serverseitige Verschlüsselung",
-    "External Storage" : "Externer Speicher",
-    "Cron" : "Cron",
-    "Email server" : "E-Mail-Server",
-    "Log" : "Log",
-    "Tips & tricks" : "Tipps & Tricks",
-    "Updates" : "Updates",
-    "Couldn't remove app." : "Die App konnte nicht entfernt werden.",
-    "Language changed" : "Sprache geändert",
-    "Invalid request" : "Ungültige Anforderung",
-    "Authentication error" : "Authentifizierungsfehler",
-    "Admins can't remove themself from the admin group" : "Administratoren können sich nicht selbst aus der admin-Gruppe löschen",
-    "Unable to add user to group %s" : "Der Benutzer konnte nicht zur Gruppe %s hinzugefügt werden",
-    "Unable to remove user from group %s" : "Der Benutzer konnte nicht aus der Gruppe %s entfernt werden",
-    "Couldn't update app." : "Die App konnte nicht aktualisiert werden.",
     "Wrong password" : "Falsches Passwort",
     "No user supplied" : "Keinen Benutzer angegeben",
+    "Authentication error" : "Authentifizierungsfehler",
     "Please provide an admin recovery password, otherwise all user data will be lost" : "Bitte geben Sie ein Wiederherstellungspasswort für das Administratorkonto an, da sonst alle Benutzerdaten verlorengehen können",
     "Wrong admin recovery password. Please check the password and try again." : "Falsches Wiederherstellungspasswort für das Admin-Konto. Bitte überprüfen Sie das Passwort und versuchen Sie es erneut.",
     "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Das Backend unterstützt die Passwortänderung nicht, aber der Benutzerschlüssel wurde erfolgreich aktualisiert.",
     "Unable to change password" : "Passwort konnte nicht geändert werden",
     "Enabled" : "Aktiviert",
     "Not enabled" : "Nicht aktiviert",
+    "installing and updating apps via the app store or Federated Cloud Sharing" : "Das Installieren und Aktualisieren von Apps durch den App-Store oder durch Federated Cloud Sharing",
     "Federated Cloud Sharing" : "Federated-Cloud-Sharing",
+    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL verwendet eine veraltete %s Version (%s). Bitte aktualisieren Sie ihr Betriebssystem, da ansonsten Funktionen, wie z.B. %s, nicht zuverlässig funktionieren werden.",
     "A problem occurred, please check your log files (Error: %s)" : "Es ist ein Problem aufgetreten, bitte überprüfen Sie Ihre Logdateien (Fehler: %s)",
     "Migration Completed" : "Migration abgeschlossen",
     "Group already exists." : "Gruppe existiert bereits.",
@@ -51,6 +35,24 @@ OC.L10N.register(
     "Email saved" : "E-Mail-Adresse gespeichert",
     "Your full name has been changed." : "Ihr vollständiger Name ist geändert worden.",
     "Unable to change full name" : "Der vollständige Name konnte nicht geändert werden",
+    "APCu" : "APCu",
+    "Redis" : "Redis",
+    "Security & setup warnings" : "Sicherheits- & Einrichtungswarnungen",
+    "Sharing" : "Teilen",
+    "Server-side encryption" : "Serverseitige Verschlüsselung",
+    "External Storage" : "Externer Speicher",
+    "Cron" : "Cron",
+    "Email server" : "E-Mail-Server",
+    "Log" : "Log",
+    "Tips & tricks" : "Tipps & Tricks",
+    "Updates" : "Updates",
+    "Couldn't remove app." : "Die App konnte nicht entfernt werden.",
+    "Language changed" : "Sprache geändert",
+    "Invalid request" : "Ungültige Anforderung",
+    "Admins can't remove themself from the admin group" : "Administratoren können sich nicht selbst aus der admin-Gruppe löschen",
+    "Unable to add user to group %s" : "Der Benutzer konnte nicht zur Gruppe %s hinzugefügt werden",
+    "Unable to remove user from group %s" : "Der Benutzer konnte nicht aus der Gruppe %s entfernt werden",
+    "Couldn't update app." : "Die App konnte nicht aktualisiert werden.",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "Sind Sie sich wirklich sicher, dass Sie »{domain}« als vertrauenswürdige Domain hinzufügen möchten?",
     "Add trusted domain" : "Vertrauenswürdige Domain hinzufügen",
     "Migration in progress. Please wait until the migration is finished" : "Migration in Arbeit. Bitte warten Sie, bis die Migration beendet ist",
@@ -61,15 +63,20 @@ OC.L10N.register(
     "Experimental" : "Experimentell",
     "All" : "Alle",
     "No apps found for your version" : "Es wurden keine Apps für Ihre Version gefunden",
+    "The app will be downloaded from the app store" : "Die App wird aus dem App-Store heruntergeladen",
     "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Offizielle Apps werden von und innerhalb der ownCloud-Community entwickelt. Sie stellen zentrale Funktionen von ownCloud bereit und sind auf den Produktiveinsatz vorbereitet.",
     "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Geprüfte Apps werden von vertrauenswürdigen Entwicklern entwickelt und haben eine oberflächliche Sicherheitsprüfung durchlaufen. Sie werden innerhalb eines offenen Code-Repositorys aktiv gepflegt und ihre Betreuer erachten sie als stabil genug für für den gelegentlichen bis normalen Einsatz.",
     "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Diese App ist nicht auf Sicherheitsprobleme hin überprüft und ist neu oder bekanntermaßen instabil. Die Installation erfolgt auf eigenes Risiko.",
     "Update to %s" : "Aktualisierung auf %s",
+    "_You have %n app update pending_::_You have %n app updates pending_" : ["Sie haben %n Aktualisierung verfügbar","Sie haben %n Aktualisierungen verfügbar"],
     "Please wait...." : "Bitte warten…",
     "Error while disabling app" : "Beim Deaktivieren der App ist ein Fehler aufgetreten",
     "Disable" : "Deaktivieren",
     "Enable" : "Aktivieren",
     "Error while enabling app" : "Beim Aktivieren der App ist ein Fehler aufgetreten",
+    "Error: this app cannot be enabled because it makes the server unstable" : "Fehler: Diese App kann nicht aktiviert werden, da es den Server instabil macht.",
+    "Error: could not disable broken app" : "Fehler: Die beschädigte Anwendung konnte nicht deaktiviert werden",
+    "Error while disabling broken app" : "Beim Deaktivieren der defekten App ist ein Fehler aufgetreten",
     "Updating...." : "Update…",
     "Error while updating app" : "Es ist ein Fehler während des Updates aufgetreten",
     "Updated" : "Aktualisiert",
@@ -78,7 +85,11 @@ OC.L10N.register(
     "Uninstall" : "Deinstallieren",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Die App wurde aktiviert, aber sie benötigt ein Update. Sie werden zur Update Seite in 5 Sekunden weitergeleitet.",
     "App update" : "App aktualisieren",
-    "No apps found for \"{query}\"" : "Es wurden keine Apps gefunden für \"{query}\"",
+    "No apps found for {query}" : "Keine Applikationen für {query} gefunden",
+    "Disconnect" : "Trennen",
+    "Error while loading browser sessions and device tokens" : "Fehler beim Laden der Browser-Sitzungen und Gerätetoken",
+    "Error while creating device token" : "Fehler beim Erstellen des Gerätetokens",
+    "Error while deleting the token" : "Fehler beim Löschen des Gerätetokens",
     "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Es ist ein Fehler aufgetreten. Bitte laden Sie ein ASCII-kodiertes PEM-Zertifikat hoch.",
     "Valid until {date}" : "Gültig bis {date}",
     "Delete" : "Löschen",
@@ -91,6 +102,7 @@ OC.L10N.register(
     "Strong password" : "Starkes Passwort",
     "Groups" : "Gruppen",
     "Unable to delete {objName}" : "Löschen von {objName} nicht möglich",
+    "Error creating group: {message}" : "Fehler beim Erstellen einer Gruppe: {message}",
     "A valid group name must be provided" : "Ein gültiger Gruppenname muss angegeben werden",
     "deleted {groupName}" : "{groupName} gelöscht",
     "undo" : "rückgängig machen",
@@ -100,10 +112,14 @@ OC.L10N.register(
     "add group" : "Gruppe hinzufügen",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "Die Änderung des Passworts führt zu Datenverlust, weil die Datenwiederherstellung für diesen Benutzer nicht verfügbar ist",
     "A valid username must be provided" : "Es muss ein gültiger Benutzername angegeben werden",
+    "Error creating user: {message}" : "Fehler beim Erstellen eines Benutzers: {message}",
     "A valid password must be provided" : "Es muss ein gültiges Passwort angegeben werden",
     "A valid email must be provided" : "Es muss eine gültige E-Mail-Adresse angegeben werden",
     "__language_name__" : "Deutsch (Förmlich: Sie)",
+    "Unlimited" : "Unbegrenzt",
     "Personal info" : "Persönliche Informationen",
+    "Sessions" : "Sitzungen",
+    "App passwords" : "App-Passwörter",
     "Sync clients" : "Sync-Clients",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Alles (fatale Probleme, Fehler, Warnungen, Infos, Fehlerdiagnose)",
     "Info, warnings, errors and fatal issues" : "Infos, Warnungen, Fehler und fatale Probleme",
@@ -117,29 +133,34 @@ OC.L10N.register(
     "SSL" : "SSL",
     "TLS" : "TLS",
     "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP scheint zur Abfrage von Systemumgebungsvariablen nicht richtig eingerichtet zu sein. Der Test mit getenv (\"PATH\") liefert nur eine leere Antwort zurück.",
+    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Bitte schauen Sie in der <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">Installationsdokumentation ↗</a>auf Hinweise zur PHP-Konfiguration, sowie die PHP-Konfiguration ihres Servers, insbesondere dann, wenn Sie PHP-FPM einsetzten.",
     "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Die schreibgeschützte Konfiguration wurde aktiviert. Dies verhindert das Setzen einiger Einstellungen über die Web-Schnittstelle. Weiterhin muss bei jedem Update der Schreibzugriff auf die Datei händisch aktiviert werden.",
     "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ist offenbar so konfiguriert, dass PHPDoc-Blöcke in der Anweisung entfernt werden. Dadurch sind mehrere Kern-Apps nicht erreichbar.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dies wird wahrscheinlich durch Zwischenspeicher/Beschleuniger wie etwa Zend OPcache oder eAccelerator verursacht.",
+    "Your database does not run with \"READ COMMITED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "ihre Datenbank läuft nicht mit der \"READ COMMITED\" Transaktionsisolationsstufe. Dies kann Probleme hervorrufen, wenn mehrere Aktionen parallel ausgeführt werden.",
     "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Ihr Server wird mit Microsoft Windows betrieben. Für ein optimales Nutzungserlebnis empfehlen wir dringend Linux.",
+    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s ist in einer älteren Version als %2$s installiert. Aus Stabilitäts- und Performancegründen empfehlen wir eine Aktualisierung auf eine neuere %1$s-Version",
     "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Das PHP-Modul 'fileinfo' fehlt. Wir empfehlen Ihnen dieses Modul zu aktivieren, um die besten Resultate bei der Bestimmung der Dateitypen zu erzielen.",
+    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Transaktionales Sperren ist deaktiviert, was zu Problemen mit Laufzeitbedingungen führen kann. Aktivieren Sie 'filelocking.enabled' in der config.php  diese Probleme zu vermeiden. Weitere Informationen findest Sie in unserer <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">Dokumentation ↗</a>.",
     "System locale can not be set to a one which supports UTF-8." : "Es kann kein Systemgebietsschema gesetzt werden, das UTF-8 unterstützt.",
     "This means that there might be problems with certain characters in file names." : "Dies bedeutet, dass es zu Problemen mit bestimmten Zeichen in Dateinamen kommen kann.",
     "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Wir empfehlen dringend, die erforderlichen Pakete auf Ihrem System zu installieren, damit eines der folgenden Gebietsschemata unterstützt wird: %s.",
     "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Wenn sich Ihre Installation nicht im Wurzelverzeichnis der Domain befindet und Cron aus dem System genutzt wird, kann es zu Fehlern bei der URL-Generierung kommen. Um dies zu verhindern, setzen Sie bitte die „overwrite.cli.url“-Option in Ihrer config.php auf das Web-Wurzelverzeichnis Ihrer Installation (Vorschlag: „%s“).",
     "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Die Ausführung des Cron-Jobs über die Kommandozeile war nicht möglich. Die folgenden technischen Fehler sind dabei aufgetreten:",
-    "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Bitte überprüfen Sie noch einmal die <a target=\"_blank\" href=\"%s\">Installationsanleitungen ↗</a> und kontrollieren Sie das <a href=\"#log-section\">Log</a> auf mögliche Fehler oder Warnungen.",
-    "All checks passed." : "Alle checks erfolgreich gepfüft.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Bitte überprüfen Sie noch einmal die <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">Installationsanleitungen ↗</a> und kontrollieren Sie das <a href=\"#log-section\">Log</a> auf mögliche Fehler oder Warnungen.",
+    "All checks passed." : "Alle Checks bestanden.",
     "Open documentation" : "Dokumentation öffnen",
     "Allow apps to use the Share API" : "Apps die Benutzung der Share-API erlauben",
     "Allow users to share via link" : "Benutzern erlauben, Inhalte über Links zu teilen",
-    "Enforce password protection" : "Passwortschutz erzwingen",
     "Allow public uploads" : "Öffentliches Hochladen erlauben",
-    "Allow users to send mail notification for shared files" : "Benutzern erlauben, E-Mail-Benachrichtigungen für freigegebene Dateien zu senden",
+    "Enforce password protection" : "Passwortschutz erzwingen",
     "Set default expiration date" : "Standardmäßiges Ablaufdatum setzen",
+    "Allow users to send mail notification for shared files" : "Benutzern erlauben, E-Mail-Benachrichtigungen für freigegebene Dateien zu senden",
     "Expire after " : "Ablauf nach ",
     "days" : "Tagen",
     "Enforce expiration date" : "Ablaufdatum erzwingen",
     "Allow resharing" : "Weiterverteilen erlauben",
+    "Allow sharing with groups" : "Mit Gruppen teilen erlauben",
     "Restrict users to only share with users in their groups" : "Benutzer auf das Teilen innerhalb ihrer Gruppen beschränken",
     "Allow users to send mail notification for shared files to other users" : "Benutzern erlauben, E-Mail-Benachrichtigungen für freigegebene Dateien an andere Benutzer zu senden",
     "Exclude groups from sharing" : "Gruppen von Freigaben ausschließen",
@@ -153,7 +174,10 @@ OC.L10N.register(
     "Use system's cron service to call the cron.php file every 15 minutes." : "Benutzen Sie den systemeigenen Cron-Dienst, um die cron.php alle 15 Minuten aufzurufen.",
     "Enable server-side encryption" : "Serverseitige Verschlüsselung aktivieren",
     "Please read carefully before activating server-side encryption: " : "Bitte lesen Sie ganz genau, bevor Sie die Serverseite Verschlüsselung aktivieren:",
+    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Wird die Verschlüsselung einmal aktiviert, so werden alle ab diesem Zeitpunkt hochgeladene Dateien verschlüsselt. Sie kann nur wieder deaktiviert werden, wenn das Verschlüsselungsmodul dies unterstützt und alle Voraussetzungen (wie das Setzen eines Wiederherstellungsschlüssels) im Vorhinein erfüllt wurden.",
+    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "Verschlüsselung an sich garantiert nicht die Sicherheit des Systems. Bitte schauen Sie in die ownCloud Dokumentation für weitere Informationen wie die Verschlüsselungs-App funktioniert und welche Anwendungsfälle unterstützt werden.",
     "Be aware that encryption always increases the file size." : "Bedenke das durch die Verschlüsselung die Dateigröße zunimmt. ",
+    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Es ist immer gut, regelmäßig Sicherungskopien von ihren Daten zu machen. Falls Sie die Verschlüsselung nutzen, sollten Sie auch eine Sicherung der Verschlüsselungsschlüssel zusammen mit ihren Daten machen.",
     "This is the final warning: Do you really want to enable encryption?" : "Dies ist die letzte Warnung: Wollen Sie die Verschlüsselung wirklich aktivieren?",
     "Enable encryption" : "Verschlüsselung aktivieren",
     "No encryption module loaded, please enable an encryption module in the app menu." : "Kein Verschlüsselungs-Modul geladen, bitte aktiviere ein Verschlüsselungs-Modul im Anwendungs-Menü.",
@@ -183,7 +207,7 @@ OC.L10N.register(
     "What to log" : "Was geloggt wird",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite wird als Datenbank verwendet. Bei größeren Installationen wird empfohlen, auf ein anderes Datenbank-Backend zu wechseln.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Insbesondere bei der Nutzung des Desktop Clients zur Dateisynchronisierung wird vom Einsatz von SQLite abgeraten.",
-    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "Um auf eine andere Datenbank zu migrieren, benutzen Sie bitte die Kommandozeile: „occ db:convert-type“ oder konsultieren Sie die <a target=\"_blank\" href=\"%s\">Dokumentation ↗</a>.",
+    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Um zu einer anderen Datenbank zu migrieren, benutzen Sie bitte die Kommandozeile: 'occ db:convert-type', oder in die <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">Dokumentation ↗</a> schauen.",
     "How to do backups" : "Wie man Backups anlegt",
     "Advanced monitoring" : "Erweitertes Monitoring",
     "Performance tuning" : "Leistungsoptimierung",
@@ -199,10 +223,13 @@ OC.L10N.register(
     "Documentation:" : "Dokumentation:",
     "User documentation" : "Dokumentation für Benutzer",
     "Admin documentation" : "Dokumentation für Administratoren",
+    "Visit website" : "Webseite besuchen",
+    "Report a bug" : "Melden Sie einen technischen Fehler",
     "Show description …" : "Beschreibung anzeigen…",
     "Hide description …" : "Beschreibung ausblenden…",
     "This app has an update available." : "Es ist eine Aktualisierung für diese Anwendung verfügbar.",
     "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Dieser App ist keine minimum ownCloud Version zugewiesen. Dies wird ein Fehler in ownCloud 11 und später sein.",
+    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Diese App hat keine maximale ownCloud Version zugeordnet. Dies wird ein Fehler in ownCloud 11 und später sein.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Diese App kann nicht installiert werden, weil die folgenden Abhängigkeiten nicht erfüllt sind:",
     "Enable only for specific groups" : "Nur für bestimmte Gruppen aktivieren",
     "Uninstall App" : "App deinstallieren",
@@ -244,6 +271,17 @@ OC.L10N.register(
     "Change password" : "Passwort ändern",
     "Language" : "Sprache",
     "Help translate" : "Helfen Sie bei der Übersetzung",
+    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "Dies sind die Web-, Desktop und mobilen Clients, mit denen Sie aktuell in Ihrer ownCloud angemeldet sind.",
+    "Browser" : "Browser",
+    "Most recent activity" : "Neueste Aktivität",
+    "You've linked these apps." : "Sie haben diese Apps verbunden.",
+    "Name" : "Name",
+    "An app password is a passcode that gives an app or device permissions to access your %s account." : "Ein App-Passwort ist ein Passwort, dass einer App oder einem Gerät erlaubt auf Ihren %s-Konto zuzugreifen.",
+    "App name" : "App-Name",
+    "Create new app password" : "Neues App-Passwort erstellen",
+    "Use the credentials below to configure your app or device." : "Verwenden Sie die folgenden Zugangsdaten um Ihre App oder Ihr Gerät zu konfigurieren.",
+    "Username" : "Benutzername",
+    "Done" : "Erledigt",
     "Get the apps to sync your files" : "Installieren Sie die Anwendungen, um Ihre Dateien zu synchronisieren",
     "Desktop client" : "Desktop-Client",
     "Android app" : "Android-App",
@@ -256,7 +294,6 @@ OC.L10N.register(
     "Show user backend" : "Benutzer-Backend anzeigen",
     "Send email to new user" : "E-Mail an neuen Benutzer senden",
     "Show email address" : "E-Mail Adresse anzeigen",
-    "Username" : "Benutzername",
     "E-Mail" : "E-Mail",
     "Create" : "Erstellen",
     "Admin Recovery Password" : "Admin-Passwort-Wiederherstellung",
@@ -267,7 +304,6 @@ OC.L10N.register(
     "Admins" : "Administratoren",
     "Default Quota" : "Standardkontingent",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Bitte Speicherkontingent eingeben (z.B.: „512 MB“ oder „12 GB“)",
-    "Unlimited" : "Unbegrenzt",
     "Other" : "Andere",
     "Full Name" : "Vollständiger Name",
     "Group Admin for" : "Gruppenadministrator für",
