@@ -1,27 +1,9 @@
 OC.L10N.register(
     "settings",
     {
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Security & setup warnings" : "Security & setup warnings",
-    "Sharing" : "Sharing",
-    "Server-side encryption" : "Server-side encryption",
-    "External Storage" : "External Storage",
-    "Cron" : "Cron",
-    "Email server" : "Email server",
-    "Log" : "Log",
-    "Tips & tricks" : "Tips & tricks",
-    "Updates" : "Updates",
-    "Couldn't remove app." : "Couldn't remove app.",
-    "Language changed" : "Language changed",
-    "Invalid request" : "Invalid request",
-    "Authentication error" : "Authentication error",
-    "Admins can't remove themself from the admin group" : "Admins can't remove themselves from the admin group",
-    "Unable to add user to group %s" : "Unable to add user to group %s",
-    "Unable to remove user from group %s" : "Unable to remove user from group %s",
-    "Couldn't update app." : "Couldn't update app.",
     "Wrong password" : "Incorrect password",
     "No user supplied" : "No user supplied",
+    "Authentication error" : "Authentication error",
     "Please provide an admin recovery password, otherwise all user data will be lost" : "Please provide an admin recovery password, otherwise all user data will be lost",
     "Wrong admin recovery password. Please check the password and try again." : "Incorrect admin recovery password. Please check the password and try again.",
     "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Backend doesn't support password change, but the user's encryption key was successfully updated.",
@@ -53,6 +35,24 @@ OC.L10N.register(
     "Email saved" : "Email saved",
     "Your full name has been changed." : "Your full name has been changed.",
     "Unable to change full name" : "Unable to change full name",
+    "APCu" : "APCu",
+    "Redis" : "Redis",
+    "Security & setup warnings" : "Security & setup warnings",
+    "Sharing" : "Sharing",
+    "Server-side encryption" : "Server-side encryption",
+    "External Storage" : "External Storage",
+    "Cron" : "Cron",
+    "Email server" : "Email server",
+    "Log" : "Log",
+    "Tips & tricks" : "Tips & tricks",
+    "Updates" : "Updates",
+    "Couldn't remove app." : "Couldn't remove app.",
+    "Language changed" : "Language changed",
+    "Invalid request" : "Invalid request",
+    "Admins can't remove themself from the admin group" : "Admins can't remove themselves from the admin group",
+    "Unable to add user to group %s" : "Unable to add user to group %s",
+    "Unable to remove user from group %s" : "Unable to remove user from group %s",
+    "Couldn't update app." : "Couldn't update app.",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "Are you really sure you want add \"{domain}\" as a trusted domain?",
     "Add trusted domain" : "Add trusted domain",
     "Migration in progress. Please wait until the migration is finished" : "Migration in progress. Please wait until the migration is finished",
@@ -63,6 +63,7 @@ OC.L10N.register(
     "Experimental" : "Experimental",
     "All" : "All",
     "No apps found for your version" : "No apps found for your version",
+    "The app will be downloaded from the app store" : "The app will be downloaded from the app store",
     "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use.",
     "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use.",
     "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "This app is not checked for security issues and is new or known to be unstable. Install at your own risk.",
@@ -73,6 +74,9 @@ OC.L10N.register(
     "Disable" : "Disable",
     "Enable" : "Enable",
     "Error while enabling app" : "Error whilst enabling app",
+    "Error: this app cannot be enabled because it makes the server unstable" : "Error: this app cannot be enabled because it makes the server unstable",
+    "Error: could not disable broken app" : "Error: could not disable broken app",
+    "Error while disabling broken app" : "Error whilst disabling broken app",
     "Updating...." : "Updating....",
     "Error while updating app" : "Error whilst updating app",
     "Updated" : "Updated",
@@ -81,7 +85,11 @@ OC.L10N.register(
     "Uninstall" : "Uninstall",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds.",
     "App update" : "App update",
-    "No apps found for \"{query}\"" : "No apps found for \"{query}\"",
+    "No apps found for {query}" : "No apps found for {query}",
+    "Disconnect" : "Disconnect",
+    "Error while loading browser sessions and device tokens" : "Error whilst loading browser sessions and device tokens",
+    "Error while creating device token" : "Error whilst creating device token",
+    "Error while deleting the token" : "Error whilst deleting the token",
     "An error occurred. Please upload an ASCII-encoded PEM certificate." : "An error occurred. Please upload an ASCII-encoded PEM certificate.",
     "Valid until {date}" : "Valid until {date}",
     "Delete" : "Delete",
@@ -108,7 +116,10 @@ OC.L10N.register(
     "A valid password must be provided" : "A valid password must be provided",
     "A valid email must be provided" : "A valid email must be provided",
     "__language_name__" : "English (British English)",
+    "Unlimited" : "Unlimited",
     "Personal info" : "Personal info",
+    "Sessions" : "Sessions",
+    "App passwords" : "App passwords",
     "Sync clients" : "Sync clients",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Everything (fatal issues, errors, warnings, info, debug)",
     "Info, warnings, errors and fatal issues" : "Info, warnings, errors and fatal issues",
@@ -122,32 +133,34 @@ OC.L10N.register(
     "SSL" : "SSL",
     "TLS" : "TLS",
     "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response.",
-    "Please check the <a target=\"_blank\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Please check the <a target=\"_blank\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm.",
+    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm.",
     "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update.",
     "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator.",
+    "Your database does not run with \"READ COMMITED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Your database does not run with \"READ COMMITED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel.",
     "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience.",
     "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version.",
     "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "The PHP module 'fileinfo' is missing. We strongly recommend enabling this module to get best results with mime-type detection.",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information.",
+    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information.",
     "System locale can not be set to a one which supports UTF-8." : "System locale can not be set to a one which supports UTF-8.",
     "This means that there might be problems with certain characters in file names." : "This means that there might be problems with certain characters in file names.",
     "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "We strongly suggest installing the required packages on your system to support one of the following locales: %s.",
     "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")",
     "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:",
-    "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>.",
     "All checks passed." : "All checks passed.",
     "Open documentation" : "Open documentation",
     "Allow apps to use the Share API" : "Allow apps to use the Share API",
     "Allow users to share via link" : "Allow users to share via link",
-    "Enforce password protection" : "Enforce password protection",
     "Allow public uploads" : "Allow public uploads",
-    "Allow users to send mail notification for shared files" : "Allow users to send mail notification for shared files",
+    "Enforce password protection" : "Enforce password protection",
     "Set default expiration date" : "Set default expiry date",
+    "Allow users to send mail notification for shared files" : "Allow users to send mail notification for shared files",
     "Expire after " : "Expire after ",
     "days" : "days",
     "Enforce expiration date" : "Enforce expiry date",
     "Allow resharing" : "Allow resharing",
+    "Allow sharing with groups" : "Allow sharing with groups",
     "Restrict users to only share with users in their groups" : "Restrict users to only share with users in their groups",
     "Allow users to send mail notification for shared files to other users" : "Allow users to send email notification for shared files to other users",
     "Exclude groups from sharing" : "Exclude groups from sharing",
@@ -194,7 +207,7 @@ OC.L10N.register(
     "What to log" : "What to log",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite is used as database. For larger installations, we recommend you switch to a different database backend.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Especially when using the desktop client for file syncing, the use of SQLite is discouraged.",
-    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>.",
+    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>.",
     "How to do backups" : "How to do backups",
     "Advanced monitoring" : "Advanced monitoring",
     "Performance tuning" : "Performance tuning",
@@ -210,6 +223,8 @@ OC.L10N.register(
     "Documentation:" : "Documentation:",
     "User documentation" : "User documentation",
     "Admin documentation" : "Admin documentation",
+    "Visit website" : "Visit website",
+    "Report a bug" : "Report a bug",
     "Show description …" : "Show description …",
     "Hide description …" : "Hide description …",
     "This app has an update available." : "This app has an update available.",
@@ -256,6 +271,17 @@ OC.L10N.register(
     "Change password" : "Change password",
     "Language" : "Language",
     "Help translate" : "Help translate",
+    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "These are the web, desktop and mobile clients currently logged in to your ownCloud.",
+    "Browser" : "Browser",
+    "Most recent activity" : "Most recent activity",
+    "You've linked these apps." : "You've linked these apps.",
+    "Name" : "Name",
+    "An app password is a passcode that gives an app or device permissions to access your %s account." : "An app password is a passcode that gives an app or device permissions to access your %s account.",
+    "App name" : "App name",
+    "Create new app password" : "Create new app password",
+    "Use the credentials below to configure your app or device." : "Use the credentials below to configure your app or device.",
+    "Username" : "Username",
+    "Done" : "Done",
     "Get the apps to sync your files" : "Get the apps to sync your files",
     "Desktop client" : "Desktop client",
     "Android app" : "Android app",
@@ -268,7 +294,6 @@ OC.L10N.register(
     "Show user backend" : "Show user backend",
     "Send email to new user" : "Send email to new user",
     "Show email address" : "Show email address",
-    "Username" : "Username",
     "E-Mail" : "E-Mail",
     "Create" : "Create",
     "Admin Recovery Password" : "Admin Recovery Password",
@@ -279,7 +304,6 @@ OC.L10N.register(
     "Admins" : "Admins",
     "Default Quota" : "Default Quota",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Please enter storage quota (e.g. \"512 MB\" or \"12 GB\")",
-    "Unlimited" : "Unlimited",
     "Other" : "Other",
     "Full Name" : "Full Name",
     "Group Admin for" : "Group Admin for",
