@@ -1,27 +1,9 @@
 OC.L10N.register(
     "settings",
     {
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Security & setup warnings" : "Avertissements de sécurité & configuration",
-    "Sharing" : "Partage",
-    "Server-side encryption" : "Chiffrement côté serveur",
-    "External Storage" : "Stockage externe",
-    "Cron" : "Cron",
-    "Email server" : "Serveur e-mail",
-    "Log" : "Log",
-    "Tips & tricks" : "Trucs et astuces",
-    "Updates" : "Mises à jour",
-    "Couldn't remove app." : "Impossible de supprimer l'application.",
-    "Language changed" : "Langue changée",
-    "Invalid request" : "Requête non valide",
-    "Authentication error" : "Erreur d'authentification",
-    "Admins can't remove themself from the admin group" : "Les administrateurs ne peuvent pas se retirer eux-mêmes du groupe admin",
-    "Unable to add user to group %s" : "Impossible d'ajouter l'utilisateur au groupe %s",
-    "Unable to remove user from group %s" : "Impossible de supprimer l'utilisateur du groupe %s",
-    "Couldn't update app." : "Impossible de mettre à jour l'application",
     "Wrong password" : "Mot de passe incorrect",
     "No user supplied" : "Aucun utilisateur fourni",
+    "Authentication error" : "Erreur d'authentification",
     "Please provide an admin recovery password, otherwise all user data will be lost" : "Veuillez fournir un mot de passe administrateur de récupération de données, sinon toutes les données de l'utilisateur seront perdues",
     "Wrong admin recovery password. Please check the password and try again." : "Mot de passe administrateur de récupération de données non valable. Veuillez vérifier le mot de passe et essayer à nouveau.",
     "Backend doesn't support password change, but the user's encryption key was successfully updated." : "L'infrastructure d'arrière-plan ne supporte pas la modification de mot de passe, mais la clef de chiffrement de l'utilisateur a été mise à jour avec succès.",
@@ -53,6 +35,24 @@ OC.L10N.register(
     "Email saved" : "E-mail sauvegardé",
     "Your full name has been changed." : "Votre nom complet a été modifié.",
     "Unable to change full name" : "Impossible de changer le nom complet",
+    "APCu" : "APCu",
+    "Redis" : "Redis",
+    "Security & setup warnings" : "Avertissements de sécurité & configuration",
+    "Sharing" : "Partage",
+    "Server-side encryption" : "Chiffrement côté serveur",
+    "External Storage" : "Stockage externe",
+    "Cron" : "Cron",
+    "Email server" : "Serveur e-mail",
+    "Log" : "Log",
+    "Tips & tricks" : "Trucs et astuces",
+    "Updates" : "Mises à jour",
+    "Couldn't remove app." : "Impossible de supprimer l'application.",
+    "Language changed" : "Langue changée",
+    "Invalid request" : "Requête non valide",
+    "Admins can't remove themself from the admin group" : "Les administrateurs ne peuvent pas se retirer eux-mêmes du groupe admin",
+    "Unable to add user to group %s" : "Impossible d'ajouter l'utilisateur au groupe %s",
+    "Unable to remove user from group %s" : "Impossible de supprimer l'utilisateur du groupe %s",
+    "Couldn't update app." : "Impossible de mettre à jour l'application",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "Êtes-vous vraiment sûr de vouloir ajouter \"{domain}\" comme domaine de confiance ?",
     "Add trusted domain" : "Ajouter un domaine de confiance",
     "Migration in progress. Please wait until the migration is finished" : "Migration en cours. Veuillez attendre que celle-ci se termine",
@@ -63,15 +63,20 @@ OC.L10N.register(
     "Experimental" : "Expérimentale",
     "All" : "Tous",
     "No apps found for your version" : "Pas d'application trouvée pour votre version",
+    "The app will be downloaded from the app store" : "Cette application va être téléchargée depuis l'app store",
     "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Les applications officielles sont développées par et avec la communauté ownCloud. Elles permettent à ownCloud d'offrir ses fonctionnalités principales et sont prêtes pour une utilisation en environnement de production. ",
     "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Les applications approuvées sont créées par des développeurs de confiance et ont passé les tests de sécurité. Elles sont activement maintenues et leur code source est ouvert. Leurs développeurs les considèrent stables pour une utilisation normale.",
     "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Cette application est nouvelle ou instable, et sa sécurité n'a pas été vérifiée. Installez-la à vos risques et périls!",
     "Update to %s" : "Mettre à niveau vers la version %s",
+    "_You have %n app update pending_::_You have %n app updates pending_" : ["Vous avez %n application qui attend ça  mise a jour .","Vous avez %n applications qui attendent leurs mise a jour ."],
     "Please wait...." : "Veuillez patienter…",
     "Error while disabling app" : "Erreur lors de la désactivation de l'application",
     "Disable" : "Désactiver",
     "Enable" : "Activer",
     "Error while enabling app" : "Erreur lors de l'activation de l'application",
+    "Error: this app cannot be enabled because it makes the server unstable" : "Erreur : Cette application ne peut pas être activer car cela le serveur instable .",
+    "Error: could not disable broken app" : "Erreur : Impossible de désactiver l’application cassé ",
+    "Error while disabling broken app" : "Erreur lors de la désactivation de l'application cassé  .",
     "Updating...." : "Mise à jour...",
     "Error while updating app" : "Erreur lors de la mise à jour de l'application",
     "Updated" : "Mise à jour effectuée",
@@ -80,7 +85,11 @@ OC.L10N.register(
     "Uninstall" : "Désinstaller",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "L'application a été activée mais doit être mise à jour. Vous allez être redirigé vers la page des mises à jour dans 5 secondes.",
     "App update" : "Mise à jour",
-    "No apps found for \"{query}\"" : "Aucune application trouvée pour \"{query}\"",
+    "No apps found for {query}" : "Aucune application trouvée pour {query}",
+    "Disconnect" : "Déconnection",
+    "Error while loading browser sessions and device tokens" : "Erreur lors du chargement des jetons de la session du navigateur et de l'appareil",
+    "Error while creating device token" : "Erreur lors de la création du jeton de l'appareil",
+    "Error while deleting the token" : "Erreur lors de la suppression du jeton",
     "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Une erreur est survenue. Veuillez fournir un certificat PEM encodé au format ASCII.",
     "Valid until {date}" : "Valide jusqu'au {date}",
     "Delete" : "Supprimer",
@@ -103,10 +112,14 @@ OC.L10N.register(
     "add group" : "ajouter un groupe",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "La modification du mot de passe entrainera la perte des données car la restauration de données n'est pas disponible pour cet utilisateur",
     "A valid username must be provided" : "Un nom d'utilisateur valide doit être saisi",
+    "Error creating user: {message}" : "Erreur a la création d'un utilisateur : {message}",
     "A valid password must be provided" : "Un mot de passe valide doit être saisi",
     "A valid email must be provided" : "Vous devez fournir une adresse e-mail valide",
     "__language_name__" : "Français",
+    "Unlimited" : "Illimité",
     "Personal info" : "Informations personnelles",
+    "Sessions" : "Sessions",
+    "App passwords" : "Mots de passe d'applications",
     "Sync clients" : "Clients de synchronisation",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Tout (erreurs fatales, erreurs, avertissements, informations, debogage)",
     "Info, warnings, errors and fatal issues" : "Informations, avertissements, erreurs et erreurs fatales",
@@ -120,31 +133,34 @@ OC.L10N.register(
     "SSL" : "SSL",
     "TLS" : "TLS",
     "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "php ne semble pas être configuré de manière à récupérer les valeurs des variables d’environnement. Le test de la commande getenv(\"PATH\") retourne seulement une réponse vide. ",
-    "Please check the <a target=\"_blank\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Veuillez consulter <a target=\"_blank\" href=\"%s\">la documentation d'installation ↗</a> pour savoir comment configurer php sur votre serveur, en particulier en cas d'utilisation de php-fpm.",
+    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Veuillez consulter <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">la documentation d'installation ↗</a> pour savoir comment configurer php sur votre serveur, en particulier en cas d'utilisation de php-fpm.",
     "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "La configuration est en mode lecture seule. Ceci empêche la modification de certaines configurations via l'interface web. De plus, le fichier doit être passé manuellement en lecture-écriture avant chaque mise à jour.",
     "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP est apparemment configuré pour supprimer les blocs de documentation internes. Cela rendra plusieurs applications de base inaccessibles.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "La raison est probablement l'utilisation d'un cache / accélérateur tel que Zend OPcache ou eAccelerator.",
+    "Your database does not run with \"READ COMMITED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Votre base de données n'est pas lancée avec le niveau d'isolation de transaction \"READ COMMITED\". Cela peut causer des problèmes lorsque plusieurs actions sont lancées parallèlement.",
     "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Votre serveur fonctionne actuellement sur une plateforme Microsoft Windows. Nous vous recommandons fortement d'utiliser une plateforme Linux pour une expérience utilisateur optimale.",
+    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "Une version de %1$s plus ancienne que %2$s est installée. Pour améliorer la stabilité et les performances, nous recommandons de mettre %1$s à jour.",
     "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Le module PHP 'fileinfo' est manquant. Il est vivement recommandé de l'activer afin d'obtenir de meilleurs résultats de détection mime-type.",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "Le verrouillage transactionnel de fichiers est désactivé. Cela peut causer des conflits en cas d'accès concurrent. Configurez 'filelocking.enabled' dans config.php pour éviter ces problèmes. Consultez la <a target=\"_blank\" href=\"%s\">documentation ↗</a> pour plus d'informations.",
+    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Le verrouillage transactionnel de fichiers est désactivé. Cela peut causer des conflits en cas d'accès concurrent. Configurez 'filelocking.enabled' dans config.php pour éviter ces problèmes. Consultez la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> pour plus d'informations.",
     "System locale can not be set to a one which supports UTF-8." : "Les paramètres régionaux n'ont pu être configurés avec prise en charge d'UTF-8.",
     "This means that there might be problems with certain characters in file names." : "Cela signifie qu'il pourrait y avoir des problèmes avec certains caractères dans les noms de fichier.",
     "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Nous vous recommandons d'installer sur votre système les paquets nécessaires à la prise en charge de l'un des paramètres régionaux suivants : %s",
     "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Si votre installation n'a pas été effectuée à la racine du domaine et qu'elle utilise le cron du système, il peut y avoir des problèmes avec la génération d'URL. Pour les éviter, veuillez configurer l'option \"overwrite.cli.url\" de votre fichier config.php avec le chemin de la racine de votre installation (suggéré : \"%s\")",
     "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "La tâche cron n'a pu s'exécuter via CLI. Ces erreurs techniques sont apparues :",
-    "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Consultez les <a target=\"_blank\" href=\"%s\">guides d'installation ↗</a>,  et cherchez des erreurs ou avertissements dans  <a href=\"#log-section\">les logs</a>.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Consultez les <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">guides d'installation ↗</a>,  et cherchez des erreurs ou avertissements dans  <a href=\"#log-section\">les logs</a>.",
     "All checks passed." : "Tous les tests ont réussi.",
     "Open documentation" : "Voir la documentation",
     "Allow apps to use the Share API" : "Autoriser les applications à utiliser l'API de partage",
     "Allow users to share via link" : "Autoriser les utilisateurs à partager par lien",
-    "Enforce password protection" : "Imposer la protection par mot de passe",
     "Allow public uploads" : "Autoriser les téléversements publics",
-    "Allow users to send mail notification for shared files" : "Autoriser les utilisateurs à envoyer des notifications de partage par e-mail",
+    "Enforce password protection" : "Imposer la protection par mot de passe",
     "Set default expiration date" : "Spécifier une date d'expiration par défaut",
+    "Allow users to send mail notification for shared files" : "Autoriser les utilisateurs à envoyer des notifications de partage par e-mail",
     "Expire after " : "Expiration après ",
     "days" : "jours",
     "Enforce expiration date" : "Imposer la date d'expiration",
     "Allow resharing" : "Autoriser le repartage",
+    "Allow sharing with groups" : "Autoriser le partage avec les groupes",
     "Restrict users to only share with users in their groups" : "N'autoriser les partages qu'entre membres de mêmes groupes",
     "Allow users to send mail notification for shared files to other users" : "Autoriser les utilisateurs à envoyer des notifications de partage par e-mail",
     "Exclude groups from sharing" : "Empêcher certains groupes de partager",
@@ -191,7 +207,7 @@ OC.L10N.register(
     "What to log" : "Ce qu'il faut journaliser",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite est actuellement utilisé comme gestionnaire de base de données. Pour des installations plus volumineuses, nous vous conseillons d'utiliser un autre gestionnaire de base de données.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "L'utilisation de SQLite est particulièrement déconseillée si vous utilisez le client de bureau pour synchroniser vos données.",
-    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "Pour migrer vers un autre type de base de données, utilisez la ligne de commande : 'occ db:convert-type' ou consultez la <a target=\"_blank\" href=\"%s\">documentation ↗</a>.",
+    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Pour migrer vers un autre type de base de données, utilisez la ligne de commande : 'occ db:convert-type' ou consultez la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>.",
     "How to do backups" : "Comment faire des sauvegardes",
     "Advanced monitoring" : "Surveillance avancée",
     "Performance tuning" : "Ajustement des performances",
@@ -207,6 +223,8 @@ OC.L10N.register(
     "Documentation:" : "Documentation :",
     "User documentation" : "Documentation utilisateur",
     "Admin documentation" : "Documentation administrateur",
+    "Visit website" : "Visiter le site web",
+    "Report a bug" : "Signaler un bogue",
     "Show description …" : "Afficher la description...",
     "Hide description …" : "Masquer la description",
     "This app has an update available." : "Cette application a une mise à jour disponible.",
@@ -253,6 +271,17 @@ OC.L10N.register(
     "Change password" : "Changer de mot de passe",
     "Language" : "Langue",
     "Help translate" : "Aidez à traduire",
+    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "Voici les clients web, de bureau et mobiles actuellement connectés à votre ownCloud.",
+    "Browser" : "Navigateur",
+    "Most recent activity" : "Activité la plus récente",
+    "You've linked these apps." : "Vous avez lié ces applications.",
+    "Name" : "Nom",
+    "An app password is a passcode that gives an app or device permissions to access your %s account." : "Un mot de passe d'une application est un code d'accès qui donne à une application ou à un appareil les droits d'accès à votre compte %s.",
+    "App name" : "Nom de l'application",
+    "Create new app password" : "Créer un nouveau mot de passe d'application",
+    "Use the credentials below to configure your app or device." : "Utilisez les identifiants ci-dessous pour configurer votre application ou votre périphérique.",
+    "Username" : "Nom d'utilisateur",
+    "Done" : "Terminé",
     "Get the apps to sync your files" : "Obtenez les applications de synchronisation de vos fichiers",
     "Desktop client" : "Client de bureau",
     "Android app" : "Application Android",
@@ -265,7 +294,6 @@ OC.L10N.register(
     "Show user backend" : "Montrer la source de l'identifiant",
     "Send email to new user" : "Envoyer un e-mail aux utilisateurs créés",
     "Show email address" : "Afficher l'adresse e-mail",
-    "Username" : "Nom d'utilisateur",
     "E-Mail" : "E-Mail",
     "Create" : "Créer",
     "Admin Recovery Password" : "Mot de passe Administrateur de récupération",
@@ -276,7 +304,6 @@ OC.L10N.register(
     "Admins" : "Administrateurs",
     "Default Quota" : "Quota par défaut",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Veuillez entrer le quota de stockage (ex. \"512 MB\" ou \"12 GB\")",
-    "Unlimited" : "Illimité",
     "Other" : "Autre",
     "Full Name" : "Nom complet",
     "Group Admin for" : "Administrateur de groupe pour",
