@@ -1,29 +1,9 @@
 OC.L10N.register(
     "settings",
     {
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Security & setup warnings" : "Peringatan Keamanan & Pengaturan",
-    "Sharing" : "Berbagi",
-    "Server-side encryption" : "Enkripsi sisi-server",
-    "External Storage" : "Penyimpanan Eksternal",
-    "Cron" : "Cron",
-    "Email server" : "Server email",
-    "Log" : "Log",
-    "Tips & tricks" : "Tips & trik",
-    "Updates" : "Pembaruan",
-    "Authentication error" : "Terjadi kesalahan saat otentikasi",
-    "Your full name has been changed." : "Nama lengkap Anda telah diubah",
-    "Unable to change full name" : "Tidak dapat mengubah nama lengkap",
-    "Couldn't remove app." : "Tidak dapat menghapus aplikasi.",
-    "Language changed" : "Bahasa telah diubah",
-    "Invalid request" : "Permintaan tidak valid",
-    "Admins can't remove themself from the admin group" : "Admin tidak dapat menghapus dirinya sendiri dari grup admin",
-    "Unable to add user to group %s" : "Tidak dapat menambahkan pengguna ke grup %s",
-    "Unable to remove user from group %s" : "Tidak dapat menghapus pengguna dari grup %s",
-    "Couldn't update app." : "Tidak dapat memperbarui aplikasi.",
     "Wrong password" : "Sandi salah",
     "No user supplied" : "Tidak ada pengguna yang diberikan",
+    "Authentication error" : "Terjadi kesalahan saat otentikasi",
     "Please provide an admin recovery password, otherwise all user data will be lost" : "Mohon sediakan sandi pemulihan admin, jika tidak semua data pengguna akan terhapus",
     "Wrong admin recovery password. Please check the password and try again." : "Sandi pemulihan admin salah. Periksa sandi dan ulangi kembali.",
     "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Backend tidak mendukung pengubahan sandi, tapi kunci enkripsi pengguna berhasil diperbarui.",
@@ -53,6 +33,26 @@ OC.L10N.register(
     "Invalid user" : "Pengguna salah",
     "Unable to change mail address" : "Tidak dapat mengubah alamat email",
     "Email saved" : "Email disimpan",
+    "Your full name has been changed." : "Nama lengkap Anda telah diubah",
+    "Unable to change full name" : "Tidak dapat mengubah nama lengkap",
+    "APCu" : "APCu",
+    "Redis" : "Redis",
+    "Security & setup warnings" : "Peringatan Keamanan & Pengaturan",
+    "Sharing" : "Berbagi",
+    "Server-side encryption" : "Enkripsi sisi-server",
+    "External Storage" : "Penyimpanan Eksternal",
+    "Cron" : "Cron",
+    "Email server" : "Server email",
+    "Log" : "Log",
+    "Tips & tricks" : "Tips & trik",
+    "Updates" : "Pembaruan",
+    "Couldn't remove app." : "Tidak dapat menghapus aplikasi.",
+    "Language changed" : "Bahasa telah diubah",
+    "Invalid request" : "Permintaan tidak valid",
+    "Admins can't remove themself from the admin group" : "Admin tidak dapat menghapus dirinya sendiri dari grup admin",
+    "Unable to add user to group %s" : "Tidak dapat menambahkan pengguna ke grup %s",
+    "Unable to remove user from group %s" : "Tidak dapat menghapus pengguna dari grup %s",
+    "Couldn't update app." : "Tidak dapat memperbarui aplikasi.",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "Apakah Anda yakin ingin menambahkan \"{domain}\" sebagai domain terpercaya?",
     "Add trusted domain" : "Tambah domain terpercaya",
     "Migration in progress. Please wait until the migration is finished" : "Migrasi sedang dalam proses. Mohon tunggu sampai migrasi selesai.",
@@ -62,6 +62,7 @@ OC.L10N.register(
     "Approved" : "Disetujui",
     "Experimental" : "Uji Coba",
     "All" : "Semua",
+    "No apps found for your version" : "Aplikasi tidak ditemukan untuk versi ini.",
     "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Aplikasi resmi dikembangkan oleh komunitas ownCloud. Mereka menawarkan fitur pusat bagi ownCloud dan siap digunakan untuk penggunaan produksi.",
     "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Aplikasi tersetujui dikembangkan oleh pengembang terpercaya dan telah lulus pemeriksaan keamanan. Mereka secara aktif dipelihara direpositori kode terbuka dan pemelihara sudah memastikan mereka stabil untuk penggunaan normal.",
     "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Apl ini belum diperiksa masalah keamanannya dan masih baru atau biasanya tidak stabil. Instal dengan resiko Anda sendiri.",
@@ -79,6 +80,9 @@ OC.L10N.register(
     "Uninstall" : "Copot",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikasi sudah diaktifkan tetapi perlu diperbarui. Anda akan dialihkan ke halaman pembaruan dalam 5 detik.",
     "App update" : "Pembaruan Aplikasi",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Terjadi kesalahan. Mohon unggah sertifikat PEM terenkode-ASCII.",
+    "Valid until {date}" : "Berlaku sampai {date}",
+    "Delete" : "Hapus",
     "An error occurred: {message}" : "Sebuah kesalahan yang muncul: {message}",
     "Select a profile picture" : "Pilih foto profil",
     "Very weak password" : "Sandi sangat lemah",
@@ -86,12 +90,8 @@ OC.L10N.register(
     "So-so password" : "Sandi lumayan",
     "Good password" : "Sandi baik",
     "Strong password" : "Sandi kuat",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Terjadi kesalahan. Mohon unggah sertifikat PEM terenkode-ASCII.",
-    "Valid until {date}" : "Berlaku sampai {date}",
-    "Delete" : "Hapus",
     "Groups" : "Grup",
     "Unable to delete {objName}" : "Tidak dapat menghapus {objName}",
-    "Error creating group" : "Terjadi kesalahan saat membuat grup",
     "A valid group name must be provided" : "Harus memberikan nama grup yang benar.",
     "deleted {groupName}" : "menghapus {groupName}",
     "undo" : "urungkan",
@@ -101,13 +101,12 @@ OC.L10N.register(
     "add group" : "tambah grup",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "Pengubahan kata sandi akan ditampilkan di data kehilangan, karena data pemulihan tidak tersedia bagi pengguna ini",
     "A valid username must be provided" : "Harus memberikan nama pengguna yang benar",
-    "Error creating user" : "Terjadi kesalahan saat membuat pengguna",
     "A valid password must be provided" : "Harus memberikan sandi yang benar",
     "A valid email must be provided" : "Email yang benar harus diberikan",
     "__language_name__" : "__language_name__",
-    "Sync clients" : "Klien sync",
+    "Unlimited" : "Tak terbatas",
     "Personal info" : "Info pribadi",
-    "SSL root certificates" : "Sertifikat root SSL",
+    "Sync clients" : "Klien sync",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Semuanya (Masalah fatal, kesalahan, peringatan, info, debug)",
     "Info, warnings, errors and fatal issues" : "Info, peringatan, kesalahan dan masalah fatal",
     "Warnings, errors and fatal issues" : "Peringatan, kesalahan dan masalah fatal",
@@ -120,29 +119,24 @@ OC.L10N.register(
     "SSL" : "SSL",
     "TLS" : "TLS",
     "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "kelihatannya php tidak diatur dengan benar untuk variabel lingkungan sistem kueri. Pemeriksaan dengan getenv(\"PATH\") hanya mengembalikan respon kosong.",
-    "Please check the <a target=\"_blank\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Silakan periksa <a target=\"_blank\" href=\"%s\">dokumentasi instalasi ↗</a> untuk membaca catatan konfigurasi dan konfigurasi php pada server Anda, terutama ketika menggunakan php-fpm.",
     "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Konfig Hanya-Baca telah diaktifkan. Ini akan mencegah setelan beberapa konfigurasi melalui antarmuka-web. Selanjutnya, berkas perlu dibuat dapat-dibaca secara manual untuk setiap pembaruan.",
     "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP tampaknya disetel menjadi strip inline doc blocks. Hal ini akan membuat beberapa aplikasi inti tidak dapat diakses.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Hal ini kemungkinan disebabkan oleh cache/akselerator seperti Zend OPcache atau eAccelerator.",
     "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Server Anda dijalankan di Microsoft Windows. Kami sangat menyarankan Linux untuk mendapatkan pengalaman pengguna yang optimal.",
-    "%1$s below version %2$s is installed, for stability and performance reasons we recommend to update to a newer %1$s version." : "%1$s dibawah versi %2$s telah diinstal, untuk alasan kestabilan dan performa, kami menyarankan untuk memperbarui ke versi %1$s yang lebih baru.",
     "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Module 'fileinfo' pada PHP tidak ada. Kami sangat menyarankan untuk mengaktifkan modul ini untuk mendapatkan hasil terbaik pada proses pendeteksian mime-type.",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "Transaksi penguncian berkas dinonaktifkan, hal ini dapat menyebabkan masalah dengan kondisi race. Aktifkan 'filelocking.enabled' pada config.php untuk menghindari masalah ini. Baca <a target=\"_blank\" href=\"%s\">dokumentasi ↗</a> untuk informasi lebih lanjut.",
     "System locale can not be set to a one which supports UTF-8." : "Sistem lokal tidak dapat diatur untuk satu yang mendukung UTF-8.",
     "This means that there might be problems with certain characters in file names." : "Ini artinya mungkin ada masalah dengan karakter tertentu pada nama berkas.",
     "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Kamu sangat menyarankan untuk menginstal paket-paket yang dibutuhkan pada sistem agar mendukung lokal berikut: %s.",
     "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Jika instalasi Anda tidak di root domain dan menggunakan sistem cron, hal tersebut dapat menyebabkan masalah dengan pembuatan URL. Untuk mencegah masalah tersebut, mohon atur opsi \"overwrite.cli.url\" pada berkas config.php Anda ke jalur lokasi webroot instalasi Anda (Disarankan: \"%s\")",
     "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Tidak mungkin untuk mengeksekusi cronjob via CLI. Kesalahan teknis berikut muncul:",
-    "Transactional file locking is using the database as locking backend, for best performance it's advised to configure a memcache for locking. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "Transaksi penguncian berkas menggunakan basis data sebagai backend penguncian, untuk mendapatkan kinerja terbaik, disarankan mengkonfigurasi memcache sebagai penguncian. Baca <a target=\"_blank\" href=\"%s\">dokumentasi ↗</a> untuk informasi lebih lanjut.",
-    "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Mohon periksa dua kali <a target=\"_blank\" href=\"%s\">panduan instalasi ↗</a>, dan periksa segala kesalahan atau peringatan pada <a href=\"#log-section\">log</a>.",
     "All checks passed." : "Semua pemeriksaan lulus.",
     "Open documentation" : "Buka dokumentasi",
     "Allow apps to use the Share API" : "Izinkan aplikasi untuk menggunakan API Pembagian",
     "Allow users to share via link" : "Izinkan pengguna untuk membagikan via tautan",
-    "Enforce password protection" : "Berlakukan perlindungan sandi",
     "Allow public uploads" : "Izinkan unggahan publik",
-    "Allow users to send mail notification for shared files" : "Izinkan pengguna untuk mengirimkan email pemberitahuan untuk berkas berbagi",
+    "Enforce password protection" : "Berlakukan perlindungan sandi",
     "Set default expiration date" : "Atur tanggal kadaluarsa default",
+    "Allow users to send mail notification for shared files" : "Izinkan pengguna untuk mengirimkan email pemberitahuan untuk berkas berbagi",
     "Expire after " : "Kadaluarsa setelah",
     "days" : "hari",
     "Enforce expiration date" : "Berlakukan tanggal kadaluarsa",
@@ -186,14 +180,12 @@ OC.L10N.register(
     "Store credentials" : "Simpan kredensial",
     "Test email settings" : "Pengaturan email percobaan",
     "Send email" : "Kirim email",
-    "Log level" : "Level log",
     "Download logfile" : "Unduh berkas log",
     "More" : "Lainnya",
     "Less" : "Ciutkan",
     "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Berkas log lebih besar dari 100MB. Pengunduhan ini memerlukan beberapa saat!",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite digunakan sebagai basis data. Untuk instalasi yang lebih besar, kami menyarankan untuk beralih ke backend basis data yang berbeda.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Terutama saat menggunakan klien desktop untuk sinkronisasi berkas, penggunaan SQLite tidak disarankan.",
-    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "Untuk migrasi ke basis data lainnya, gunakan alat baris perintah: 'occ db:convert-type', atau lihat <a target=\"_blank\" href=\"%s\">dokumentasi ↗</a>.",
     "How to do backups" : "Bagaimana cara membuat cadangan",
     "Advanced monitoring" : "Pemantauan tingkat lanjut",
     "Performance tuning" : "Pemeliharaan performa",
@@ -204,8 +196,6 @@ OC.L10N.register(
     "Developer documentation" : "Dokumentasi pengembang",
     "Experimental applications ahead" : "Aplikasi percobaan terdepan",
     "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "Aplikasi percobaan belum diperiksa untuk masalah keamanan, baru atau dikenal tidak stabil dan dalam proses pengembangan. Menginstalnya dapat menyebabkan kehilangan data atau penerobosan keamanan.",
-    "by" : "oleh",
-    "licensed" : "dilisensikan",
     "Documentation:" : "Dokumentasi:",
     "User documentation" : "Dokumentasi pengguna.",
     "Admin documentation" : "Dokumentasi admin",
@@ -215,7 +205,11 @@ OC.L10N.register(
     "Enable only for specific groups" : "Aktifkan hanya untuk grup tertentu",
     "Uninstall App" : "Copot aplikasi",
     "Enable experimental apps" : "Aktifkan aplikasi percobaan",
-    "No apps found for your version" : "Aplikasi tidak ditemukan untuk versi ini.",
+    "Common Name" : "Nama umum",
+    "Valid until" : "Berlaku sampai",
+    "Issued By" : "Diterbitkan oleh",
+    "Valid until %s" : "Berlaku sampai %s",
+    "Import root certificate" : "Impor sertifikat root",
     "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Hai,<br><br>sekedar memberi tahu bahwa Andaa sekarang memiliki akun %s.<br><br>Nama Pengguna Anda: %s<br>Akses di: <a href=\"%s\">%s</a><br><br>",
     "Cheers!" : "Horee!",
     "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Hai,\n\nsekedar memberi tahu bahwa Andaa sekarang memiliki akun %s.\n\nNama Pengguna Anda: %s\nAkses di: %s\n",
@@ -224,47 +218,38 @@ OC.L10N.register(
     "Forum" : "Forum",
     "Issue tracker" : "Pelacak masalah",
     "Commercial support" : "Dukungan komersial",
+    "Profile picture" : "Foto profil",
+    "Upload new" : "Unggah baru",
+    "Remove image" : "Hapus gambar",
+    "Cancel" : "Batal",
+    "Full name" : "Nama lengkap",
+    "No display name set" : "Nama tampilan tidak diatur",
+    "Email" : "Email",
+    "Your email address" : "Alamat email Anda",
+    "No email address set" : "Alamat email tidak diatur",
+    "You are member of the following groups:" : "Anda adalah anggota dari grup berikut:",
+    "Password" : "Sandi",
+    "Unable to change your password" : "Gagal mengubah sandi Anda",
+    "Current password" : "Sandi saat ini",
+    "New password" : "Sandi baru",
+    "Change password" : "Ubah sandi",
+    "Language" : "Bahasa",
+    "Help translate" : "Bantu menerjemahkan",
+    "Name" : "Nama",
+    "Username" : "Nama pengguna",
+    "Done" : "Selesai",
     "Get the apps to sync your files" : "Dapatkan aplikasi untuk sinkronisasi berkas Anda",
     "Desktop client" : "Klien desktop",
     "Android app" : "Aplikasi Android",
     "iOS app" : "Aplikasi iOS",
     "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Jika Anda ingin mendukung proyek ini\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">bergabunglah dalam pengembangan</a>\n\t\tatau\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">promosikan</a>!",
     "Show First Run Wizard again" : "Tampilkan Penuntun Konfigurasi Awal",
-    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Anda telah menggunakan <strong>%s</strong> dari total <strong>%s</strong>",
-    "Password" : "Sandi",
-    "Unable to change your password" : "Gagal mengubah sandi Anda",
-    "Current password" : "Sandi saat ini",
-    "New password" : "Sandi baru",
-    "Change password" : "Ubah sandi",
-    "Full name" : "Nama lengkap",
-    "No display name set" : "Nama tampilan tidak diatur",
-    "Email" : "Email",
-    "Your email address" : "Alamat email Anda",
-    "Fill in an email address to enable password recovery and receive notifications" : "Isikan alamat email untuk mengaktifkan pemulihan sandi dan menerima notifikasi",
-    "No email address set" : "Alamat email tidak diatur",
-    "You are member of the following groups:" : "Anda adalah anggota dari grup berikut:",
-    "Profile picture" : "Foto profil",
-    "Upload new" : "Unggah baru",
-    "Select new from Files" : "Pilih baru dari Berkas",
-    "Remove image" : "Hapus gambar",
-    "Either png or jpg. Ideally square but you will be able to crop it. The file is not allowed to exceed the maximum size of 20 MB." : "Boleh png atau jpg. Idealnya berbentuk persegi tetapi Anda dapat memotongnya. Berkas tidak diizinkan melebihi ukuran 20 MB.",
-    "Your avatar is provided by your original account." : "Avatar disediakan oleh akun asli Anda.",
-    "Cancel" : "Batal",
-    "Choose as profile image" : "Pilih sebagai gambar profil",
-    "Language" : "Bahasa",
-    "Help translate" : "Bantu menerjemahkan",
-    "Common Name" : "Nama umum",
-    "Valid until" : "Berlaku sampai",
-    "Issued By" : "Diterbitkan oleh",
-    "Valid until %s" : "Berlaku sampai %s",
-    "Import root certificate" : "Impor sertifikat root",
     "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Dikembangkan oleh {communityopen}komunitas ownCloud{linkclose}, {githubopen}kode sumber{linkclose} dilisensikan dibawah {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
     "Show storage location" : "Tampilkan kolasi penyimpanan",
     "Show last log in" : "Tampilkan masuk terakhir",
     "Show user backend" : "Tampilkan pengguna backend",
     "Send email to new user" : "Kirim email kepada pengguna baru",
     "Show email address" : "Tampilkan alamat email",
-    "Username" : "Nama pengguna",
     "E-Mail" : "E-Mail",
     "Create" : "Buat",
     "Admin Recovery Password" : "Sandi pemulihan Admin",
@@ -275,7 +260,6 @@ OC.L10N.register(
     "Admins" : "Admin",
     "Default Quota" : "Kuota default",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Silakan masukkan jumlah penyimpanan (contoh: \"512 MB\" atau \"12 GB\")",
-    "Unlimited" : "Tak terbatas",
     "Other" : "Lainnya",
     "Full Name" : "Nama Lengkap",
     "Group Admin for" : "Grup Admin untuk",
