@@ -1,24 +1,12 @@
 OC.L10N.register(
     "settings",
     {
-    "Security & setup warnings" : "Ostrzeżenia bezpieczeństwa i konfiguracji",
-    "Sharing" : "Udostępnianie",
-    "External Storage" : "Zewnętrzna zasoby dyskowe",
-    "Cron" : "Cron",
-    "Log" : "Logi",
-    "Updates" : "Aktualizacje",
-    "Couldn't remove app." : "Nie można usunąć aplikacji.",
-    "Language changed" : "Zmieniono język",
-    "Invalid request" : "Nieprawidłowe żądanie",
-    "Authentication error" : "Błąd uwierzytelniania",
-    "Admins can't remove themself from the admin group" : "Administratorzy nie mogą usunąć siebie samych z grupy administratorów",
-    "Unable to add user to group %s" : "Nie można dodać użytkownika do grupy %s",
-    "Unable to remove user from group %s" : "Nie można usunąć użytkownika z grupy %s",
-    "Couldn't update app." : "Nie można uaktualnić aplikacji.",
     "Wrong password" : "Złe hasło",
     "No user supplied" : "Niedostarczony użytkownik",
+    "Authentication error" : "Błąd uwierzytelniania",
     "Please provide an admin recovery password, otherwise all user data will be lost" : "Podaj hasło odzyskiwania administratora, w przeciwnym razie wszystkie dane użytkownika zostaną utracone",
     "Wrong admin recovery password. Please check the password and try again." : "Błędne hasło odzyskiwania. Sprawdź hasło i spróbuj ponownie.",
+    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Zaplecze nie obsługuje zmiany hasła, ale klucz szyfrowania użytkownika został pomyślnie zaktualizowany.",
     "Unable to change password" : "Nie można zmienić hasła",
     "Enabled" : "Włączone",
     "Not enabled" : "Nie włączone",
@@ -40,9 +28,28 @@ OC.L10N.register(
     "Email saved" : "E-mail zapisany",
     "Your full name has been changed." : "Twoja pełna nazwa została zmieniona.",
     "Unable to change full name" : "Nie można zmienić pełnej nazwy",
+    "Redis" : "Redis",
+    "Security & setup warnings" : "Ostrzeżenia bezpieczeństwa i konfiguracji",
+    "Sharing" : "Udostępnianie",
+    "Server-side encryption" : "Szyfrowanie po stronie serwera",
+    "External Storage" : "Zewnętrzna zasoby dyskowe",
+    "Cron" : "Cron",
+    "Email server" : "Serwer pocztowy",
+    "Log" : "Logi",
+    "Updates" : "Aktualizacje",
+    "Couldn't remove app." : "Nie można usunąć aplikacji.",
+    "Language changed" : "Zmieniono język",
+    "Invalid request" : "Nieprawidłowe żądanie",
+    "Admins can't remove themself from the admin group" : "Administratorzy nie mogą usunąć siebie samych z grupy administratorów",
+    "Unable to add user to group %s" : "Nie można dodać użytkownika do grupy %s",
+    "Unable to remove user from group %s" : "Nie można usunąć użytkownika z grupy %s",
+    "Couldn't update app." : "Nie można uaktualnić aplikacji.",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "Czy jesteś pewien/pewna że chcesz dodać \"{domain}\" jako zaufaną domenę?",
     "Add trusted domain" : "Dodaj zaufaną domenę",
+    "Migration in progress. Please wait until the migration is finished" : "Trwa migracja. Proszę poczekać, aż migracja dobiegnie końca.",
+    "Migration started …" : "Migracja rozpoczęta...",
     "Sending..." : "Wysyłam...",
+    "Experimental" : "Eksperymentalny",
     "All" : "Wszystkie",
     "No apps found for your version" : "Nie znaleziono aplikacji dla twojej wersji",
     "Update to %s" : "Uaktualnij do %s",
@@ -57,8 +64,12 @@ OC.L10N.register(
     "Uninstalling ...." : "Odinstalowywanie....",
     "Error while uninstalling app" : "Błąd przy odinstalowywaniu aplikacji",
     "Uninstall" : "Odinstaluj",
+    "Error while loading browser sessions and device tokens" : "Błąd podczas ładowania sesji przeglądarek i tokenów urządzeń",
+    "Error while creating device token" : "Błąd podczas tworzenia tokena urządzenia.",
+    "Error while deleting the token" : "Błąd podczas usuwania tokena.",
     "Valid until {date}" : "Ważny do {date}",
     "Delete" : "Usuń",
+    "An error occurred: {message}" : "Wystąpił błąd: {message}",
     "Select a profile picture" : "Wybierz zdjęcie profilu",
     "Very weak password" : "Bardzo słabe hasło",
     "Weak password" : "Słabe hasło",
@@ -67,6 +78,7 @@ OC.L10N.register(
     "Strong password" : "Mocne hasło",
     "Groups" : "Grupy",
     "Unable to delete {objName}" : "Nie można usunąć {objName}",
+    "Error creating group: {message}" : "Błąd podczas tworzenia grupy: {message}",
     "A valid group name must be provided" : "Należy podać prawidłową nazwę grupy",
     "deleted {groupName}" : "usunięto {groupName}",
     "undo" : "cofnij",
@@ -76,9 +88,14 @@ OC.L10N.register(
     "add group" : "dodaj grupę",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "Zmiana hasła spowoduje utratę danych, ponieważ odzyskiwanie danych nie jest włączone dla tego użytkownika",
     "A valid username must be provided" : "Należy podać prawidłową nazwę użytkownika",
+    "Error creating user: {message}" : "Błąd podczas tworzenia użytkownika: {message}",
     "A valid password must be provided" : "Należy podać prawidłowe hasło",
     "A valid email must be provided" : "Podaj poprawny adres email",
     "__language_name__" : "polski",
+    "Unlimited" : "Bez limitu",
+    "Personal info" : "Informacje osobiste",
+    "Sessions" : "Sesje",
+    "Sync clients" : "Klienty synchronizacji",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Wszystko  (Informacje, ostrzeżenia, błędy i poważne problemy, debug)",
     "Info, warnings, errors and fatal issues" : "Informacje, ostrzeżenia, błędy i poważne problemy",
     "Warnings, errors and fatal issues" : "Ostrzeżenia, błędy i poważne problemy",
@@ -100,10 +117,10 @@ OC.L10N.register(
     "Open documentation" : "Otwórz dokumentację",
     "Allow apps to use the Share API" : "Zezwalaj aplikacjom na korzystanie z API udostępniania",
     "Allow users to share via link" : "Pozwól użytkownikom współdzielić przez link",
-    "Enforce password protection" : "Wymuś zabezpieczenie hasłem",
     "Allow public uploads" : "Pozwól na  publiczne wczytywanie",
-    "Allow users to send mail notification for shared files" : "Zezwól użytkownikom na wysyłanie powiadomień email dla udostępnionych plików",
+    "Enforce password protection" : "Wymuś zabezpieczenie hasłem",
     "Set default expiration date" : "Ustaw domyślną datę wygaśnięcia",
+    "Allow users to send mail notification for shared files" : "Zezwól użytkownikom na wysyłanie powiadomień email dla udostępnionych plików",
     "Expire after " : "Wygaś po",
     "days" : "dniach",
     "Enforce expiration date" : "Wymuś datę wygaśnięcia",
@@ -115,7 +132,11 @@ OC.L10N.register(
     "Execute one task with each page loaded" : "Wykonuj jedno zadanie wraz z każdą wczytaną stroną",
     "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php jest zarejestrowany w serwisie webcron do uruchamiania cron.php raz na 15 minut przez http.",
     "Use system's cron service to call the cron.php file every 15 minutes." : "Użyj systemowej usługi cron do wywoływania cron.php co 15 minut.",
+    "Enable server-side encryption" : "Włącz szyfrowanie po stronie serwera",
+    "Be aware that encryption always increases the file size." : "Należy pamiętać, że szyfrowanie zawsze zwiększa rozmiar pliku.",
+    "This is the final warning: Do you really want to enable encryption?" : "To ostatnie ostrzeżenie: Czy na pewno chcesz włączyć szyfrowanie?",
     "Enable encryption" : "Włącz szyfrowanie",
+    "Select default encryption module:" : "Wybierz domyślny moduł szyfrujący:",
     "This is used for sending out notifications." : "To jest używane do wysyłania powiadomień",
     "Send mode" : "Tryb wysyłki",
     "Encryption" : "Szyfrowanie",
@@ -139,6 +160,7 @@ OC.L10N.register(
     "Developer documentation" : "Dokumentacja dewelopera",
     "Documentation:" : "Dokumentacja:",
     "User documentation" : "Dokumentacja użytkownika",
+    "Report a bug" : "Zgłoś błąd",
     "Show description …" : "Pokaż opis ...",
     "Hide description …" : "Ukryj opis ...",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Ta aplikacja nie może być zainstalowana, ponieważ nie są spełnione następujące zależności:",
@@ -173,6 +195,9 @@ OC.L10N.register(
     "Change password" : "Zmień hasło",
     "Language" : "Język",
     "Help translate" : "Pomóż w tłumaczeniu",
+    "Name" : "Nazwa",
+    "Username" : "Nazwa użytkownika",
+    "Done" : "Ukończono",
     "Get the apps to sync your files" : "Pobierz aplikacje żeby synchronizować swoje pliki",
     "Desktop client" : "Klient na komputer",
     "Android app" : "Aplikacja Android",
@@ -180,9 +205,9 @@ OC.L10N.register(
     "Show First Run Wizard again" : "Uruchom ponownie kreatora pierwszego uruchomienia",
     "Show storage location" : "Pokaż miejsce przechowywania",
     "Show last log in" : "Pokaż ostatni login",
+    "Show user backend" : "Pokaż moduł użytkownika",
     "Send email to new user" : "Wyślij email do nowego użytkownika",
     "Show email address" : "Pokaż adres email",
-    "Username" : "Nazwa użytkownika",
     "E-Mail" : "E-mail",
     "Create" : "Utwórz",
     "Admin Recovery Password" : "Odzyskiwanie hasła administratora",
@@ -193,7 +218,6 @@ OC.L10N.register(
     "Admins" : "Administratorzy",
     "Default Quota" : "Domyślny udział",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Proszę ustawić ograniczenie zasobów (np. \"512 MB\" albo \"12 GB)",
-    "Unlimited" : "Bez limitu",
     "Other" : "Inne",
     "Full Name" : "Pełna nazwa",
     "Group Admin for" : "Grupa Admin dla",
