@@ -1,27 +1,9 @@
 OC.L10N.register(
     "settings",
     {
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Security & setup warnings" : "Güvenlik ve kurulum uyarıları",
-    "Sharing" : "Paylaşım",
-    "Server-side encryption" : "Sunucu taraflı şifreleme",
-    "External Storage" : "Harici Depolama",
-    "Cron" : "Cron",
-    "Email server" : "E-posta sunucusu",
-    "Log" : "Günlük",
-    "Tips & tricks" : "İpuçları ve hileler",
-    "Updates" : "Güncellemeler",
-    "Couldn't remove app." : "Uygulama kaldırılamadı.",
-    "Language changed" : "Dil değiştirildi",
-    "Invalid request" : "Geçersiz istek",
-    "Authentication error" : "Kimlik doğrulama hatası",
-    "Admins can't remove themself from the admin group" : "Yöneticiler kendilerini admin grubundan kaldıramaz",
-    "Unable to add user to group %s" : "Kullanıcı %s grubuna eklenemiyor",
-    "Unable to remove user from group %s" : "%s grubundan kullanıcı kaldırılamıyor",
-    "Couldn't update app." : "Uygulama güncellenemedi.",
     "Wrong password" : "Hatalı parola",
     "No user supplied" : "Kullanıcı girilmedi",
+    "Authentication error" : "Kimlik doğrulama hatası",
     "Please provide an admin recovery password, otherwise all user data will be lost" : "Lütfen yönetici kurtarma parolasını girin, aksi takdirde tüm kullanıcı verisi kaybedilecek",
     "Wrong admin recovery password. Please check the password and try again." : "Hatalı yönetici kurtarma parolası. Lütfen parolayı denetleyip yeniden deneyin.",
     "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Arka uç, parola değiştirmesini desteklemiyor, ancak kullanıcı şifreleme anahtarı başarıyla güncellendi.",
@@ -53,6 +35,24 @@ OC.L10N.register(
     "Email saved" : "E-posta kaydedildi",
     "Your full name has been changed." : "Tam adınız değiştirildi.",
     "Unable to change full name" : "Tam adınız değiştirilirken hata",
+    "APCu" : "APCu",
+    "Redis" : "Redis",
+    "Security & setup warnings" : "Güvenlik ve kurulum uyarıları",
+    "Sharing" : "Paylaşım",
+    "Server-side encryption" : "Sunucu taraflı şifreleme",
+    "External Storage" : "Harici Depolama",
+    "Cron" : "Cron",
+    "Email server" : "E-posta sunucusu",
+    "Log" : "Günlük",
+    "Tips & tricks" : "İpuçları ve hileler",
+    "Updates" : "Güncellemeler",
+    "Couldn't remove app." : "Uygulama kaldırılamadı.",
+    "Language changed" : "Dil değiştirildi",
+    "Invalid request" : "Geçersiz istek",
+    "Admins can't remove themself from the admin group" : "Yöneticiler kendilerini admin grubundan kaldıramaz",
+    "Unable to add user to group %s" : "Kullanıcı %s grubuna eklenemiyor",
+    "Unable to remove user from group %s" : "%s grubundan kullanıcı kaldırılamıyor",
+    "Couldn't update app." : "Uygulama güncellenemedi.",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "\"{domain}\" alan adını güvenilir alan adı olarak eklemek istediğinizden emin misiniz?",
     "Add trusted domain" : "Güvenilir alan adı ekle",
     "Migration in progress. Please wait until the migration is finished" : "Taşınma sürüyor. Lütfen taşınma tamamlanana kadar bekleyin",
@@ -63,15 +63,20 @@ OC.L10N.register(
     "Experimental" : "Deneysel",
     "All" : "Tümü",
     "No apps found for your version" : "Sürümünüz için uygulama bulunamadı",
+    "The app will be downloaded from the app store" : "uygulama uygulama dükkanından indirilebilecek",
     "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Resmi uygulamalar ownCloud topluluğu tarafından geliştirilir. ownCloud'a işlevsellik merkezli olarak hazırlanırlar ve günlük kullanıma hazırdırlar.",
     "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Onaylanan uygulamalar güvenilir geliştiriciler tarafından geliştirilir ve detaylı olmayan bir güvenlik kontrolünden geçirilir. Bunlar açık kaynak kod deposunda bulunmakta ve normal kullanım için kararlı oldukları varsayılmaktadır.",
     "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Bu uygulama güvenlik kontrolünden geçmedi veya yeni ya da kararsız olarak bilinmektedir. Kendiniz bu riski alarak yükleyebilirsiniz.",
     "Update to %s" : "%s sürümüne güncelle",
+    "_You have %n app update pending_::_You have %n app updates pending_" : ["Bekleyen %n uygulama güncellemesi var","Bekleyen %n uygulama güncellemesi var"],
     "Please wait...." : "Lütfen bekleyin....",
     "Error while disabling app" : "Uygulama devre dışı bırakılırken hata",
     "Disable" : "Devre Dışı Bırak",
     "Enable" : "Etkinleştir",
     "Error while enabling app" : "Uygulama etkinleştirilirken hata",
+    "Error: this app cannot be enabled because it makes the server unstable" : "Hata: bu uygulama etkinleştirilemez çünkü sunucuyu kararsız yapıyor",
+    "Error: could not disable broken app" : "Hata: bozuk uygulama devre dışı bırakılamadı",
+    "Error while disabling broken app" : "Bozuk uygulama devre dışı bırakılırken hata",
     "Updating...." : "Güncelleniyor....",
     "Error while updating app" : "Uygulama güncellenirken hata",
     "Updated" : "Güncellendi",
@@ -80,7 +85,7 @@ OC.L10N.register(
     "Uninstall" : "Kaldır",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Uygulama etkinleştirildi fakat güncellenmesi gerekiyor. 5 saniye içinde güncelleme sayfasına yönlendirileceksiniz.",
     "App update" : "Uygulama güncellemesi",
-    "No apps found for \"{query}\"" : "\"{query}\" için uygulama bulunamadı",
+    "No apps found for {query}" : "sorgulayabilmeniz için hiçbir uygulama bulunmamakta",
     "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Bir hata oluştu. Lütfen ASCII-kodlanmış PEM sertifikasını yükleyin.",
     "Valid until {date}" : "{date} tarihine kadar geçerli",
     "Delete" : "Sil",
@@ -93,6 +98,7 @@ OC.L10N.register(
     "Strong password" : "Güçlü parola",
     "Groups" : "Gruplar",
     "Unable to delete {objName}" : "{objName} silinemiyor",
+    "Error creating group: {message}" : "Grup oluşturulurken hata: {message}",
     "A valid group name must be provided" : "Geçerli bir grup adı mutlaka sağlanmalı",
     "deleted {groupName}" : "{groupName} silindi",
     "undo" : "geri al",
@@ -102,9 +108,11 @@ OC.L10N.register(
     "add group" : "grup ekle",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "Parolayı değiştirmek, bu kullanıcı için veri kurtarması kullanılamadığından veri kaybına sebep olacak",
     "A valid username must be provided" : "Geçerli bir kullanıcı adı mutlaka sağlanmalı",
+    "Error creating user: {message}" : "Kullanıcı oluşturulurken hata: {message}",
     "A valid password must be provided" : "Geçerli bir parola mutlaka sağlanmalı",
     "A valid email must be provided" : "Geçerli bir e-posta belirtilmeli",
     "__language_name__" : "Türkçe",
+    "Unlimited" : "Sınırsız",
     "Personal info" : "Kişisel bilgi",
     "Sync clients" : "Eşitleme istemcileri",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Her şey (Ciddi sorunlar, hatalar, uyarılar, bilgi, hata ayıklama)",
@@ -119,31 +127,33 @@ OC.L10N.register(
     "SSL" : "SSL",
     "TLS" : "TLS",
     "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP sistem değişkenleri sorgusuna uygun olarak ayarlanmamış görünüyor. getenv(\"PATH\") komutu sadece boş bir cevap döndürüyor.",
-    "Please check the <a target=\"_blank\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Lütfen <a target=\"_blank\" href=\"%s\">kurulum belgelendirmesindeki ↗</a> php ayarlama notlarını ve sunucudaki özellikle php-fpm kullanırken php ayarlamalarını kontrol edin.",
+    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Lütfen php yapılandırma notları ve özellikler php-fpm kullanırken sunucu php yapılandırması için <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">kurulum belgelendirmesine ↗</a> bakın.",
     "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Salt Okunur yapılandırma etkinleştirilmiş. Bu, bazı ayarların web arayüzü ile yapılandırılmasını önler. Ayrıca, bu dosya her güncelleme sırasında el ile yazılabilir yapılmalıdır.",
     "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP satırıçi doc bloklarını ayıklamak üzere yapılandırılmış gibi görünüyor. Bu, bazı çekirdek (core) uygulamalarını erişilemez yapacak.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Bu, muhtemelen Zend OPcache veya eAccelerator gibi bir önbellek/hızlandırıcı nedeniyle gerçekleşir.",
     "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Sunucunuz, Microsoft Windows ile çalışıyor. En uygun kullanıcı deneyimi için şiddetle Linux'u öneriyoruz.",
+    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s, %2$s sürümü altı kurulu. Kararlılık ve performans için daha yeni bir %1$s sürümüne güncellemenizi öneririz.",
     "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP modülü 'fileinfo' kayıp. MIME türü tanıma ile en iyi sonuçları elde etmek için bu modülü etkinleştirmenizi öneririz.",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "İşlemsel dosya kilidi devre dışı, bu yarış koşulu durumlarına sebep olabilir. Bu sorunları önlemek için config.php içerisindeki 'filelocking.enabled' seçeneğini etkinleştirin. Daha fazla bilgi için <a target=\"_blank\" href=\"%s\">belgelendirmeye ↗</a> bakın.",
+    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "İşlemsel dosya kilidi devre dışı. Bu yarış koşulu (race condition) sorunlarına neden olabilir. Bu sorunlardan kaçınmak için config.php içindeki 'filelocking.enabled' ayarını etkinleştirin. Daha fazla bilgi için <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">belgelendirmeye ↗</a> bakın.",
     "System locale can not be set to a one which supports UTF-8." : "Sistem yereli, UTF-8 destekleyenlerden biri olarak ayarlanamadı.",
     "This means that there might be problems with certain characters in file names." : "Bu, dosya adlarında belirli karakterlerde problem olabileceği anlamına gelir.",
     "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Şu dillerden birini desteklemesi için sisteminize gerekli paketleri kurmanızı şiddetle tavsiye ederiz: %s.",
     "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Eğer kurulumunuz alan adının köküne yapılmamışsa ve sistem cron'u kullanıyorsa, URL oluşturma ile ilgili sorunlar oluşabilir. Bu sorunların önüne geçmek için, kurulumunuzun web kök yolundaki config.php dosyasında \"overwrite.cli.url\" seçeneğini ayarlayın (Önerilen: \"%s\")",
     "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Bu CLI ile cronjobı çalıştırmak mümkün değildi. Aşağıdaki teknik hatalar ortaya çıkmıştır:",
-    "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Lütfen <a target=\"_blank\" href=\"%s\">kurulum rehberlerini ↗</a> iki kez denetleyip <a href=\"#log-section\">günlük</a> içerisindeki hata ve uyarılara bakın.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Lütfen <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">kurulum rehberlerine ↗</a> ve <a href=\"#log-section\">günlük</a> kısmındaki hata ve uyarılara bakın.",
     "All checks passed." : "Tüm kontroller geçildi.",
     "Open documentation" : "Belgelendirmeyi aç",
     "Allow apps to use the Share API" : "Uygulamaların paylaşım API'sini kullanmasına izin ver",
     "Allow users to share via link" : "Kullanıcıların bağlantı ile paylaşmasına izin ver",
-    "Enforce password protection" : "Parola korumasını zorla",
     "Allow public uploads" : "Herkes tarafından yüklemeye izin ver",
-    "Allow users to send mail notification for shared files" : "Paylaşılmış dosyalar için kullanıcıların posta bildirimi göndermesine izin ver",
+    "Enforce password protection" : "Parola korumasını zorla",
     "Set default expiration date" : "Öntanımlı son kullanma tarihini ayarla",
+    "Allow users to send mail notification for shared files" : "Paylaşılmış dosyalar için kullanıcıların posta bildirimi göndermesine izin ver",
     "Expire after " : "Süre",
     "days" : "gün sonra dolsun",
     "Enforce expiration date" : "Son kullanma tarihini zorla",
     "Allow resharing" : "Yeniden paylaşıma izin ver",
+    "Allow sharing with groups" : "Grouplar ile paylaşıma izin ver",
     "Restrict users to only share with users in their groups" : "Kullanıcıların, dosyaları sadece kendi gruplarındaki kullanıcılarla paylaşmasına izin ver",
     "Allow users to send mail notification for shared files to other users" : "Kullanıcıların diğer kullanıcılara, paylaşılmış dosyalar için posta bildirimi göndermesine izin ver",
     "Exclude groups from sharing" : "Grupları paylaşma eyleminden hariç tut",
@@ -190,7 +200,7 @@ OC.L10N.register(
     "What to log" : "Neler günlüklenmeli",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "Veritabanı olarak SQLite kullanılıyor. Daha büyük kurulumlar için farklı bir veritabanı arka ucuna geçmenizi öneriyoruz.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Özellikle dosya eşitleme için masaüstü istemcisi kullanılırken SQLite kullanımı önerilmez.",
-    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "Başka bir veritabanına geçmek için komut satırı aracını kullanın: 'occ db:convert-type' veya <a target=\"_blank\" href=\"%s\">belgelendirmeye ↗</a> bakın.",
+    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Başka bir veritabanına geçmek için komut satırı aracını kullanın: 'occ db:convert-type' veya <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">belgelendirmeye ↗</a> bakın.",
     "How to do backups" : "Nasıl yedekleme yapılır",
     "Advanced monitoring" : "Gelişmiş izleme",
     "Performance tuning" : "Performans ayarlama",
@@ -208,6 +218,7 @@ OC.L10N.register(
     "Admin documentation" : "Yönetici belgelendirmesi",
     "Show description …" : "Açıklamayı göster...",
     "Hide description …" : "Açıklamayı gizle...",
+    "This app has an update available." : "Bu uygulamanın bir güncellemesi var.",
     "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Bu uygulama atanmış bir en düşük ownCloud sürümü içermiyor. ownCloud 11 ve sonrasında bu bir hata olacaktır.",
     "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Bu uygulama atanmış bir en yüksek ownCloud sürümü içermiyor. ownCloud 11 ve sonrasında bu bir hata olacaktır.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Bu uygulama, aşağıdaki bağımlılıklar sağlanmadığından yüklenemiyor:",
@@ -251,6 +262,9 @@ OC.L10N.register(
     "Change password" : "Parola değiştir",
     "Language" : "Dil",
     "Help translate" : "Çevirilere yardım edin",
+    "Name" : "Ad",
+    "Username" : "Kullanıcı Adı",
+    "Done" : "Bitti",
     "Get the apps to sync your files" : "Dosyalarınızı eşitlemek için uygulamaları indirin",
     "Desktop client" : "Masaüstü istemcisi",
     "Android app" : "Android uygulaması",
@@ -263,7 +277,6 @@ OC.L10N.register(
     "Show user backend" : "Kullanıcı arka ucunu göster",
     "Send email to new user" : "Yeni kullanıcıya e-posta gönder",
     "Show email address" : "E-posta adresini göster",
-    "Username" : "Kullanıcı Adı",
     "E-Mail" : "E-Posta",
     "Create" : "Oluştur",
     "Admin Recovery Password" : "Yönetici Kurtarma Parolası",
@@ -274,7 +287,6 @@ OC.L10N.register(
     "Admins" : "Yöneticiler",
     "Default Quota" : "Öntanımlı Kota",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Lütfen disk alanı kotasını girin (örnek: \"512MB\" veya \"12GB\")",
-    "Unlimited" : "Sınırsız",
     "Other" : "Diğer",
     "Full Name" : "Tam Adı",
     "Group Admin for" : "Grup Yöneticisi",
